import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ApiManagementBackendConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly apiManagementName: string;
    /**
     * @stability stable
     */
    readonly description?: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly protocol: string;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly resourceId?: string;
    /**
     * @stability stable
     */
    readonly title?: string;
    /**
     * @stability stable
     */
    readonly url: string;
    /**
     * credentials block.
     *
     * @stability stable
     */
    readonly credentials?: ApiManagementBackendCredentials[];
    /**
     * proxy block.
     *
     * @stability stable
     */
    readonly proxy?: ApiManagementBackendProxy[];
    /**
     * service_fabric_cluster block.
     *
     * @stability stable
     */
    readonly serviceFabricCluster?: ApiManagementBackendServiceFabricCluster[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: ApiManagementBackendTimeouts;
    /**
     * tls block.
     *
     * @stability stable
     */
    readonly tls?: ApiManagementBackendTls[];
}
/**
 * @stability stable
 */
export interface ApiManagementBackendCredentialsAuthorization {
    /**
     * @stability stable
     */
    readonly parameter?: string;
    /**
     * @stability stable
     */
    readonly scheme?: string;
}
/**
 * @stability stable
 */
export interface ApiManagementBackendCredentials {
    /**
     * @stability stable
     */
    readonly certificate?: string[];
    /**
     * @stability stable
     */
    readonly header?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly query?: {
        [key: string]: string;
    };
    /**
     * authorization block.
     *
     * @stability stable
     */
    readonly authorization?: ApiManagementBackendCredentialsAuthorization[];
}
/**
 * @stability stable
 */
export interface ApiManagementBackendProxy {
    /**
     * @stability stable
     */
    readonly password?: string;
    /**
     * @stability stable
     */
    readonly url: string;
    /**
     * @stability stable
     */
    readonly username: string;
}
/**
 * @stability stable
 */
export interface ApiManagementBackendServiceFabricClusterServerX509Name {
    /**
     * @stability stable
     */
    readonly issuerCertificateThumbprint: string;
    /**
     * @stability stable
     */
    readonly name: string;
}
/**
 * @stability stable
 */
export interface ApiManagementBackendServiceFabricCluster {
    /**
     * @stability stable
     */
    readonly clientCertificateThumbprint: string;
    /**
     * @stability stable
     */
    readonly managementEndpoints: string[];
    /**
     * @stability stable
     */
    readonly maxPartitionResolutionRetries: number;
    /**
     * @stability stable
     */
    readonly serverCertificateThumbprints?: string[];
    /**
     * server_x509_name block.
     *
     * @stability stable
     */
    readonly serverX509Name?: ApiManagementBackendServiceFabricClusterServerX509Name[];
}
/**
 * @stability stable
 */
export interface ApiManagementBackendTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export interface ApiManagementBackendTls {
    /**
     * @stability stable
     */
    readonly validateCertificateChain?: boolean;
    /**
     * @stability stable
     */
    readonly validateCertificateName?: boolean;
}
/**
 * @stability stable
 */
export declare class ApiManagementBackend extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ApiManagementBackendConfig);
    private _apiManagementName;
    /**
     * @stability stable
     */
    get apiManagementName(): string;
    /**
     * @stability stable
     */
    set apiManagementName(value: string);
    /**
     * @stability stable
     */
    get apiManagementNameInput(): string;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _protocol;
    /**
     * @stability stable
     */
    get protocol(): string;
    /**
     * @stability stable
     */
    set protocol(value: string);
    /**
     * @stability stable
     */
    get protocolInput(): string;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    private _resourceId?;
    /**
     * @stability stable
     */
    get resourceId(): string;
    /**
     * @stability stable
     */
    set resourceId(value: string);
    /**
     * @stability stable
     */
    resetResourceId(): void;
    /**
     * @stability stable
     */
    get resourceIdInput(): string | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _url;
    /**
     * @stability stable
     */
    get url(): string;
    /**
     * @stability stable
     */
    set url(value: string);
    /**
     * @stability stable
     */
    get urlInput(): string;
    private _credentials?;
    /**
     * @stability stable
     */
    get credentials(): ApiManagementBackendCredentials[];
    /**
     * @stability stable
     */
    set credentials(value: ApiManagementBackendCredentials[]);
    /**
     * @stability stable
     */
    resetCredentials(): void;
    /**
     * @stability stable
     */
    get credentialsInput(): ApiManagementBackendCredentials[] | undefined;
    private _proxy?;
    /**
     * @stability stable
     */
    get proxy(): ApiManagementBackendProxy[];
    /**
     * @stability stable
     */
    set proxy(value: ApiManagementBackendProxy[]);
    /**
     * @stability stable
     */
    resetProxy(): void;
    /**
     * @stability stable
     */
    get proxyInput(): ApiManagementBackendProxy[] | undefined;
    private _serviceFabricCluster?;
    /**
     * @stability stable
     */
    get serviceFabricCluster(): ApiManagementBackendServiceFabricCluster[];
    /**
     * @stability stable
     */
    set serviceFabricCluster(value: ApiManagementBackendServiceFabricCluster[]);
    /**
     * @stability stable
     */
    resetServiceFabricCluster(): void;
    /**
     * @stability stable
     */
    get serviceFabricClusterInput(): ApiManagementBackendServiceFabricCluster[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ApiManagementBackendTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ApiManagementBackendTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ApiManagementBackendTimeouts | undefined;
    private _tls?;
    /**
     * @stability stable
     */
    get tls(): ApiManagementBackendTls[];
    /**
     * @stability stable
     */
    set tls(value: ApiManagementBackendTls[]);
    /**
     * @stability stable
     */
    resetTls(): void;
    /**
     * @stability stable
     */
    get tlsInput(): ApiManagementBackendTls[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
