import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface AppServiceConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly appServicePlanId: string;
    /**
     * @stability stable
     */
    readonly appSettings?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly clientAffinityEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly clientCertEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly enabled?: boolean;
    /**
     * @stability stable
     */
    readonly httpsOnly?: boolean;
    /**
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * auth_settings block.
     *
     * @stability stable
     */
    readonly authSettings?: AppServiceAuthSettings[];
    /**
     * backup block.
     *
     * @stability stable
     */
    readonly backup?: AppServiceBackup[];
    /**
     * connection_string block.
     *
     * @stability stable
     */
    readonly connectionString?: AppServiceConnectionString[];
    /**
     * identity block.
     *
     * @stability stable
     */
    readonly identity?: AppServiceIdentity[];
    /**
     * logs block.
     *
     * @stability stable
     */
    readonly logs?: AppServiceLogs[];
    /**
     * site_config block.
     *
     * @stability stable
     */
    readonly siteConfig?: AppServiceSiteConfig[];
    /**
     * source_control block.
     *
     * @stability stable
     */
    readonly sourceControl?: AppServiceSourceControl[];
    /**
     * storage_account block.
     *
     * @stability stable
     */
    readonly storageAccount?: AppServiceStorageAccount[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: AppServiceTimeouts;
}
/**
 * @stability stable
 */
export declare class AppServiceSiteCredential extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get password(): string;
    /**
     * @stability stable
     */
    get username(): string;
}
/**
 * @stability stable
 */
export interface AppServiceAuthSettingsActiveDirectory {
    /**
     * @stability stable
     */
    readonly allowedAudiences?: string[];
    /**
     * @stability stable
     */
    readonly clientId: string;
    /**
     * @stability stable
     */
    readonly clientSecret?: string;
}
/**
 * @stability stable
 */
export interface AppServiceAuthSettingsFacebook {
    /**
     * @stability stable
     */
    readonly appId: string;
    /**
     * @stability stable
     */
    readonly appSecret: string;
    /**
     * @stability stable
     */
    readonly oauthScopes?: string[];
}
/**
 * @stability stable
 */
export interface AppServiceAuthSettingsGoogle {
    /**
     * @stability stable
     */
    readonly clientId: string;
    /**
     * @stability stable
     */
    readonly clientSecret: string;
    /**
     * @stability stable
     */
    readonly oauthScopes?: string[];
}
/**
 * @stability stable
 */
export interface AppServiceAuthSettingsMicrosoft {
    /**
     * @stability stable
     */
    readonly clientId: string;
    /**
     * @stability stable
     */
    readonly clientSecret: string;
    /**
     * @stability stable
     */
    readonly oauthScopes?: string[];
}
/**
 * @stability stable
 */
export interface AppServiceAuthSettingsTwitter {
    /**
     * @stability stable
     */
    readonly consumerKey: string;
    /**
     * @stability stable
     */
    readonly consumerSecret: string;
}
/**
 * @stability stable
 */
export interface AppServiceAuthSettings {
    /**
     * @stability stable
     */
    readonly additionalLoginParams?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly allowedExternalRedirectUrls?: string[];
    /**
     * @stability stable
     */
    readonly defaultProvider?: string;
    /**
     * @stability stable
     */
    readonly enabled: boolean;
    /**
     * @stability stable
     */
    readonly issuer?: string;
    /**
     * @stability stable
     */
    readonly runtimeVersion?: string;
    /**
     * @stability stable
     */
    readonly tokenRefreshExtensionHours?: number;
    /**
     * @stability stable
     */
    readonly tokenStoreEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly unauthenticatedClientAction?: string;
    /**
     * active_directory block.
     *
     * @stability stable
     */
    readonly activeDirectory?: AppServiceAuthSettingsActiveDirectory[];
    /**
     * facebook block.
     *
     * @stability stable
     */
    readonly facebook?: AppServiceAuthSettingsFacebook[];
    /**
     * google block.
     *
     * @stability stable
     */
    readonly google?: AppServiceAuthSettingsGoogle[];
    /**
     * microsoft block.
     *
     * @stability stable
     */
    readonly microsoft?: AppServiceAuthSettingsMicrosoft[];
    /**
     * twitter block.
     *
     * @stability stable
     */
    readonly twitter?: AppServiceAuthSettingsTwitter[];
}
/**
 * @stability stable
 */
export interface AppServiceBackupSchedule {
    /**
     * @stability stable
     */
    readonly frequencyInterval: number;
    /**
     * @stability stable
     */
    readonly frequencyUnit: string;
    /**
     * @stability stable
     */
    readonly keepAtLeastOneBackup?: boolean;
    /**
     * @stability stable
     */
    readonly retentionPeriodInDays?: number;
    /**
     * @stability stable
     */
    readonly startTime?: string;
}
/**
 * @stability stable
 */
export interface AppServiceBackup {
    /**
     * @stability stable
     */
    readonly enabled?: boolean;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly storageAccountUrl: string;
    /**
     * schedule block.
     *
     * @stability stable
     */
    readonly schedule: AppServiceBackupSchedule[];
}
/**
 * @stability stable
 */
export interface AppServiceConnectionString {
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly type: string;
    /**
     * @stability stable
     */
    readonly value: string;
}
/**
 * @stability stable
 */
export interface AppServiceIdentity {
    /**
     * @stability stable
     */
    readonly identityIds?: string[];
    /**
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface AppServiceLogsApplicationLogsAzureBlobStorage {
    /**
     * @stability stable
     */
    readonly level: string;
    /**
     * @stability stable
     */
    readonly retentionInDays: number;
    /**
     * @stability stable
     */
    readonly sasUrl: string;
}
/**
 * @stability stable
 */
export interface AppServiceLogsApplicationLogs {
    /**
     * @stability stable
     */
    readonly fileSystemLevel?: string;
    /**
     * azure_blob_storage block.
     *
     * @stability stable
     */
    readonly azureBlobStorage?: AppServiceLogsApplicationLogsAzureBlobStorage[];
}
/**
 * @stability stable
 */
export interface AppServiceLogsHttpLogsAzureBlobStorage {
    /**
     * @stability stable
     */
    readonly retentionInDays: number;
    /**
     * @stability stable
     */
    readonly sasUrl: string;
}
/**
 * @stability stable
 */
export interface AppServiceLogsHttpLogsFileSystem {
    /**
     * @stability stable
     */
    readonly retentionInDays: number;
    /**
     * @stability stable
     */
    readonly retentionInMb: number;
}
/**
 * @stability stable
 */
export interface AppServiceLogsHttpLogs {
    /**
     * azure_blob_storage block.
     *
     * @stability stable
     */
    readonly azureBlobStorage?: AppServiceLogsHttpLogsAzureBlobStorage[];
    /**
     * file_system block.
     *
     * @stability stable
     */
    readonly fileSystem?: AppServiceLogsHttpLogsFileSystem[];
}
/**
 * @stability stable
 */
export interface AppServiceLogs {
    /**
     * @stability stable
     */
    readonly detailedErrorMessagesEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly failedRequestTracingEnabled?: boolean;
    /**
     * application_logs block.
     *
     * @stability stable
     */
    readonly applicationLogs?: AppServiceLogsApplicationLogs[];
    /**
     * http_logs block.
     *
     * @stability stable
     */
    readonly httpLogs?: AppServiceLogsHttpLogs[];
}
/**
 * @stability stable
 */
export interface AppServiceSiteConfigIpRestriction {
    /**
     * @stability stable
     */
    readonly action?: string;
    /**
     * @stability stable
     */
    readonly ipAddress?: string;
    /**
     * @stability stable
     */
    readonly name?: string;
    /**
     * @stability stable
     */
    readonly priority?: number;
    /**
     * @stability stable
     */
    readonly serviceTag?: string;
    /**
     * @stability stable
     */
    readonly virtualNetworkSubnetId?: string;
}
/**
 * @stability stable
 */
export interface AppServiceSiteConfigScmIpRestriction {
    /**
     * @stability stable
     */
    readonly action?: string;
    /**
     * @stability stable
     */
    readonly ipAddress?: string;
    /**
     * @stability stable
     */
    readonly name?: string;
    /**
     * @stability stable
     */
    readonly priority?: number;
    /**
     * @stability stable
     */
    readonly serviceTag?: string;
    /**
     * @stability stable
     */
    readonly virtualNetworkSubnetId?: string;
}
/**
 * @stability stable
 */
export interface AppServiceSiteConfigCors {
    /**
     * @stability stable
     */
    readonly allowedOrigins: string[];
    /**
     * @stability stable
     */
    readonly supportCredentials?: boolean;
}
/**
 * @stability stable
 */
export interface AppServiceSiteConfig {
    /**
     * @stability stable
     */
    readonly alwaysOn?: boolean;
    /**
     * @stability stable
     */
    readonly appCommandLine?: string;
    /**
     * @stability stable
     */
    readonly autoSwapSlotName?: string;
    /**
     * @stability stable
     */
    readonly defaultDocuments?: string[];
    /**
     * @stability stable
     */
    readonly dotnetFrameworkVersion?: string;
    /**
     * @stability stable
     */
    readonly ftpsState?: string;
    /**
     * @stability stable
     */
    readonly healthCheckPath?: string;
    /**
     * @stability stable
     */
    readonly http2Enabled?: boolean;
    /**
     * @stability stable
     */
    readonly ipRestriction?: AppServiceSiteConfigIpRestriction[];
    /**
     * @stability stable
     */
    readonly javaContainer?: string;
    /**
     * @stability stable
     */
    readonly javaContainerVersion?: string;
    /**
     * @stability stable
     */
    readonly javaVersion?: string;
    /**
     * @stability stable
     */
    readonly linuxFxVersion?: string;
    /**
     * @stability stable
     */
    readonly localMysqlEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly managedPipelineMode?: string;
    /**
     * @stability stable
     */
    readonly minTlsVersion?: string;
    /**
     * @stability stable
     */
    readonly numberOfWorkers?: number;
    /**
     * @stability stable
     */
    readonly phpVersion?: string;
    /**
     * @stability stable
     */
    readonly pythonVersion?: string;
    /**
     * @stability stable
     */
    readonly remoteDebuggingEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly remoteDebuggingVersion?: string;
    /**
     * @stability stable
     */
    readonly scmIpRestriction?: AppServiceSiteConfigScmIpRestriction[];
    /**
     * @stability stable
     */
    readonly scmType?: string;
    /**
     * @stability stable
     */
    readonly scmUseMainIpRestriction?: boolean;
    /**
     * @stability stable
     */
    readonly use32BitWorkerProcess?: boolean;
    /**
     * @stability stable
     */
    readonly websocketsEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly windowsFxVersion?: string;
    /**
     * cors block.
     *
     * @stability stable
     */
    readonly cors?: AppServiceSiteConfigCors[];
}
/**
 * @stability stable
 */
export interface AppServiceSourceControl {
    /**
     * @stability stable
     */
    readonly branch?: string;
    /**
     * @stability stable
     */
    readonly manualIntegration?: boolean;
    /**
     * @stability stable
     */
    readonly repoUrl?: string;
    /**
     * @stability stable
     */
    readonly rollbackEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly useMercurial?: boolean;
}
/**
 * @stability stable
 */
export interface AppServiceStorageAccount {
    /**
     * @stability stable
     */
    readonly accessKey: string;
    /**
     * @stability stable
     */
    readonly accountName: string;
    /**
     * @stability stable
     */
    readonly mountPath?: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly shareName: string;
    /**
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface AppServiceTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class AppService extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: AppServiceConfig);
    private _appServicePlanId;
    /**
     * @stability stable
     */
    get appServicePlanId(): string;
    /**
     * @stability stable
     */
    set appServicePlanId(value: string);
    /**
     * @stability stable
     */
    get appServicePlanIdInput(): string;
    private _appSettings?;
    /**
     * @stability stable
     */
    get appSettings(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set appSettings(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetAppSettings(): void;
    /**
     * @stability stable
     */
    get appSettingsInput(): {
        [key: string]: string;
    } | undefined;
    private _clientAffinityEnabled?;
    /**
     * @stability stable
     */
    get clientAffinityEnabled(): boolean;
    /**
     * @stability stable
     */
    set clientAffinityEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetClientAffinityEnabled(): void;
    /**
     * @stability stable
     */
    get clientAffinityEnabledInput(): boolean | undefined;
    private _clientCertEnabled?;
    /**
     * @stability stable
     */
    get clientCertEnabled(): boolean;
    /**
     * @stability stable
     */
    set clientCertEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetClientCertEnabled(): void;
    /**
     * @stability stable
     */
    get clientCertEnabledInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get customDomainVerificationId(): string;
    /**
     * @stability stable
     */
    get defaultSiteHostname(): string;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean;
    /**
     * @stability stable
     */
    set enabled(value: boolean);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | undefined;
    private _httpsOnly?;
    /**
     * @stability stable
     */
    get httpsOnly(): boolean;
    /**
     * @stability stable
     */
    set httpsOnly(value: boolean);
    /**
     * @stability stable
     */
    resetHttpsOnly(): void;
    /**
     * @stability stable
     */
    get httpsOnlyInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    /**
     * @stability stable
     */
    get outboundIpAddressList(): string[];
    /**
     * @stability stable
     */
    get outboundIpAddresses(): string;
    /**
     * @stability stable
     */
    get possibleOutboundIpAddressList(): string[];
    /**
     * @stability stable
     */
    get possibleOutboundIpAddresses(): string;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    /**
     * @stability stable
     */
    siteCredential(index: string): AppServiceSiteCredential;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _authSettings?;
    /**
     * @stability stable
     */
    get authSettings(): AppServiceAuthSettings[];
    /**
     * @stability stable
     */
    set authSettings(value: AppServiceAuthSettings[]);
    /**
     * @stability stable
     */
    resetAuthSettings(): void;
    /**
     * @stability stable
     */
    get authSettingsInput(): AppServiceAuthSettings[] | undefined;
    private _backup?;
    /**
     * @stability stable
     */
    get backup(): AppServiceBackup[];
    /**
     * @stability stable
     */
    set backup(value: AppServiceBackup[]);
    /**
     * @stability stable
     */
    resetBackup(): void;
    /**
     * @stability stable
     */
    get backupInput(): AppServiceBackup[] | undefined;
    private _connectionString?;
    /**
     * @stability stable
     */
    get connectionString(): AppServiceConnectionString[];
    /**
     * @stability stable
     */
    set connectionString(value: AppServiceConnectionString[]);
    /**
     * @stability stable
     */
    resetConnectionString(): void;
    /**
     * @stability stable
     */
    get connectionStringInput(): AppServiceConnectionString[] | undefined;
    private _identity?;
    /**
     * @stability stable
     */
    get identity(): AppServiceIdentity[];
    /**
     * @stability stable
     */
    set identity(value: AppServiceIdentity[]);
    /**
     * @stability stable
     */
    resetIdentity(): void;
    /**
     * @stability stable
     */
    get identityInput(): AppServiceIdentity[] | undefined;
    private _logs?;
    /**
     * @stability stable
     */
    get logs(): AppServiceLogs[];
    /**
     * @stability stable
     */
    set logs(value: AppServiceLogs[]);
    /**
     * @stability stable
     */
    resetLogs(): void;
    /**
     * @stability stable
     */
    get logsInput(): AppServiceLogs[] | undefined;
    private _siteConfig?;
    /**
     * @stability stable
     */
    get siteConfig(): AppServiceSiteConfig[];
    /**
     * @stability stable
     */
    set siteConfig(value: AppServiceSiteConfig[]);
    /**
     * @stability stable
     */
    resetSiteConfig(): void;
    /**
     * @stability stable
     */
    get siteConfigInput(): AppServiceSiteConfig[] | undefined;
    private _sourceControl?;
    /**
     * @stability stable
     */
    get sourceControl(): AppServiceSourceControl[];
    /**
     * @stability stable
     */
    set sourceControl(value: AppServiceSourceControl[]);
    /**
     * @stability stable
     */
    resetSourceControl(): void;
    /**
     * @stability stable
     */
    get sourceControlInput(): AppServiceSourceControl[] | undefined;
    private _storageAccount?;
    /**
     * @stability stable
     */
    get storageAccount(): AppServiceStorageAccount[];
    /**
     * @stability stable
     */
    set storageAccount(value: AppServiceStorageAccount[]);
    /**
     * @stability stable
     */
    resetStorageAccount(): void;
    /**
     * @stability stable
     */
    get storageAccountInput(): AppServiceStorageAccount[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): AppServiceTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: AppServiceTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): AppServiceTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
