import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface AzurermProviderConfig {
    /**
     * @stability stable
     */
    readonly auxiliaryTenantIds?: string[];
    /**
     * The password associated with the Client Certificate.
     *
     * For use when authenticating as a Service Principal using a Client Certificate
     *
     * @stability stable
     */
    readonly clientCertificatePassword?: string;
    /**
     * The path to the Client Certificate associated with the Service Principal for use when authenticating as a Service Principal using a Client Certificate.
     *
     * @stability stable
     */
    readonly clientCertificatePath?: string;
    /**
     * The Client ID which should be used.
     *
     * @stability stable
     */
    readonly clientId?: string;
    /**
     * The Client Secret which should be used.
     *
     * For use When authenticating as a Service Principal using a Client Secret.
     *
     * @stability stable
     */
    readonly clientSecret?: string;
    /**
     * This will disable the x-ms-correlation-request-id header.
     *
     * @stability stable
     */
    readonly disableCorrelationRequestId?: boolean;
    /**
     * This will disable the Terraform Partner ID which is used if a custom `partner_id` isn't specified.
     *
     * @stability stable
     */
    readonly disableTerraformPartnerId?: boolean;
    /**
     * The Cloud Environment which should be used.
     *
     * Possible values are public, usgovernment, german, and china. Defaults to public.
     *
     * @stability stable
     */
    readonly environment?: string;
    /**
     * The Hostname which should be used for the Azure Metadata Service.
     *
     * @stability stable
     */
    readonly metadataHost?: string;
    /**
     * Deprecated - replaced by `metadata_host`.
     *
     * @stability stable
     */
    readonly metadataUrl?: string;
    /**
     * The path to a custom endpoint for Managed Service Identity - in most circumstances this should be detected automatically.
     *
     * @stability stable
     */
    readonly msiEndpoint?: string;
    /**
     * A GUID/UUID that is registered with Microsoft to facilitate partner resource usage attribution.
     *
     * @stability stable
     */
    readonly partnerId?: string;
    /**
     * [DEPRECATED] This will cause the AzureRM Provider to skip verifying the credentials being used are valid.
     *
     * @stability stable
     */
    readonly skipCredentialsValidation?: boolean;
    /**
     * Should the AzureRM Provider skip registering all of the Resource Providers that it supports, if they're not already registered?
     *
     * @stability stable
     */
    readonly skipProviderRegistration?: boolean;
    /**
     * Should the AzureRM Provider use AzureAD to access the Storage Data Plane API's?
     *
     * @stability stable
     */
    readonly storageUseAzuread?: boolean;
    /**
     * The Subscription ID which should be used.
     *
     * @stability stable
     */
    readonly subscriptionId?: string;
    /**
     * The Tenant ID which should be used.
     *
     * @stability stable
     */
    readonly tenantId?: string;
    /**
     * Allowed Managed Service Identity be used for Authentication.
     *
     * @stability stable
     */
    readonly useMsi?: boolean;
    /**
     * Alias name.
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * features block.
     *
     * @stability stable
     */
    readonly features: AzurermProviderFeatures[];
}
/**
 * @stability stable
 */
export interface AzurermProviderFeaturesKeyVault {
    /**
     * @stability stable
     */
    readonly purgeSoftDeleteOnDestroy?: boolean;
    /**
     * @stability stable
     */
    readonly recoverSoftDeletedKeyVaults?: boolean;
}
/**
 * @stability stable
 */
export interface AzurermProviderFeaturesLogAnalyticsWorkspace {
    /**
     * @stability stable
     */
    readonly permanentlyDeleteOnDestroy: boolean;
}
/**
 * @stability stable
 */
export interface AzurermProviderFeaturesNetwork {
    /**
     * @stability stable
     */
    readonly relaxedLocking: boolean;
}
/**
 * @stability stable
 */
export interface AzurermProviderFeaturesTemplateDeployment {
    /**
     * @stability stable
     */
    readonly deleteNestedItemsDuringDeletion: boolean;
}
/**
 * @stability stable
 */
export interface AzurermProviderFeaturesVirtualMachine {
    /**
     * @stability stable
     */
    readonly deleteOsDiskOnDeletion?: boolean;
    /**
     * @stability stable
     */
    readonly gracefulShutdown?: boolean;
}
/**
 * @stability stable
 */
export interface AzurermProviderFeaturesVirtualMachineScaleSet {
    /**
     * @stability stable
     */
    readonly rollInstancesWhenRequired: boolean;
}
/**
 * @stability stable
 */
export interface AzurermProviderFeatures {
    /**
     * key_vault block.
     *
     * @stability stable
     */
    readonly keyVault?: AzurermProviderFeaturesKeyVault[];
    /**
     * log_analytics_workspace block.
     *
     * @stability stable
     */
    readonly logAnalyticsWorkspace?: AzurermProviderFeaturesLogAnalyticsWorkspace[];
    /**
     * network block.
     *
     * @stability stable
     */
    readonly network?: AzurermProviderFeaturesNetwork[];
    /**
     * template_deployment block.
     *
     * @stability stable
     */
    readonly templateDeployment?: AzurermProviderFeaturesTemplateDeployment[];
    /**
     * virtual_machine block.
     *
     * @stability stable
     */
    readonly virtualMachine?: AzurermProviderFeaturesVirtualMachine[];
    /**
     * virtual_machine_scale_set block.
     *
     * @stability stable
     */
    readonly virtualMachineScaleSet?: AzurermProviderFeaturesVirtualMachineScaleSet[];
}
/**
 * @stability stable
 */
export declare class AzurermProvider extends cdktf.TerraformProvider {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: AzurermProviderConfig);
    private _auxiliaryTenantIds?;
    /**
     * @stability stable
     */
    get auxiliaryTenantIds(): string[] | undefined;
    /**
     * @stability stable
     */
    set auxiliaryTenantIds(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetAuxiliaryTenantIds(): void;
    /**
     * @stability stable
     */
    get auxiliaryTenantIdsInput(): string[] | undefined;
    private _clientCertificatePassword?;
    /**
     * @stability stable
     */
    get clientCertificatePassword(): string | undefined;
    /**
     * @stability stable
     */
    set clientCertificatePassword(value: string | undefined);
    /**
     * @stability stable
     */
    resetClientCertificatePassword(): void;
    /**
     * @stability stable
     */
    get clientCertificatePasswordInput(): string | undefined;
    private _clientCertificatePath?;
    /**
     * @stability stable
     */
    get clientCertificatePath(): string | undefined;
    /**
     * @stability stable
     */
    set clientCertificatePath(value: string | undefined);
    /**
     * @stability stable
     */
    resetClientCertificatePath(): void;
    /**
     * @stability stable
     */
    get clientCertificatePathInput(): string | undefined;
    private _clientId?;
    /**
     * @stability stable
     */
    get clientId(): string | undefined;
    /**
     * @stability stable
     */
    set clientId(value: string | undefined);
    /**
     * @stability stable
     */
    resetClientId(): void;
    /**
     * @stability stable
     */
    get clientIdInput(): string | undefined;
    private _clientSecret?;
    /**
     * @stability stable
     */
    get clientSecret(): string | undefined;
    /**
     * @stability stable
     */
    set clientSecret(value: string | undefined);
    /**
     * @stability stable
     */
    resetClientSecret(): void;
    /**
     * @stability stable
     */
    get clientSecretInput(): string | undefined;
    private _disableCorrelationRequestId?;
    /**
     * @stability stable
     */
    get disableCorrelationRequestId(): boolean | undefined;
    /**
     * @stability stable
     */
    set disableCorrelationRequestId(value: boolean | undefined);
    /**
     * @stability stable
     */
    resetDisableCorrelationRequestId(): void;
    /**
     * @stability stable
     */
    get disableCorrelationRequestIdInput(): boolean | undefined;
    private _disableTerraformPartnerId?;
    /**
     * @stability stable
     */
    get disableTerraformPartnerId(): boolean | undefined;
    /**
     * @stability stable
     */
    set disableTerraformPartnerId(value: boolean | undefined);
    /**
     * @stability stable
     */
    resetDisableTerraformPartnerId(): void;
    /**
     * @stability stable
     */
    get disableTerraformPartnerIdInput(): boolean | undefined;
    private _environment?;
    /**
     * @stability stable
     */
    get environment(): string | undefined;
    /**
     * @stability stable
     */
    set environment(value: string | undefined);
    /**
     * @stability stable
     */
    resetEnvironment(): void;
    /**
     * @stability stable
     */
    get environmentInput(): string | undefined;
    private _metadataHost?;
    /**
     * @stability stable
     */
    get metadataHost(): string | undefined;
    /**
     * @stability stable
     */
    set metadataHost(value: string | undefined);
    /**
     * @stability stable
     */
    resetMetadataHost(): void;
    /**
     * @stability stable
     */
    get metadataHostInput(): string | undefined;
    private _metadataUrl?;
    /**
     * @stability stable
     */
    get metadataUrl(): string | undefined;
    /**
     * @stability stable
     */
    set metadataUrl(value: string | undefined);
    /**
     * @stability stable
     */
    resetMetadataUrl(): void;
    /**
     * @stability stable
     */
    get metadataUrlInput(): string | undefined;
    private _msiEndpoint?;
    /**
     * @stability stable
     */
    get msiEndpoint(): string | undefined;
    /**
     * @stability stable
     */
    set msiEndpoint(value: string | undefined);
    /**
     * @stability stable
     */
    resetMsiEndpoint(): void;
    /**
     * @stability stable
     */
    get msiEndpointInput(): string | undefined;
    private _partnerId?;
    /**
     * @stability stable
     */
    get partnerId(): string | undefined;
    /**
     * @stability stable
     */
    set partnerId(value: string | undefined);
    /**
     * @stability stable
     */
    resetPartnerId(): void;
    /**
     * @stability stable
     */
    get partnerIdInput(): string | undefined;
    private _skipCredentialsValidation?;
    /**
     * @stability stable
     */
    get skipCredentialsValidation(): boolean | undefined;
    /**
     * @stability stable
     */
    set skipCredentialsValidation(value: boolean | undefined);
    /**
     * @stability stable
     */
    resetSkipCredentialsValidation(): void;
    /**
     * @stability stable
     */
    get skipCredentialsValidationInput(): boolean | undefined;
    private _skipProviderRegistration?;
    /**
     * @stability stable
     */
    get skipProviderRegistration(): boolean | undefined;
    /**
     * @stability stable
     */
    set skipProviderRegistration(value: boolean | undefined);
    /**
     * @stability stable
     */
    resetSkipProviderRegistration(): void;
    /**
     * @stability stable
     */
    get skipProviderRegistrationInput(): boolean | undefined;
    private _storageUseAzuread?;
    /**
     * @stability stable
     */
    get storageUseAzuread(): boolean | undefined;
    /**
     * @stability stable
     */
    set storageUseAzuread(value: boolean | undefined);
    /**
     * @stability stable
     */
    resetStorageUseAzuread(): void;
    /**
     * @stability stable
     */
    get storageUseAzureadInput(): boolean | undefined;
    private _subscriptionId?;
    /**
     * @stability stable
     */
    get subscriptionId(): string | undefined;
    /**
     * @stability stable
     */
    set subscriptionId(value: string | undefined);
    /**
     * @stability stable
     */
    resetSubscriptionId(): void;
    /**
     * @stability stable
     */
    get subscriptionIdInput(): string | undefined;
    private _tenantId?;
    /**
     * @stability stable
     */
    get tenantId(): string | undefined;
    /**
     * @stability stable
     */
    set tenantId(value: string | undefined);
    /**
     * @stability stable
     */
    resetTenantId(): void;
    /**
     * @stability stable
     */
    get tenantIdInput(): string | undefined;
    private _useMsi?;
    /**
     * @stability stable
     */
    get useMsi(): boolean | undefined;
    /**
     * @stability stable
     */
    set useMsi(value: boolean | undefined);
    /**
     * @stability stable
     */
    resetUseMsi(): void;
    /**
     * @stability stable
     */
    get useMsiInput(): boolean | undefined;
    private _alias?;
    /**
     * @stability stable
     */
    get alias(): string | undefined;
    /**
     * @stability stable
     */
    set alias(value: string | undefined);
    /**
     * @stability stable
     */
    resetAlias(): void;
    /**
     * @stability stable
     */
    get aliasInput(): string | undefined;
    private _features;
    /**
     * @stability stable
     */
    get features(): AzurermProviderFeatures[];
    /**
     * @stability stable
     */
    set features(value: AzurermProviderFeatures[]);
    /**
     * @stability stable
     */
    get featuresInput(): AzurermProviderFeatures[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
