import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface CosmosdbAccountConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly analyticalStorageEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly enableAutomaticFailover?: boolean;
    /**
     * @stability stable
     */
    readonly enableFreeTier?: boolean;
    /**
     * @stability stable
     */
    readonly enableMultipleWriteLocations?: boolean;
    /**
     * @stability stable
     */
    readonly ipRangeFilter?: string;
    /**
     * @stability stable
     */
    readonly isVirtualNetworkFilterEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly keyVaultKeyId?: string;
    /**
     * @stability stable
     */
    readonly kind?: string;
    /**
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly offerType: string;
    /**
     * @stability stable
     */
    readonly publicNetworkAccessEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * capabilities block.
     *
     * @stability stable
     */
    readonly capabilities?: CosmosdbAccountCapabilities[];
    /**
     * consistency_policy block.
     *
     * @stability stable
     */
    readonly consistencyPolicy: CosmosdbAccountConsistencyPolicy[];
    /**
     * geo_location block.
     *
     * @stability stable
     */
    readonly geoLocation: CosmosdbAccountGeoLocation[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: CosmosdbAccountTimeouts;
    /**
     * virtual_network_rule block.
     *
     * @stability stable
     */
    readonly virtualNetworkRule?: CosmosdbAccountVirtualNetworkRule[];
}
/**
 * @stability stable
 */
export interface CosmosdbAccountCapabilities {
    /**
     * @stability stable
     */
    readonly name: string;
}
/**
 * @stability stable
 */
export interface CosmosdbAccountConsistencyPolicy {
    /**
     * @stability stable
     */
    readonly consistencyLevel: string;
    /**
     * @stability stable
     */
    readonly maxIntervalInSeconds?: number;
    /**
     * @stability stable
     */
    readonly maxStalenessPrefix?: number;
}
/**
 * @stability stable
 */
export interface CosmosdbAccountGeoLocation {
    /**
     * @stability stable
     */
    readonly failoverPriority: number;
    /**
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly prefix?: string;
    /**
     * @stability stable
     */
    readonly zoneRedundant?: boolean;
}
/**
 * @stability stable
 */
export interface CosmosdbAccountTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export interface CosmosdbAccountVirtualNetworkRule {
    /**
     * @stability stable
     */
    readonly id: string;
    /**
     * @stability stable
     */
    readonly ignoreMissingVnetServiceEndpoint?: boolean;
}
/**
 * @stability stable
 */
export declare class CosmosdbAccount extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CosmosdbAccountConfig);
    private _analyticalStorageEnabled?;
    /**
     * @stability stable
     */
    get analyticalStorageEnabled(): boolean;
    /**
     * @stability stable
     */
    set analyticalStorageEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetAnalyticalStorageEnabled(): void;
    /**
     * @stability stable
     */
    get analyticalStorageEnabledInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get connectionStrings(): string[];
    private _enableAutomaticFailover?;
    /**
     * @stability stable
     */
    get enableAutomaticFailover(): boolean;
    /**
     * @stability stable
     */
    set enableAutomaticFailover(value: boolean);
    /**
     * @stability stable
     */
    resetEnableAutomaticFailover(): void;
    /**
     * @stability stable
     */
    get enableAutomaticFailoverInput(): boolean | undefined;
    private _enableFreeTier?;
    /**
     * @stability stable
     */
    get enableFreeTier(): boolean;
    /**
     * @stability stable
     */
    set enableFreeTier(value: boolean);
    /**
     * @stability stable
     */
    resetEnableFreeTier(): void;
    /**
     * @stability stable
     */
    get enableFreeTierInput(): boolean | undefined;
    private _enableMultipleWriteLocations?;
    /**
     * @stability stable
     */
    get enableMultipleWriteLocations(): boolean;
    /**
     * @stability stable
     */
    set enableMultipleWriteLocations(value: boolean);
    /**
     * @stability stable
     */
    resetEnableMultipleWriteLocations(): void;
    /**
     * @stability stable
     */
    get enableMultipleWriteLocationsInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get endpoint(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _ipRangeFilter?;
    /**
     * @stability stable
     */
    get ipRangeFilter(): string;
    /**
     * @stability stable
     */
    set ipRangeFilter(value: string);
    /**
     * @stability stable
     */
    resetIpRangeFilter(): void;
    /**
     * @stability stable
     */
    get ipRangeFilterInput(): string | undefined;
    private _isVirtualNetworkFilterEnabled?;
    /**
     * @stability stable
     */
    get isVirtualNetworkFilterEnabled(): boolean;
    /**
     * @stability stable
     */
    set isVirtualNetworkFilterEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetIsVirtualNetworkFilterEnabled(): void;
    /**
     * @stability stable
     */
    get isVirtualNetworkFilterEnabledInput(): boolean | undefined;
    private _keyVaultKeyId?;
    /**
     * @stability stable
     */
    get keyVaultKeyId(): string;
    /**
     * @stability stable
     */
    set keyVaultKeyId(value: string);
    /**
     * @stability stable
     */
    resetKeyVaultKeyId(): void;
    /**
     * @stability stable
     */
    get keyVaultKeyIdInput(): string | undefined;
    private _kind?;
    /**
     * @stability stable
     */
    get kind(): string;
    /**
     * @stability stable
     */
    set kind(value: string);
    /**
     * @stability stable
     */
    resetKind(): void;
    /**
     * @stability stable
     */
    get kindInput(): string | undefined;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _offerType;
    /**
     * @stability stable
     */
    get offerType(): string;
    /**
     * @stability stable
     */
    set offerType(value: string);
    /**
     * @stability stable
     */
    get offerTypeInput(): string;
    /**
     * @stability stable
     */
    get primaryKey(): string;
    /**
     * @stability stable
     */
    get primaryMasterKey(): string;
    /**
     * @stability stable
     */
    get primaryReadonlyKey(): string;
    /**
     * @stability stable
     */
    get primaryReadonlyMasterKey(): string;
    private _publicNetworkAccessEnabled?;
    /**
     * @stability stable
     */
    get publicNetworkAccessEnabled(): boolean;
    /**
     * @stability stable
     */
    set publicNetworkAccessEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetPublicNetworkAccessEnabled(): void;
    /**
     * @stability stable
     */
    get publicNetworkAccessEnabledInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get readEndpoints(): string[];
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    /**
     * @stability stable
     */
    get secondaryKey(): string;
    /**
     * @stability stable
     */
    get secondaryMasterKey(): string;
    /**
     * @stability stable
     */
    get secondaryReadonlyKey(): string;
    /**
     * @stability stable
     */
    get secondaryReadonlyMasterKey(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get writeEndpoints(): string[];
    private _capabilities?;
    /**
     * @stability stable
     */
    get capabilities(): CosmosdbAccountCapabilities[];
    /**
     * @stability stable
     */
    set capabilities(value: CosmosdbAccountCapabilities[]);
    /**
     * @stability stable
     */
    resetCapabilities(): void;
    /**
     * @stability stable
     */
    get capabilitiesInput(): CosmosdbAccountCapabilities[] | undefined;
    private _consistencyPolicy;
    /**
     * @stability stable
     */
    get consistencyPolicy(): CosmosdbAccountConsistencyPolicy[];
    /**
     * @stability stable
     */
    set consistencyPolicy(value: CosmosdbAccountConsistencyPolicy[]);
    /**
     * @stability stable
     */
    get consistencyPolicyInput(): CosmosdbAccountConsistencyPolicy[];
    private _geoLocation;
    /**
     * @stability stable
     */
    get geoLocation(): CosmosdbAccountGeoLocation[];
    /**
     * @stability stable
     */
    set geoLocation(value: CosmosdbAccountGeoLocation[]);
    /**
     * @stability stable
     */
    get geoLocationInput(): CosmosdbAccountGeoLocation[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): CosmosdbAccountTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: CosmosdbAccountTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): CosmosdbAccountTimeouts | undefined;
    private _virtualNetworkRule?;
    /**
     * @stability stable
     */
    get virtualNetworkRule(): CosmosdbAccountVirtualNetworkRule[];
    /**
     * @stability stable
     */
    set virtualNetworkRule(value: CosmosdbAccountVirtualNetworkRule[]);
    /**
     * @stability stable
     */
    resetVirtualNetworkRule(): void;
    /**
     * @stability stable
     */
    get virtualNetworkRuleInput(): CosmosdbAccountVirtualNetworkRule[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
