import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface CosmosdbSqlContainerConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly accountName: string;
    /**
     * @stability stable
     */
    readonly databaseName: string;
    /**
     * @stability stable
     */
    readonly defaultTtl?: number;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly partitionKeyPath?: string;
    /**
     * @stability stable
     */
    readonly partitionKeyVersion?: number;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly throughput?: number;
    /**
     * autoscale_settings block.
     *
     * @stability stable
     */
    readonly autoscaleSettings?: CosmosdbSqlContainerAutoscaleSettings[];
    /**
     * indexing_policy block.
     *
     * @stability stable
     */
    readonly indexingPolicy?: CosmosdbSqlContainerIndexingPolicy[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: CosmosdbSqlContainerTimeouts;
    /**
     * unique_key block.
     *
     * @stability stable
     */
    readonly uniqueKey?: CosmosdbSqlContainerUniqueKey[];
}
/**
 * @stability stable
 */
export interface CosmosdbSqlContainerAutoscaleSettings {
    /**
     * @stability stable
     */
    readonly maxThroughput?: number;
}
/**
 * @stability stable
 */
export interface CosmosdbSqlContainerIndexingPolicyCompositeIndexIndex {
    /**
     * @stability stable
     */
    readonly order: string;
    /**
     * @stability stable
     */
    readonly path: string;
}
/**
 * @stability stable
 */
export interface CosmosdbSqlContainerIndexingPolicyCompositeIndex {
    /**
     * index block.
     *
     * @stability stable
     */
    readonly index: CosmosdbSqlContainerIndexingPolicyCompositeIndexIndex[];
}
/**
 * @stability stable
 */
export interface CosmosdbSqlContainerIndexingPolicyExcludedPath {
    /**
     * @stability stable
     */
    readonly path: string;
}
/**
 * @stability stable
 */
export interface CosmosdbSqlContainerIndexingPolicyIncludedPath {
    /**
     * @stability stable
     */
    readonly path: string;
}
/**
 * @stability stable
 */
export interface CosmosdbSqlContainerIndexingPolicy {
    /**
     * @stability stable
     */
    readonly indexingMode?: string;
    /**
     * composite_index block.
     *
     * @stability stable
     */
    readonly compositeIndex?: CosmosdbSqlContainerIndexingPolicyCompositeIndex[];
    /**
     * excluded_path block.
     *
     * @stability stable
     */
    readonly excludedPath?: CosmosdbSqlContainerIndexingPolicyExcludedPath[];
    /**
     * included_path block.
     *
     * @stability stable
     */
    readonly includedPath?: CosmosdbSqlContainerIndexingPolicyIncludedPath[];
}
/**
 * @stability stable
 */
export interface CosmosdbSqlContainerTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export interface CosmosdbSqlContainerUniqueKey {
    /**
     * @stability stable
     */
    readonly paths: string[];
}
/**
 * @stability stable
 */
export declare class CosmosdbSqlContainer extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CosmosdbSqlContainerConfig);
    private _accountName;
    /**
     * @stability stable
     */
    get accountName(): string;
    /**
     * @stability stable
     */
    set accountName(value: string);
    /**
     * @stability stable
     */
    get accountNameInput(): string;
    private _databaseName;
    /**
     * @stability stable
     */
    get databaseName(): string;
    /**
     * @stability stable
     */
    set databaseName(value: string);
    /**
     * @stability stable
     */
    get databaseNameInput(): string;
    private _defaultTtl?;
    /**
     * @stability stable
     */
    get defaultTtl(): number;
    /**
     * @stability stable
     */
    set defaultTtl(value: number);
    /**
     * @stability stable
     */
    resetDefaultTtl(): void;
    /**
     * @stability stable
     */
    get defaultTtlInput(): number | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _partitionKeyPath?;
    /**
     * @stability stable
     */
    get partitionKeyPath(): string;
    /**
     * @stability stable
     */
    set partitionKeyPath(value: string);
    /**
     * @stability stable
     */
    resetPartitionKeyPath(): void;
    /**
     * @stability stable
     */
    get partitionKeyPathInput(): string | undefined;
    private _partitionKeyVersion?;
    /**
     * @stability stable
     */
    get partitionKeyVersion(): number;
    /**
     * @stability stable
     */
    set partitionKeyVersion(value: number);
    /**
     * @stability stable
     */
    resetPartitionKeyVersion(): void;
    /**
     * @stability stable
     */
    get partitionKeyVersionInput(): number | undefined;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    private _throughput?;
    /**
     * @stability stable
     */
    get throughput(): number;
    /**
     * @stability stable
     */
    set throughput(value: number);
    /**
     * @stability stable
     */
    resetThroughput(): void;
    /**
     * @stability stable
     */
    get throughputInput(): number | undefined;
    private _autoscaleSettings?;
    /**
     * @stability stable
     */
    get autoscaleSettings(): CosmosdbSqlContainerAutoscaleSettings[];
    /**
     * @stability stable
     */
    set autoscaleSettings(value: CosmosdbSqlContainerAutoscaleSettings[]);
    /**
     * @stability stable
     */
    resetAutoscaleSettings(): void;
    /**
     * @stability stable
     */
    get autoscaleSettingsInput(): CosmosdbSqlContainerAutoscaleSettings[] | undefined;
    private _indexingPolicy?;
    /**
     * @stability stable
     */
    get indexingPolicy(): CosmosdbSqlContainerIndexingPolicy[];
    /**
     * @stability stable
     */
    set indexingPolicy(value: CosmosdbSqlContainerIndexingPolicy[]);
    /**
     * @stability stable
     */
    resetIndexingPolicy(): void;
    /**
     * @stability stable
     */
    get indexingPolicyInput(): CosmosdbSqlContainerIndexingPolicy[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): CosmosdbSqlContainerTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: CosmosdbSqlContainerTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): CosmosdbSqlContainerTimeouts | undefined;
    private _uniqueKey?;
    /**
     * @stability stable
     */
    get uniqueKey(): CosmosdbSqlContainerUniqueKey[];
    /**
     * @stability stable
     */
    set uniqueKey(value: CosmosdbSqlContainerUniqueKey[]);
    /**
     * @stability stable
     */
    resetUniqueKey(): void;
    /**
     * @stability stable
     */
    get uniqueKeyInput(): CosmosdbSqlContainerUniqueKey[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
