import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataFactoryConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly publicNetworkEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * github_configuration block.
     *
     * @stability stable
     */
    readonly githubConfiguration?: DataFactoryGithubConfiguration[];
    /**
     * identity block.
     *
     * @stability stable
     */
    readonly identity?: DataFactoryIdentity[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: DataFactoryTimeouts;
    /**
     * vsts_configuration block.
     *
     * @stability stable
     */
    readonly vstsConfiguration?: DataFactoryVstsConfiguration[];
}
/**
 * @stability stable
 */
export interface DataFactoryGithubConfiguration {
    /**
     * @stability stable
     */
    readonly accountName: string;
    /**
     * @stability stable
     */
    readonly branchName: string;
    /**
     * @stability stable
     */
    readonly gitUrl: string;
    /**
     * @stability stable
     */
    readonly repositoryName: string;
    /**
     * @stability stable
     */
    readonly rootFolder: string;
}
/**
 * @stability stable
 */
export interface DataFactoryIdentity {
    /**
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface DataFactoryTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export interface DataFactoryVstsConfiguration {
    /**
     * @stability stable
     */
    readonly accountName: string;
    /**
     * @stability stable
     */
    readonly branchName: string;
    /**
     * @stability stable
     */
    readonly projectName: string;
    /**
     * @stability stable
     */
    readonly repositoryName: string;
    /**
     * @stability stable
     */
    readonly rootFolder: string;
    /**
     * @stability stable
     */
    readonly tenantId: string;
}
/**
 * @stability stable
 */
export declare class DataFactory extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataFactoryConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _publicNetworkEnabled?;
    /**
     * @stability stable
     */
    get publicNetworkEnabled(): boolean;
    /**
     * @stability stable
     */
    set publicNetworkEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetPublicNetworkEnabled(): void;
    /**
     * @stability stable
     */
    get publicNetworkEnabledInput(): boolean | undefined;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _githubConfiguration?;
    /**
     * @stability stable
     */
    get githubConfiguration(): DataFactoryGithubConfiguration[];
    /**
     * @stability stable
     */
    set githubConfiguration(value: DataFactoryGithubConfiguration[]);
    /**
     * @stability stable
     */
    resetGithubConfiguration(): void;
    /**
     * @stability stable
     */
    get githubConfigurationInput(): DataFactoryGithubConfiguration[] | undefined;
    private _identity?;
    /**
     * @stability stable
     */
    get identity(): DataFactoryIdentity[];
    /**
     * @stability stable
     */
    set identity(value: DataFactoryIdentity[]);
    /**
     * @stability stable
     */
    resetIdentity(): void;
    /**
     * @stability stable
     */
    get identityInput(): DataFactoryIdentity[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): DataFactoryTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: DataFactoryTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DataFactoryTimeouts | undefined;
    private _vstsConfiguration?;
    /**
     * @stability stable
     */
    get vstsConfiguration(): DataFactoryVstsConfiguration[];
    /**
     * @stability stable
     */
    set vstsConfiguration(value: DataFactoryVstsConfiguration[]);
    /**
     * @stability stable
     */
    resetVstsConfiguration(): void;
    /**
     * @stability stable
     */
    get vstsConfigurationInput(): DataFactoryVstsConfiguration[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
