import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DevTestScheduleConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly labName: string;
    /**
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly status?: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly taskType: string;
    /**
     * @stability stable
     */
    readonly timeZoneId: string;
    /**
     * daily_recurrence block.
     *
     * @stability stable
     */
    readonly dailyRecurrence?: DevTestScheduleDailyRecurrence[];
    /**
     * hourly_recurrence block.
     *
     * @stability stable
     */
    readonly hourlyRecurrence?: DevTestScheduleHourlyRecurrence[];
    /**
     * notification_settings block.
     *
     * @stability stable
     */
    readonly notificationSettings: DevTestScheduleNotificationSettings[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: DevTestScheduleTimeouts;
    /**
     * weekly_recurrence block.
     *
     * @stability stable
     */
    readonly weeklyRecurrence?: DevTestScheduleWeeklyRecurrence[];
}
/**
 * @stability stable
 */
export interface DevTestScheduleDailyRecurrence {
    /**
     * @stability stable
     */
    readonly time: string;
}
/**
 * @stability stable
 */
export interface DevTestScheduleHourlyRecurrence {
    /**
     * @stability stable
     */
    readonly minute: number;
}
/**
 * @stability stable
 */
export interface DevTestScheduleNotificationSettings {
    /**
     * @stability stable
     */
    readonly status?: string;
    /**
     * @stability stable
     */
    readonly timeInMinutes?: number;
    /**
     * @stability stable
     */
    readonly webhookUrl?: string;
}
/**
 * @stability stable
 */
export interface DevTestScheduleTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export interface DevTestScheduleWeeklyRecurrence {
    /**
     * @stability stable
     */
    readonly time: string;
    /**
     * @stability stable
     */
    readonly weekDays?: string[];
}
/**
 * @stability stable
 */
export declare class DevTestSchedule extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DevTestScheduleConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _labName;
    /**
     * @stability stable
     */
    get labName(): string;
    /**
     * @stability stable
     */
    set labName(value: string);
    /**
     * @stability stable
     */
    get labNameInput(): string;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    private _status?;
    /**
     * @stability stable
     */
    get status(): string;
    /**
     * @stability stable
     */
    set status(value: string);
    /**
     * @stability stable
     */
    resetStatus(): void;
    /**
     * @stability stable
     */
    get statusInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _taskType;
    /**
     * @stability stable
     */
    get taskType(): string;
    /**
     * @stability stable
     */
    set taskType(value: string);
    /**
     * @stability stable
     */
    get taskTypeInput(): string;
    private _timeZoneId;
    /**
     * @stability stable
     */
    get timeZoneId(): string;
    /**
     * @stability stable
     */
    set timeZoneId(value: string);
    /**
     * @stability stable
     */
    get timeZoneIdInput(): string;
    private _dailyRecurrence?;
    /**
     * @stability stable
     */
    get dailyRecurrence(): DevTestScheduleDailyRecurrence[];
    /**
     * @stability stable
     */
    set dailyRecurrence(value: DevTestScheduleDailyRecurrence[]);
    /**
     * @stability stable
     */
    resetDailyRecurrence(): void;
    /**
     * @stability stable
     */
    get dailyRecurrenceInput(): DevTestScheduleDailyRecurrence[] | undefined;
    private _hourlyRecurrence?;
    /**
     * @stability stable
     */
    get hourlyRecurrence(): DevTestScheduleHourlyRecurrence[];
    /**
     * @stability stable
     */
    set hourlyRecurrence(value: DevTestScheduleHourlyRecurrence[]);
    /**
     * @stability stable
     */
    resetHourlyRecurrence(): void;
    /**
     * @stability stable
     */
    get hourlyRecurrenceInput(): DevTestScheduleHourlyRecurrence[] | undefined;
    private _notificationSettings;
    /**
     * @stability stable
     */
    get notificationSettings(): DevTestScheduleNotificationSettings[];
    /**
     * @stability stable
     */
    set notificationSettings(value: DevTestScheduleNotificationSettings[]);
    /**
     * @stability stable
     */
    get notificationSettingsInput(): DevTestScheduleNotificationSettings[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): DevTestScheduleTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: DevTestScheduleTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DevTestScheduleTimeouts | undefined;
    private _weeklyRecurrence?;
    /**
     * @stability stable
     */
    get weeklyRecurrence(): DevTestScheduleWeeklyRecurrence[];
    /**
     * @stability stable
     */
    set weeklyRecurrence(value: DevTestScheduleWeeklyRecurrence[]);
    /**
     * @stability stable
     */
    resetWeeklyRecurrence(): void;
    /**
     * @stability stable
     */
    get weeklyRecurrenceInput(): DevTestScheduleWeeklyRecurrence[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
