import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface FirewallPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly basePolicyId?: string;
    /**
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly sku?: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly threatIntelligenceMode?: string;
    /**
     * dns block.
     *
     * @stability stable
     */
    readonly dns?: FirewallPolicyDns[];
    /**
     * threat_intelligence_allowlist block.
     *
     * @stability stable
     */
    readonly threatIntelligenceAllowlist?: FirewallPolicyThreatIntelligenceAllowlist[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: FirewallPolicyTimeouts;
}
/**
 * @stability stable
 */
export interface FirewallPolicyDns {
    /**
     * @stability stable
     */
    readonly networkRuleFqdnEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly proxyEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly servers?: string[];
}
/**
 * @stability stable
 */
export interface FirewallPolicyThreatIntelligenceAllowlist {
    /**
     * @stability stable
     */
    readonly fqdns?: string[];
    /**
     * @stability stable
     */
    readonly ipAddresses?: string[];
}
/**
 * @stability stable
 */
export interface FirewallPolicyTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class FirewallPolicy extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: FirewallPolicyConfig);
    private _basePolicyId?;
    /**
     * @stability stable
     */
    get basePolicyId(): string;
    /**
     * @stability stable
     */
    set basePolicyId(value: string);
    /**
     * @stability stable
     */
    resetBasePolicyId(): void;
    /**
     * @stability stable
     */
    get basePolicyIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get childPolicies(): string[];
    /**
     * @stability stable
     */
    get firewalls(): string[];
    /**
     * @stability stable
     */
    get id(): string;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    /**
     * @stability stable
     */
    get ruleCollectionGroups(): string[];
    private _sku?;
    /**
     * @stability stable
     */
    get sku(): string;
    /**
     * @stability stable
     */
    set sku(value: string);
    /**
     * @stability stable
     */
    resetSku(): void;
    /**
     * @stability stable
     */
    get skuInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _threatIntelligenceMode?;
    /**
     * @stability stable
     */
    get threatIntelligenceMode(): string;
    /**
     * @stability stable
     */
    set threatIntelligenceMode(value: string);
    /**
     * @stability stable
     */
    resetThreatIntelligenceMode(): void;
    /**
     * @stability stable
     */
    get threatIntelligenceModeInput(): string | undefined;
    private _dns?;
    /**
     * @stability stable
     */
    get dns(): FirewallPolicyDns[];
    /**
     * @stability stable
     */
    set dns(value: FirewallPolicyDns[]);
    /**
     * @stability stable
     */
    resetDns(): void;
    /**
     * @stability stable
     */
    get dnsInput(): FirewallPolicyDns[] | undefined;
    private _threatIntelligenceAllowlist?;
    /**
     * @stability stable
     */
    get threatIntelligenceAllowlist(): FirewallPolicyThreatIntelligenceAllowlist[];
    /**
     * @stability stable
     */
    set threatIntelligenceAllowlist(value: FirewallPolicyThreatIntelligenceAllowlist[]);
    /**
     * @stability stable
     */
    resetThreatIntelligenceAllowlist(): void;
    /**
     * @stability stable
     */
    get threatIntelligenceAllowlistInput(): FirewallPolicyThreatIntelligenceAllowlist[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): FirewallPolicyTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: FirewallPolicyTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): FirewallPolicyTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
