import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface FirewallConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly dnsServers?: string[];
    /**
     * @stability stable
     */
    readonly firewallPolicyId?: string;
    /**
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly privateIpRanges?: string[];
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly skuName?: string;
    /**
     * @stability stable
     */
    readonly skuTier?: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly threatIntelMode?: string;
    /**
     * @stability stable
     */
    readonly zones?: string[];
    /**
     * ip_configuration block.
     *
     * @stability stable
     */
    readonly ipConfiguration?: FirewallIpConfiguration[];
    /**
     * management_ip_configuration block.
     *
     * @stability stable
     */
    readonly managementIpConfiguration?: FirewallManagementIpConfiguration[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: FirewallTimeouts;
    /**
     * virtual_hub block.
     *
     * @stability stable
     */
    readonly virtualHub?: FirewallVirtualHub[];
}
/**
 * @stability stable
 */
export interface FirewallIpConfiguration {
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly publicIpAddressId: string;
    /**
     * @stability stable
     */
    readonly subnetId?: string;
}
/**
 * @stability stable
 */
export interface FirewallManagementIpConfiguration {
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly publicIpAddressId: string;
    /**
     * @stability stable
     */
    readonly subnetId: string;
}
/**
 * @stability stable
 */
export interface FirewallTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export interface FirewallVirtualHub {
    /**
     * @stability stable
     */
    readonly publicIpCount?: number;
    /**
     * @stability stable
     */
    readonly virtualHubId: string;
}
/**
 * @stability stable
 */
export declare class Firewall extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: FirewallConfig);
    private _dnsServers?;
    /**
     * @stability stable
     */
    get dnsServers(): string[];
    /**
     * @stability stable
     */
    set dnsServers(value: string[]);
    /**
     * @stability stable
     */
    resetDnsServers(): void;
    /**
     * @stability stable
     */
    get dnsServersInput(): string[] | undefined;
    private _firewallPolicyId?;
    /**
     * @stability stable
     */
    get firewallPolicyId(): string;
    /**
     * @stability stable
     */
    set firewallPolicyId(value: string);
    /**
     * @stability stable
     */
    resetFirewallPolicyId(): void;
    /**
     * @stability stable
     */
    get firewallPolicyIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _privateIpRanges?;
    /**
     * @stability stable
     */
    get privateIpRanges(): string[];
    /**
     * @stability stable
     */
    set privateIpRanges(value: string[]);
    /**
     * @stability stable
     */
    resetPrivateIpRanges(): void;
    /**
     * @stability stable
     */
    get privateIpRangesInput(): string[] | undefined;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    private _skuName?;
    /**
     * @stability stable
     */
    get skuName(): string;
    /**
     * @stability stable
     */
    set skuName(value: string);
    /**
     * @stability stable
     */
    resetSkuName(): void;
    /**
     * @stability stable
     */
    get skuNameInput(): string | undefined;
    private _skuTier?;
    /**
     * @stability stable
     */
    get skuTier(): string;
    /**
     * @stability stable
     */
    set skuTier(value: string);
    /**
     * @stability stable
     */
    resetSkuTier(): void;
    /**
     * @stability stable
     */
    get skuTierInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _threatIntelMode?;
    /**
     * @stability stable
     */
    get threatIntelMode(): string;
    /**
     * @stability stable
     */
    set threatIntelMode(value: string);
    /**
     * @stability stable
     */
    resetThreatIntelMode(): void;
    /**
     * @stability stable
     */
    get threatIntelModeInput(): string | undefined;
    private _zones?;
    /**
     * @stability stable
     */
    get zones(): string[];
    /**
     * @stability stable
     */
    set zones(value: string[]);
    /**
     * @stability stable
     */
    resetZones(): void;
    /**
     * @stability stable
     */
    get zonesInput(): string[] | undefined;
    private _ipConfiguration?;
    /**
     * @stability stable
     */
    get ipConfiguration(): FirewallIpConfiguration[];
    /**
     * @stability stable
     */
    set ipConfiguration(value: FirewallIpConfiguration[]);
    /**
     * @stability stable
     */
    resetIpConfiguration(): void;
    /**
     * @stability stable
     */
    get ipConfigurationInput(): FirewallIpConfiguration[] | undefined;
    private _managementIpConfiguration?;
    /**
     * @stability stable
     */
    get managementIpConfiguration(): FirewallManagementIpConfiguration[];
    /**
     * @stability stable
     */
    set managementIpConfiguration(value: FirewallManagementIpConfiguration[]);
    /**
     * @stability stable
     */
    resetManagementIpConfiguration(): void;
    /**
     * @stability stable
     */
    get managementIpConfigurationInput(): FirewallManagementIpConfiguration[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): FirewallTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: FirewallTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): FirewallTimeouts | undefined;
    private _virtualHub?;
    /**
     * @stability stable
     */
    get virtualHub(): FirewallVirtualHub[];
    /**
     * @stability stable
     */
    set virtualHub(value: FirewallVirtualHub[]);
    /**
     * @stability stable
     */
    resetVirtualHub(): void;
    /**
     * @stability stable
     */
    get virtualHubInput(): FirewallVirtualHub[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
