import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface FrontdoorConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly backendPoolsSendReceiveTimeoutSeconds?: number;
    /**
     * @stability stable
     */
    readonly enforceBackendPoolsCertificateNameCheck: boolean;
    /**
     * @stability stable
     */
    readonly friendlyName?: string;
    /**
     * @stability stable
     */
    readonly loadBalancerEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly location?: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * backend_pool block.
     *
     * @stability stable
     */
    readonly backendPool: FrontdoorBackendPool[];
    /**
     * backend_pool_health_probe block.
     *
     * @stability stable
     */
    readonly backendPoolHealthProbe: FrontdoorBackendPoolHealthProbe[];
    /**
     * backend_pool_load_balancing block.
     *
     * @stability stable
     */
    readonly backendPoolLoadBalancing: FrontdoorBackendPoolLoadBalancing[];
    /**
     * frontend_endpoint block.
     *
     * @stability stable
     */
    readonly frontendEndpoint: FrontdoorFrontendEndpoint[];
    /**
     * routing_rule block.
     *
     * @stability stable
     */
    readonly routingRule: FrontdoorRoutingRule[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: FrontdoorTimeouts;
}
/**
 * @stability stable
 */
export interface FrontdoorBackendPoolBackend {
    /**
     * @stability stable
     */
    readonly address: string;
    /**
     * @stability stable
     */
    readonly enabled?: boolean;
    /**
     * @stability stable
     */
    readonly hostHeader: string;
    /**
     * @stability stable
     */
    readonly httpPort: number;
    /**
     * @stability stable
     */
    readonly httpsPort: number;
    /**
     * @stability stable
     */
    readonly priority?: number;
    /**
     * @stability stable
     */
    readonly weight?: number;
}
/**
 * @stability stable
 */
export interface FrontdoorBackendPool {
    /**
     * @stability stable
     */
    readonly healthProbeName: string;
    /**
     * @stability stable
     */
    readonly loadBalancingName: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * backend block.
     *
     * @stability stable
     */
    readonly backend: FrontdoorBackendPoolBackend[];
}
/**
 * @stability stable
 */
export interface FrontdoorBackendPoolHealthProbe {
    /**
     * @stability stable
     */
    readonly enabled?: boolean;
    /**
     * @stability stable
     */
    readonly intervalInSeconds?: number;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly path?: string;
    /**
     * @stability stable
     */
    readonly probeMethod?: string;
    /**
     * @stability stable
     */
    readonly protocol?: string;
}
/**
 * @stability stable
 */
export interface FrontdoorBackendPoolLoadBalancing {
    /**
     * @stability stable
     */
    readonly additionalLatencyMilliseconds?: number;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly sampleSize?: number;
    /**
     * @stability stable
     */
    readonly successfulSamplesRequired?: number;
}
/**
 * @stability stable
 */
export interface FrontdoorFrontendEndpointCustomHttpsConfiguration {
    /**
     * @stability stable
     */
    readonly azureKeyVaultCertificateSecretName?: string;
    /**
     * @stability stable
     */
    readonly azureKeyVaultCertificateSecretVersion?: string;
    /**
     * @stability stable
     */
    readonly azureKeyVaultCertificateVaultId?: string;
    /**
     * @stability stable
     */
    readonly certificateSource?: string;
}
/**
 * @stability stable
 */
export interface FrontdoorFrontendEndpoint {
    /**
     * @stability stable
     */
    readonly customHttpsProvisioningEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly hostName: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly sessionAffinityEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly sessionAffinityTtlSeconds?: number;
    /**
     * @stability stable
     */
    readonly webApplicationFirewallPolicyLinkId?: string;
    /**
     * custom_https_configuration block.
     *
     * @stability stable
     */
    readonly customHttpsConfiguration?: FrontdoorFrontendEndpointCustomHttpsConfiguration[];
}
/**
 * @stability stable
 */
export interface FrontdoorRoutingRuleForwardingConfiguration {
    /**
     * @stability stable
     */
    readonly backendPoolName: string;
    /**
     * @stability stable
     */
    readonly cacheEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly cacheQueryParameterStripDirective?: string;
    /**
     * @stability stable
     */
    readonly cacheUseDynamicCompression?: boolean;
    /**
     * @stability stable
     */
    readonly customForwardingPath?: string;
    /**
     * @stability stable
     */
    readonly forwardingProtocol?: string;
}
/**
 * @stability stable
 */
export interface FrontdoorRoutingRuleRedirectConfiguration {
    /**
     * @stability stable
     */
    readonly customFragment?: string;
    /**
     * @stability stable
     */
    readonly customHost?: string;
    /**
     * @stability stable
     */
    readonly customPath?: string;
    /**
     * @stability stable
     */
    readonly customQueryString?: string;
    /**
     * @stability stable
     */
    readonly redirectProtocol: string;
    /**
     * @stability stable
     */
    readonly redirectType: string;
}
/**
 * @stability stable
 */
export interface FrontdoorRoutingRule {
    /**
     * @stability stable
     */
    readonly acceptedProtocols: string[];
    /**
     * @stability stable
     */
    readonly enabled?: boolean;
    /**
     * @stability stable
     */
    readonly frontendEndpoints: string[];
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly patternsToMatch: string[];
    /**
     * forwarding_configuration block.
     *
     * @stability stable
     */
    readonly forwardingConfiguration?: FrontdoorRoutingRuleForwardingConfiguration[];
    /**
     * redirect_configuration block.
     *
     * @stability stable
     */
    readonly redirectConfiguration?: FrontdoorRoutingRuleRedirectConfiguration[];
}
/**
 * @stability stable
 */
export interface FrontdoorTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class Frontdoor extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: FrontdoorConfig);
    /**
     * @stability stable
     */
    backendPoolHealthProbes(key: string): string;
    /**
     * @stability stable
     */
    backendPoolLoadBalancingSettings(key: string): string;
    /**
     * @stability stable
     */
    backendPools(key: string): string;
    private _backendPoolsSendReceiveTimeoutSeconds?;
    /**
     * @stability stable
     */
    get backendPoolsSendReceiveTimeoutSeconds(): number;
    /**
     * @stability stable
     */
    set backendPoolsSendReceiveTimeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetBackendPoolsSendReceiveTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get backendPoolsSendReceiveTimeoutSecondsInput(): number | undefined;
    /**
     * @stability stable
     */
    get cname(): string;
    private _enforceBackendPoolsCertificateNameCheck;
    /**
     * @stability stable
     */
    get enforceBackendPoolsCertificateNameCheck(): boolean;
    /**
     * @stability stable
     */
    set enforceBackendPoolsCertificateNameCheck(value: boolean);
    /**
     * @stability stable
     */
    get enforceBackendPoolsCertificateNameCheckInput(): boolean;
    private _friendlyName?;
    /**
     * @stability stable
     */
    get friendlyName(): string;
    /**
     * @stability stable
     */
    set friendlyName(value: string);
    /**
     * @stability stable
     */
    resetFriendlyName(): void;
    /**
     * @stability stable
     */
    get friendlyNameInput(): string | undefined;
    /**
     * @stability stable
     */
    frontendEndpoints(key: string): string;
    /**
     * @stability stable
     */
    get headerFrontdoorId(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _loadBalancerEnabled?;
    /**
     * @stability stable
     */
    get loadBalancerEnabled(): boolean;
    /**
     * @stability stable
     */
    set loadBalancerEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetLoadBalancerEnabled(): void;
    /**
     * @stability stable
     */
    get loadBalancerEnabledInput(): boolean | undefined;
    private _location?;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    resetLocation(): void;
    /**
     * @stability stable
     */
    get locationInput(): string | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    /**
     * @stability stable
     */
    routingRules(key: string): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _backendPool;
    /**
     * @stability stable
     */
    get backendPool(): FrontdoorBackendPool[];
    /**
     * @stability stable
     */
    set backendPool(value: FrontdoorBackendPool[]);
    /**
     * @stability stable
     */
    get backendPoolInput(): FrontdoorBackendPool[];
    private _backendPoolHealthProbe;
    /**
     * @stability stable
     */
    get backendPoolHealthProbe(): FrontdoorBackendPoolHealthProbe[];
    /**
     * @stability stable
     */
    set backendPoolHealthProbe(value: FrontdoorBackendPoolHealthProbe[]);
    /**
     * @stability stable
     */
    get backendPoolHealthProbeInput(): FrontdoorBackendPoolHealthProbe[];
    private _backendPoolLoadBalancing;
    /**
     * @stability stable
     */
    get backendPoolLoadBalancing(): FrontdoorBackendPoolLoadBalancing[];
    /**
     * @stability stable
     */
    set backendPoolLoadBalancing(value: FrontdoorBackendPoolLoadBalancing[]);
    /**
     * @stability stable
     */
    get backendPoolLoadBalancingInput(): FrontdoorBackendPoolLoadBalancing[];
    private _frontendEndpoint;
    /**
     * @stability stable
     */
    get frontendEndpoint(): FrontdoorFrontendEndpoint[];
    /**
     * @stability stable
     */
    set frontendEndpoint(value: FrontdoorFrontendEndpoint[]);
    /**
     * @stability stable
     */
    get frontendEndpointInput(): FrontdoorFrontendEndpoint[];
    private _routingRule;
    /**
     * @stability stable
     */
    get routingRule(): FrontdoorRoutingRule[];
    /**
     * @stability stable
     */
    set routingRule(value: FrontdoorRoutingRule[]);
    /**
     * @stability stable
     */
    get routingRuleInput(): FrontdoorRoutingRule[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): FrontdoorTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: FrontdoorTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): FrontdoorTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
