import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface FunctionAppConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly appServicePlanId: string;
    /**
     * @stability stable
     */
    readonly appSettings?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly clientAffinityEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly clientCertMode?: string;
    /**
     * @stability stable
     */
    readonly dailyMemoryTimeQuota?: number;
    /**
     * @stability stable
     */
    readonly enableBuiltinLogging?: boolean;
    /**
     * @stability stable
     */
    readonly enabled?: boolean;
    /**
     * @stability stable
     */
    readonly httpsOnly?: boolean;
    /**
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly osType?: string;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly storageAccountAccessKey?: string;
    /**
     * @stability stable
     */
    readonly storageAccountName?: string;
    /**
     * @stability stable
     */
    readonly storageConnectionString?: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly version?: string;
    /**
     * auth_settings block.
     *
     * @stability stable
     */
    readonly authSettings?: FunctionAppAuthSettings[];
    /**
     * connection_string block.
     *
     * @stability stable
     */
    readonly connectionString?: FunctionAppConnectionString[];
    /**
     * identity block.
     *
     * @stability stable
     */
    readonly identity?: FunctionAppIdentity[];
    /**
     * site_config block.
     *
     * @stability stable
     */
    readonly siteConfig?: FunctionAppSiteConfig[];
    /**
     * source_control block.
     *
     * @stability stable
     */
    readonly sourceControl?: FunctionAppSourceControl[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: FunctionAppTimeouts;
}
/**
 * @stability stable
 */
export declare class FunctionAppSiteCredential extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get password(): string;
    /**
     * @stability stable
     */
    get username(): string;
}
/**
 * @stability stable
 */
export interface FunctionAppAuthSettingsActiveDirectory {
    /**
     * @stability stable
     */
    readonly allowedAudiences?: string[];
    /**
     * @stability stable
     */
    readonly clientId: string;
    /**
     * @stability stable
     */
    readonly clientSecret?: string;
}
/**
 * @stability stable
 */
export interface FunctionAppAuthSettingsFacebook {
    /**
     * @stability stable
     */
    readonly appId: string;
    /**
     * @stability stable
     */
    readonly appSecret: string;
    /**
     * @stability stable
     */
    readonly oauthScopes?: string[];
}
/**
 * @stability stable
 */
export interface FunctionAppAuthSettingsGoogle {
    /**
     * @stability stable
     */
    readonly clientId: string;
    /**
     * @stability stable
     */
    readonly clientSecret: string;
    /**
     * @stability stable
     */
    readonly oauthScopes?: string[];
}
/**
 * @stability stable
 */
export interface FunctionAppAuthSettingsMicrosoft {
    /**
     * @stability stable
     */
    readonly clientId: string;
    /**
     * @stability stable
     */
    readonly clientSecret: string;
    /**
     * @stability stable
     */
    readonly oauthScopes?: string[];
}
/**
 * @stability stable
 */
export interface FunctionAppAuthSettingsTwitter {
    /**
     * @stability stable
     */
    readonly consumerKey: string;
    /**
     * @stability stable
     */
    readonly consumerSecret: string;
}
/**
 * @stability stable
 */
export interface FunctionAppAuthSettings {
    /**
     * @stability stable
     */
    readonly additionalLoginParams?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly allowedExternalRedirectUrls?: string[];
    /**
     * @stability stable
     */
    readonly defaultProvider?: string;
    /**
     * @stability stable
     */
    readonly enabled: boolean;
    /**
     * @stability stable
     */
    readonly issuer?: string;
    /**
     * @stability stable
     */
    readonly runtimeVersion?: string;
    /**
     * @stability stable
     */
    readonly tokenRefreshExtensionHours?: number;
    /**
     * @stability stable
     */
    readonly tokenStoreEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly unauthenticatedClientAction?: string;
    /**
     * active_directory block.
     *
     * @stability stable
     */
    readonly activeDirectory?: FunctionAppAuthSettingsActiveDirectory[];
    /**
     * facebook block.
     *
     * @stability stable
     */
    readonly facebook?: FunctionAppAuthSettingsFacebook[];
    /**
     * google block.
     *
     * @stability stable
     */
    readonly google?: FunctionAppAuthSettingsGoogle[];
    /**
     * microsoft block.
     *
     * @stability stable
     */
    readonly microsoft?: FunctionAppAuthSettingsMicrosoft[];
    /**
     * twitter block.
     *
     * @stability stable
     */
    readonly twitter?: FunctionAppAuthSettingsTwitter[];
}
/**
 * @stability stable
 */
export interface FunctionAppConnectionString {
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly type: string;
    /**
     * @stability stable
     */
    readonly value: string;
}
/**
 * @stability stable
 */
export interface FunctionAppIdentity {
    /**
     * @stability stable
     */
    readonly identityIds?: string[];
    /**
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface FunctionAppSiteConfigIpRestriction {
    /**
     * @stability stable
     */
    readonly action?: string;
    /**
     * @stability stable
     */
    readonly ipAddress?: string;
    /**
     * @stability stable
     */
    readonly name?: string;
    /**
     * @stability stable
     */
    readonly priority?: number;
    /**
     * @stability stable
     */
    readonly serviceTag?: string;
    /**
     * @stability stable
     */
    readonly virtualNetworkSubnetId?: string;
}
/**
 * @stability stable
 */
export interface FunctionAppSiteConfigScmIpRestriction {
    /**
     * @stability stable
     */
    readonly action?: string;
    /**
     * @stability stable
     */
    readonly ipAddress?: string;
    /**
     * @stability stable
     */
    readonly name?: string;
    /**
     * @stability stable
     */
    readonly priority?: number;
    /**
     * @stability stable
     */
    readonly serviceTag?: string;
    /**
     * @stability stable
     */
    readonly virtualNetworkSubnetId?: string;
}
/**
 * @stability stable
 */
export interface FunctionAppSiteConfigCors {
    /**
     * @stability stable
     */
    readonly allowedOrigins: string[];
    /**
     * @stability stable
     */
    readonly supportCredentials?: boolean;
}
/**
 * @stability stable
 */
export interface FunctionAppSiteConfig {
    /**
     * @stability stable
     */
    readonly alwaysOn?: boolean;
    /**
     * @stability stable
     */
    readonly autoSwapSlotName?: string;
    /**
     * @stability stable
     */
    readonly ftpsState?: string;
    /**
     * @stability stable
     */
    readonly healthCheckPath?: string;
    /**
     * @stability stable
     */
    readonly http2Enabled?: boolean;
    /**
     * @stability stable
     */
    readonly ipRestriction?: FunctionAppSiteConfigIpRestriction[];
    /**
     * @stability stable
     */
    readonly linuxFxVersion?: string;
    /**
     * @stability stable
     */
    readonly minTlsVersion?: string;
    /**
     * @stability stable
     */
    readonly preWarmedInstanceCount?: number;
    /**
     * @stability stable
     */
    readonly scmIpRestriction?: FunctionAppSiteConfigScmIpRestriction[];
    /**
     * @stability stable
     */
    readonly scmType?: string;
    /**
     * @stability stable
     */
    readonly scmUseMainIpRestriction?: boolean;
    /**
     * @stability stable
     */
    readonly use32BitWorkerProcess?: boolean;
    /**
     * @stability stable
     */
    readonly websocketsEnabled?: boolean;
    /**
     * cors block.
     *
     * @stability stable
     */
    readonly cors?: FunctionAppSiteConfigCors[];
}
/**
 * @stability stable
 */
export interface FunctionAppSourceControl {
    /**
     * @stability stable
     */
    readonly branch?: string;
    /**
     * @stability stable
     */
    readonly manualIntegration?: boolean;
    /**
     * @stability stable
     */
    readonly repoUrl?: string;
    /**
     * @stability stable
     */
    readonly rollbackEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly useMercurial?: boolean;
}
/**
 * @stability stable
 */
export interface FunctionAppTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class FunctionApp extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: FunctionAppConfig);
    private _appServicePlanId;
    /**
     * @stability stable
     */
    get appServicePlanId(): string;
    /**
     * @stability stable
     */
    set appServicePlanId(value: string);
    /**
     * @stability stable
     */
    get appServicePlanIdInput(): string;
    private _appSettings?;
    /**
     * @stability stable
     */
    get appSettings(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set appSettings(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetAppSettings(): void;
    /**
     * @stability stable
     */
    get appSettingsInput(): {
        [key: string]: string;
    } | undefined;
    private _clientAffinityEnabled?;
    /**
     * @stability stable
     */
    get clientAffinityEnabled(): boolean;
    /**
     * @stability stable
     */
    set clientAffinityEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetClientAffinityEnabled(): void;
    /**
     * @stability stable
     */
    get clientAffinityEnabledInput(): boolean | undefined;
    private _clientCertMode?;
    /**
     * @stability stable
     */
    get clientCertMode(): string;
    /**
     * @stability stable
     */
    set clientCertMode(value: string);
    /**
     * @stability stable
     */
    resetClientCertMode(): void;
    /**
     * @stability stable
     */
    get clientCertModeInput(): string | undefined;
    /**
     * @stability stable
     */
    get customDomainVerificationId(): string;
    private _dailyMemoryTimeQuota?;
    /**
     * @stability stable
     */
    get dailyMemoryTimeQuota(): number;
    /**
     * @stability stable
     */
    set dailyMemoryTimeQuota(value: number);
    /**
     * @stability stable
     */
    resetDailyMemoryTimeQuota(): void;
    /**
     * @stability stable
     */
    get dailyMemoryTimeQuotaInput(): number | undefined;
    /**
     * @stability stable
     */
    get defaultHostname(): string;
    private _enableBuiltinLogging?;
    /**
     * @stability stable
     */
    get enableBuiltinLogging(): boolean;
    /**
     * @stability stable
     */
    set enableBuiltinLogging(value: boolean);
    /**
     * @stability stable
     */
    resetEnableBuiltinLogging(): void;
    /**
     * @stability stable
     */
    get enableBuiltinLoggingInput(): boolean | undefined;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean;
    /**
     * @stability stable
     */
    set enabled(value: boolean);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | undefined;
    private _httpsOnly?;
    /**
     * @stability stable
     */
    get httpsOnly(): boolean;
    /**
     * @stability stable
     */
    set httpsOnly(value: boolean);
    /**
     * @stability stable
     */
    resetHttpsOnly(): void;
    /**
     * @stability stable
     */
    get httpsOnlyInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get kind(): string;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _osType?;
    /**
     * @stability stable
     */
    get osType(): string;
    /**
     * @stability stable
     */
    set osType(value: string);
    /**
     * @stability stable
     */
    resetOsType(): void;
    /**
     * @stability stable
     */
    get osTypeInput(): string | undefined;
    /**
     * @stability stable
     */
    get outboundIpAddresses(): string;
    /**
     * @stability stable
     */
    get possibleOutboundIpAddresses(): string;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    /**
     * @stability stable
     */
    siteCredential(index: string): FunctionAppSiteCredential;
    private _storageAccountAccessKey?;
    /**
     * @stability stable
     */
    get storageAccountAccessKey(): string;
    /**
     * @stability stable
     */
    set storageAccountAccessKey(value: string);
    /**
     * @stability stable
     */
    resetStorageAccountAccessKey(): void;
    /**
     * @stability stable
     */
    get storageAccountAccessKeyInput(): string | undefined;
    private _storageAccountName?;
    /**
     * @stability stable
     */
    get storageAccountName(): string;
    /**
     * @stability stable
     */
    set storageAccountName(value: string);
    /**
     * @stability stable
     */
    resetStorageAccountName(): void;
    /**
     * @stability stable
     */
    get storageAccountNameInput(): string | undefined;
    private _storageConnectionString?;
    /**
     * @stability stable
     */
    get storageConnectionString(): string;
    /**
     * @stability stable
     */
    set storageConnectionString(value: string);
    /**
     * @stability stable
     */
    resetStorageConnectionString(): void;
    /**
     * @stability stable
     */
    get storageConnectionStringInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _version?;
    /**
     * @stability stable
     */
    get version(): string;
    /**
     * @stability stable
     */
    set version(value: string);
    /**
     * @stability stable
     */
    resetVersion(): void;
    /**
     * @stability stable
     */
    get versionInput(): string | undefined;
    private _authSettings?;
    /**
     * @stability stable
     */
    get authSettings(): FunctionAppAuthSettings[];
    /**
     * @stability stable
     */
    set authSettings(value: FunctionAppAuthSettings[]);
    /**
     * @stability stable
     */
    resetAuthSettings(): void;
    /**
     * @stability stable
     */
    get authSettingsInput(): FunctionAppAuthSettings[] | undefined;
    private _connectionString?;
    /**
     * @stability stable
     */
    get connectionString(): FunctionAppConnectionString[];
    /**
     * @stability stable
     */
    set connectionString(value: FunctionAppConnectionString[]);
    /**
     * @stability stable
     */
    resetConnectionString(): void;
    /**
     * @stability stable
     */
    get connectionStringInput(): FunctionAppConnectionString[] | undefined;
    private _identity?;
    /**
     * @stability stable
     */
    get identity(): FunctionAppIdentity[];
    /**
     * @stability stable
     */
    set identity(value: FunctionAppIdentity[]);
    /**
     * @stability stable
     */
    resetIdentity(): void;
    /**
     * @stability stable
     */
    get identityInput(): FunctionAppIdentity[] | undefined;
    private _siteConfig?;
    /**
     * @stability stable
     */
    get siteConfig(): FunctionAppSiteConfig[];
    /**
     * @stability stable
     */
    set siteConfig(value: FunctionAppSiteConfig[]);
    /**
     * @stability stable
     */
    resetSiteConfig(): void;
    /**
     * @stability stable
     */
    get siteConfigInput(): FunctionAppSiteConfig[] | undefined;
    private _sourceControl?;
    /**
     * @stability stable
     */
    get sourceControl(): FunctionAppSourceControl[];
    /**
     * @stability stable
     */
    set sourceControl(value: FunctionAppSourceControl[]);
    /**
     * @stability stable
     */
    resetSourceControl(): void;
    /**
     * @stability stable
     */
    get sourceControlInput(): FunctionAppSourceControl[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): FunctionAppTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: FunctionAppTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): FunctionAppTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
