import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface HpcCacheConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly cacheSizeInGb: number;
    /**
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly mtu?: number;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly ntpServer?: string;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly rootSquashEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly skuName: string;
    /**
     * @stability stable
     */
    readonly subnetId: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * default_access_policy block.
     *
     * @stability stable
     */
    readonly defaultAccessPolicy?: HpcCacheDefaultAccessPolicy[];
    /**
     * dns block.
     *
     * @stability stable
     */
    readonly dns?: HpcCacheDns[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: HpcCacheTimeouts;
}
/**
 * @stability stable
 */
export interface HpcCacheDefaultAccessPolicyAccessRule {
    /**
     * @stability stable
     */
    readonly access: string;
    /**
     * @stability stable
     */
    readonly anonymousGid?: number;
    /**
     * @stability stable
     */
    readonly anonymousUid?: number;
    /**
     * @stability stable
     */
    readonly filter?: string;
    /**
     * @stability stable
     */
    readonly rootSquashEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly scope: string;
    /**
     * @stability stable
     */
    readonly submountAccessEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly suidEnabled?: boolean;
}
/**
 * @stability stable
 */
export interface HpcCacheDefaultAccessPolicy {
    /**
     * access_rule block.
     *
     * @stability stable
     */
    readonly accessRule: HpcCacheDefaultAccessPolicyAccessRule[];
}
/**
 * @stability stable
 */
export interface HpcCacheDns {
    /**
     * @stability stable
     */
    readonly searchDomain?: string;
    /**
     * @stability stable
     */
    readonly servers: string[];
}
/**
 * @stability stable
 */
export interface HpcCacheTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class HpcCache extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: HpcCacheConfig);
    private _cacheSizeInGb;
    /**
     * @stability stable
     */
    get cacheSizeInGb(): number;
    /**
     * @stability stable
     */
    set cacheSizeInGb(value: number);
    /**
     * @stability stable
     */
    get cacheSizeInGbInput(): number;
    /**
     * @stability stable
     */
    get id(): string;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    /**
     * @stability stable
     */
    get mountAddresses(): string[];
    private _mtu?;
    /**
     * @stability stable
     */
    get mtu(): number;
    /**
     * @stability stable
     */
    set mtu(value: number);
    /**
     * @stability stable
     */
    resetMtu(): void;
    /**
     * @stability stable
     */
    get mtuInput(): number | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _ntpServer?;
    /**
     * @stability stable
     */
    get ntpServer(): string;
    /**
     * @stability stable
     */
    set ntpServer(value: string);
    /**
     * @stability stable
     */
    resetNtpServer(): void;
    /**
     * @stability stable
     */
    get ntpServerInput(): string | undefined;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    private _rootSquashEnabled?;
    /**
     * @stability stable
     */
    get rootSquashEnabled(): boolean;
    /**
     * @stability stable
     */
    set rootSquashEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetRootSquashEnabled(): void;
    /**
     * @stability stable
     */
    get rootSquashEnabledInput(): boolean | undefined;
    private _skuName;
    /**
     * @stability stable
     */
    get skuName(): string;
    /**
     * @stability stable
     */
    set skuName(value: string);
    /**
     * @stability stable
     */
    get skuNameInput(): string;
    private _subnetId;
    /**
     * @stability stable
     */
    get subnetId(): string;
    /**
     * @stability stable
     */
    set subnetId(value: string);
    /**
     * @stability stable
     */
    get subnetIdInput(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _defaultAccessPolicy?;
    /**
     * @stability stable
     */
    get defaultAccessPolicy(): HpcCacheDefaultAccessPolicy[];
    /**
     * @stability stable
     */
    set defaultAccessPolicy(value: HpcCacheDefaultAccessPolicy[]);
    /**
     * @stability stable
     */
    resetDefaultAccessPolicy(): void;
    /**
     * @stability stable
     */
    get defaultAccessPolicyInput(): HpcCacheDefaultAccessPolicy[] | undefined;
    private _dns?;
    /**
     * @stability stable
     */
    get dns(): HpcCacheDns[];
    /**
     * @stability stable
     */
    set dns(value: HpcCacheDns[]);
    /**
     * @stability stable
     */
    resetDns(): void;
    /**
     * @stability stable
     */
    get dnsInput(): HpcCacheDns[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): HpcCacheTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: HpcCacheTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): HpcCacheTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
