import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ImageConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly hyperVGeneration?: string;
    /**
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly sourceVirtualMachineId?: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly zoneResilient?: boolean;
    /**
     * data_disk block.
     *
     * @stability stable
     */
    readonly dataDisk?: ImageDataDisk[];
    /**
     * os_disk block.
     *
     * @stability stable
     */
    readonly osDisk?: ImageOsDisk[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: ImageTimeouts;
}
/**
 * @stability stable
 */
export interface ImageDataDisk {
    /**
     * @stability stable
     */
    readonly blobUri?: string;
    /**
     * @stability stable
     */
    readonly caching?: string;
    /**
     * @stability stable
     */
    readonly lun?: number;
    /**
     * @stability stable
     */
    readonly managedDiskId?: string;
    /**
     * @stability stable
     */
    readonly sizeGb?: number;
}
/**
 * @stability stable
 */
export interface ImageOsDisk {
    /**
     * @stability stable
     */
    readonly blobUri?: string;
    /**
     * @stability stable
     */
    readonly caching?: string;
    /**
     * @stability stable
     */
    readonly managedDiskId?: string;
    /**
     * @stability stable
     */
    readonly osState?: string;
    /**
     * @stability stable
     */
    readonly osType?: string;
    /**
     * @stability stable
     */
    readonly sizeGb?: number;
}
/**
 * @stability stable
 */
export interface ImageTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class Image extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ImageConfig);
    private _hyperVGeneration?;
    /**
     * @stability stable
     */
    get hyperVGeneration(): string;
    /**
     * @stability stable
     */
    set hyperVGeneration(value: string);
    /**
     * @stability stable
     */
    resetHyperVGeneration(): void;
    /**
     * @stability stable
     */
    get hyperVGenerationInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    private _sourceVirtualMachineId?;
    /**
     * @stability stable
     */
    get sourceVirtualMachineId(): string;
    /**
     * @stability stable
     */
    set sourceVirtualMachineId(value: string);
    /**
     * @stability stable
     */
    resetSourceVirtualMachineId(): void;
    /**
     * @stability stable
     */
    get sourceVirtualMachineIdInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _zoneResilient?;
    /**
     * @stability stable
     */
    get zoneResilient(): boolean;
    /**
     * @stability stable
     */
    set zoneResilient(value: boolean);
    /**
     * @stability stable
     */
    resetZoneResilient(): void;
    /**
     * @stability stable
     */
    get zoneResilientInput(): boolean | undefined;
    private _dataDisk?;
    /**
     * @stability stable
     */
    get dataDisk(): ImageDataDisk[];
    /**
     * @stability stable
     */
    set dataDisk(value: ImageDataDisk[]);
    /**
     * @stability stable
     */
    resetDataDisk(): void;
    /**
     * @stability stable
     */
    get dataDiskInput(): ImageDataDisk[] | undefined;
    private _osDisk?;
    /**
     * @stability stable
     */
    get osDisk(): ImageOsDisk[];
    /**
     * @stability stable
     */
    set osDisk(value: ImageOsDisk[]);
    /**
     * @stability stable
     */
    resetOsDisk(): void;
    /**
     * @stability stable
     */
    get osDiskInput(): ImageOsDisk[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ImageTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ImageTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ImageTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
