import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface IothubConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly endpoint?: IothubEndpoint[];
    /**
     * @stability stable
     */
    readonly enrichment?: IothubEnrichment[];
    /**
     * @stability stable
     */
    readonly eventHubPartitionCount?: number;
    /**
     * @stability stable
     */
    readonly eventHubRetentionInDays?: number;
    /**
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly minTlsVersion?: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly publicNetworkAccessEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly route?: IothubRoute[];
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * fallback_route block.
     *
     * @stability stable
     */
    readonly fallbackRoute?: IothubFallbackRoute[];
    /**
     * file_upload block.
     *
     * @stability stable
     */
    readonly fileUpload?: IothubFileUpload[];
    /**
     * ip_filter_rule block.
     *
     * @stability stable
     */
    readonly ipFilterRule?: IothubIpFilterRule[];
    /**
     * sku block.
     *
     * @stability stable
     */
    readonly sku: IothubSku[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: IothubTimeouts;
}
/**
 * @stability stable
 */
export interface IothubEndpoint {
    /**
     * @stability stable
     */
    readonly batchFrequencyInSeconds?: number;
    /**
     * @stability stable
     */
    readonly connectionString?: string;
    /**
     * @stability stable
     */
    readonly containerName?: string;
    /**
     * @stability stable
     */
    readonly encoding?: string;
    /**
     * @stability stable
     */
    readonly fileNameFormat?: string;
    /**
     * @stability stable
     */
    readonly maxChunkSizeInBytes?: number;
    /**
     * @stability stable
     */
    readonly name?: string;
    /**
     * @stability stable
     */
    readonly resourceGroupName?: string;
    /**
     * @stability stable
     */
    readonly type?: string;
}
/**
 * @stability stable
 */
export interface IothubEnrichment {
    /**
     * @stability stable
     */
    readonly endpointNames?: string[];
    /**
     * @stability stable
     */
    readonly key?: string;
    /**
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface IothubRoute {
    /**
     * @stability stable
     */
    readonly condition?: string;
    /**
     * @stability stable
     */
    readonly enabled?: boolean;
    /**
     * @stability stable
     */
    readonly endpointNames?: string[];
    /**
     * @stability stable
     */
    readonly name?: string;
    /**
     * @stability stable
     */
    readonly source?: string;
}
/**
 * @stability stable
 */
export declare class IothubSharedAccessPolicy extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get keyName(): string;
    /**
     * @stability stable
     */
    get permissions(): string;
    /**
     * @stability stable
     */
    get primaryKey(): string;
    /**
     * @stability stable
     */
    get secondaryKey(): string;
}
/**
 * @stability stable
 */
export interface IothubFallbackRoute {
    /**
     * @stability stable
     */
    readonly condition?: string;
    /**
     * @stability stable
     */
    readonly enabled?: boolean;
    /**
     * @stability stable
     */
    readonly endpointNames?: string[];
    /**
     * @stability stable
     */
    readonly source?: string;
}
/**
 * @stability stable
 */
export interface IothubFileUpload {
    /**
     * @stability stable
     */
    readonly connectionString: string;
    /**
     * @stability stable
     */
    readonly containerName: string;
    /**
     * @stability stable
     */
    readonly defaultTtl?: string;
    /**
     * @stability stable
     */
    readonly lockDuration?: string;
    /**
     * @stability stable
     */
    readonly maxDeliveryCount?: number;
    /**
     * @stability stable
     */
    readonly notifications?: boolean;
    /**
     * @stability stable
     */
    readonly sasTtl?: string;
}
/**
 * @stability stable
 */
export interface IothubIpFilterRule {
    /**
     * @stability stable
     */
    readonly action: string;
    /**
     * @stability stable
     */
    readonly ipMask: string;
    /**
     * @stability stable
     */
    readonly name: string;
}
/**
 * @stability stable
 */
export interface IothubSku {
    /**
     * @stability stable
     */
    readonly capacity: number;
    /**
     * @stability stable
     */
    readonly name: string;
}
/**
 * @stability stable
 */
export interface IothubTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class Iothub extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: IothubConfig);
    private _endpoint?;
    /**
     * @stability stable
     */
    get endpoint(): IothubEndpoint[];
    /**
     * @stability stable
     */
    set endpoint(value: IothubEndpoint[]);
    /**
     * @stability stable
     */
    resetEndpoint(): void;
    /**
     * @stability stable
     */
    get endpointInput(): IothubEndpoint[] | undefined;
    private _enrichment?;
    /**
     * @stability stable
     */
    get enrichment(): IothubEnrichment[];
    /**
     * @stability stable
     */
    set enrichment(value: IothubEnrichment[]);
    /**
     * @stability stable
     */
    resetEnrichment(): void;
    /**
     * @stability stable
     */
    get enrichmentInput(): IothubEnrichment[] | undefined;
    /**
     * @stability stable
     */
    get eventHubEventsEndpoint(): string;
    /**
     * @stability stable
     */
    get eventHubEventsPath(): string;
    /**
     * @stability stable
     */
    get eventHubOperationsEndpoint(): string;
    /**
     * @stability stable
     */
    get eventHubOperationsPath(): string;
    private _eventHubPartitionCount?;
    /**
     * @stability stable
     */
    get eventHubPartitionCount(): number;
    /**
     * @stability stable
     */
    set eventHubPartitionCount(value: number);
    /**
     * @stability stable
     */
    resetEventHubPartitionCount(): void;
    /**
     * @stability stable
     */
    get eventHubPartitionCountInput(): number | undefined;
    private _eventHubRetentionInDays?;
    /**
     * @stability stable
     */
    get eventHubRetentionInDays(): number;
    /**
     * @stability stable
     */
    set eventHubRetentionInDays(value: number);
    /**
     * @stability stable
     */
    resetEventHubRetentionInDays(): void;
    /**
     * @stability stable
     */
    get eventHubRetentionInDaysInput(): number | undefined;
    /**
     * @stability stable
     */
    get hostname(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _minTlsVersion?;
    /**
     * @stability stable
     */
    get minTlsVersion(): string;
    /**
     * @stability stable
     */
    set minTlsVersion(value: string);
    /**
     * @stability stable
     */
    resetMinTlsVersion(): void;
    /**
     * @stability stable
     */
    get minTlsVersionInput(): string | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _publicNetworkAccessEnabled?;
    /**
     * @stability stable
     */
    get publicNetworkAccessEnabled(): boolean;
    /**
     * @stability stable
     */
    set publicNetworkAccessEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetPublicNetworkAccessEnabled(): void;
    /**
     * @stability stable
     */
    get publicNetworkAccessEnabledInput(): boolean | undefined;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    private _route?;
    /**
     * @stability stable
     */
    get route(): IothubRoute[];
    /**
     * @stability stable
     */
    set route(value: IothubRoute[]);
    /**
     * @stability stable
     */
    resetRoute(): void;
    /**
     * @stability stable
     */
    get routeInput(): IothubRoute[] | undefined;
    /**
     * @stability stable
     */
    sharedAccessPolicy(index: string): IothubSharedAccessPolicy;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get type(): string;
    private _fallbackRoute?;
    /**
     * @stability stable
     */
    get fallbackRoute(): IothubFallbackRoute[];
    /**
     * @stability stable
     */
    set fallbackRoute(value: IothubFallbackRoute[]);
    /**
     * @stability stable
     */
    resetFallbackRoute(): void;
    /**
     * @stability stable
     */
    get fallbackRouteInput(): IothubFallbackRoute[] | undefined;
    private _fileUpload?;
    /**
     * @stability stable
     */
    get fileUpload(): IothubFileUpload[];
    /**
     * @stability stable
     */
    set fileUpload(value: IothubFileUpload[]);
    /**
     * @stability stable
     */
    resetFileUpload(): void;
    /**
     * @stability stable
     */
    get fileUploadInput(): IothubFileUpload[] | undefined;
    private _ipFilterRule?;
    /**
     * @stability stable
     */
    get ipFilterRule(): IothubIpFilterRule[];
    /**
     * @stability stable
     */
    set ipFilterRule(value: IothubIpFilterRule[]);
    /**
     * @stability stable
     */
    resetIpFilterRule(): void;
    /**
     * @stability stable
     */
    get ipFilterRuleInput(): IothubIpFilterRule[] | undefined;
    private _sku;
    /**
     * @stability stable
     */
    get sku(): IothubSku[];
    /**
     * @stability stable
     */
    set sku(value: IothubSku[]);
    /**
     * @stability stable
     */
    get skuInput(): IothubSku[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): IothubTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: IothubTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): IothubTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
