import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface KeyVaultCertificateConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly keyVaultId: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * certificate block.
     *
     * @stability stable
     */
    readonly certificate?: KeyVaultCertificateCertificate[];
    /**
     * certificate_policy block.
     *
     * @stability stable
     */
    readonly certificatePolicy: KeyVaultCertificateCertificatePolicy[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: KeyVaultCertificateTimeouts;
}
/**
 * @stability stable
 */
export declare class KeyVaultCertificateCertificateAttribute extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get created(): string;
    /**
     * @stability stable
     */
    get enabled(): boolean;
    /**
     * @stability stable
     */
    get expires(): string;
    /**
     * @stability stable
     */
    get notBefore(): string;
    /**
     * @stability stable
     */
    get recoveryLevel(): string;
    /**
     * @stability stable
     */
    get updated(): string;
}
/**
 * @stability stable
 */
export interface KeyVaultCertificateCertificate {
    /**
     * @stability stable
     */
    readonly contents: string;
    /**
     * @stability stable
     */
    readonly password?: string;
}
/**
 * @stability stable
 */
export interface KeyVaultCertificateCertificatePolicyIssuerParameters {
    /**
     * @stability stable
     */
    readonly name: string;
}
/**
 * @stability stable
 */
export interface KeyVaultCertificateCertificatePolicyKeyProperties {
    /**
     * @stability stable
     */
    readonly exportable: boolean;
    /**
     * @stability stable
     */
    readonly keySize: number;
    /**
     * @stability stable
     */
    readonly keyType: string;
    /**
     * @stability stable
     */
    readonly reuseKey: boolean;
}
/**
 * @stability stable
 */
export interface KeyVaultCertificateCertificatePolicyLifetimeActionAction {
    /**
     * @stability stable
     */
    readonly actionType: string;
}
/**
 * @stability stable
 */
export interface KeyVaultCertificateCertificatePolicyLifetimeActionTrigger {
    /**
     * @stability stable
     */
    readonly daysBeforeExpiry?: number;
    /**
     * @stability stable
     */
    readonly lifetimePercentage?: number;
}
/**
 * @stability stable
 */
export interface KeyVaultCertificateCertificatePolicyLifetimeAction {
    /**
     * action block.
     *
     * @stability stable
     */
    readonly action: KeyVaultCertificateCertificatePolicyLifetimeActionAction[];
    /**
     * trigger block.
     *
     * @stability stable
     */
    readonly trigger: KeyVaultCertificateCertificatePolicyLifetimeActionTrigger[];
}
/**
 * @stability stable
 */
export interface KeyVaultCertificateCertificatePolicySecretProperties {
    /**
     * @stability stable
     */
    readonly contentType: string;
}
/**
 * @stability stable
 */
export interface KeyVaultCertificateCertificatePolicyX509CertificatePropertiesSubjectAlternativeNames {
    /**
     * @stability stable
     */
    readonly dnsNames?: string[];
    /**
     * @stability stable
     */
    readonly emails?: string[];
    /**
     * @stability stable
     */
    readonly upns?: string[];
}
/**
 * @stability stable
 */
export interface KeyVaultCertificateCertificatePolicyX509CertificateProperties {
    /**
     * @stability stable
     */
    readonly extendedKeyUsage?: string[];
    /**
     * @stability stable
     */
    readonly keyUsage: string[];
    /**
     * @stability stable
     */
    readonly subject: string;
    /**
     * @stability stable
     */
    readonly validityInMonths: number;
    /**
     * subject_alternative_names block.
     *
     * @stability stable
     */
    readonly subjectAlternativeNames?: KeyVaultCertificateCertificatePolicyX509CertificatePropertiesSubjectAlternativeNames[];
}
/**
 * @stability stable
 */
export interface KeyVaultCertificateCertificatePolicy {
    /**
     * issuer_parameters block.
     *
     * @stability stable
     */
    readonly issuerParameters: KeyVaultCertificateCertificatePolicyIssuerParameters[];
    /**
     * key_properties block.
     *
     * @stability stable
     */
    readonly keyProperties: KeyVaultCertificateCertificatePolicyKeyProperties[];
    /**
     * lifetime_action block.
     *
     * @stability stable
     */
    readonly lifetimeAction?: KeyVaultCertificateCertificatePolicyLifetimeAction[];
    /**
     * secret_properties block.
     *
     * @stability stable
     */
    readonly secretProperties: KeyVaultCertificateCertificatePolicySecretProperties[];
    /**
     * x509_certificate_properties block.
     *
     * @stability stable
     */
    readonly x509CertificateProperties?: KeyVaultCertificateCertificatePolicyX509CertificateProperties[];
}
/**
 * @stability stable
 */
export interface KeyVaultCertificateTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
}
/**
 * @stability stable
 */
export declare class KeyVaultCertificate extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: KeyVaultCertificateConfig);
    /**
     * @stability stable
     */
    certificateAttribute(index: string): KeyVaultCertificateCertificateAttribute;
    /**
     * @stability stable
     */
    get certificateData(): string;
    /**
     * @stability stable
     */
    get certificateDataBase64(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _keyVaultId;
    /**
     * @stability stable
     */
    get keyVaultId(): string;
    /**
     * @stability stable
     */
    set keyVaultId(value: string);
    /**
     * @stability stable
     */
    get keyVaultIdInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    /**
     * @stability stable
     */
    get secretId(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get thumbprint(): string;
    /**
     * @stability stable
     */
    get version(): string;
    private _certificate?;
    /**
     * @stability stable
     */
    get certificate(): KeyVaultCertificateCertificate[];
    /**
     * @stability stable
     */
    set certificate(value: KeyVaultCertificateCertificate[]);
    /**
     * @stability stable
     */
    resetCertificate(): void;
    /**
     * @stability stable
     */
    get certificateInput(): KeyVaultCertificateCertificate[] | undefined;
    private _certificatePolicy;
    /**
     * @stability stable
     */
    get certificatePolicy(): KeyVaultCertificateCertificatePolicy[];
    /**
     * @stability stable
     */
    set certificatePolicy(value: KeyVaultCertificateCertificatePolicy[]);
    /**
     * @stability stable
     */
    get certificatePolicyInput(): KeyVaultCertificateCertificatePolicy[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): KeyVaultCertificateTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: KeyVaultCertificateTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): KeyVaultCertificateTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
