import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface KeyVaultConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly accessPolicy?: KeyVaultAccessPolicy[];
    /**
     * @stability stable
     */
    readonly enableRbacAuthorization?: boolean;
    /**
     * @stability stable
     */
    readonly enabledForDeployment?: boolean;
    /**
     * @stability stable
     */
    readonly enabledForDiskEncryption?: boolean;
    /**
     * @stability stable
     */
    readonly enabledForTemplateDeployment?: boolean;
    /**
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly purgeProtectionEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly skuName: string;
    /**
     * @stability stable
     */
    readonly softDeleteEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly softDeleteRetentionDays?: number;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly tenantId: string;
    /**
     * contact block.
     *
     * @stability stable
     */
    readonly contact?: KeyVaultContact[];
    /**
     * network_acls block.
     *
     * @stability stable
     */
    readonly networkAcls?: KeyVaultNetworkAcls[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: KeyVaultTimeouts;
}
/**
 * @stability stable
 */
export interface KeyVaultAccessPolicy {
    /**
     * @stability stable
     */
    readonly applicationId?: string;
    /**
     * @stability stable
     */
    readonly certificatePermissions?: string[];
    /**
     * @stability stable
     */
    readonly keyPermissions?: string[];
    /**
     * @stability stable
     */
    readonly objectId?: string;
    /**
     * @stability stable
     */
    readonly secretPermissions?: string[];
    /**
     * @stability stable
     */
    readonly storagePermissions?: string[];
    /**
     * @stability stable
     */
    readonly tenantId?: string;
}
/**
 * @stability stable
 */
export interface KeyVaultContact {
    /**
     * @stability stable
     */
    readonly email: string;
    /**
     * @stability stable
     */
    readonly name?: string;
    /**
     * @stability stable
     */
    readonly phone?: string;
}
/**
 * @stability stable
 */
export interface KeyVaultNetworkAcls {
    /**
     * @stability stable
     */
    readonly bypass: string;
    /**
     * @stability stable
     */
    readonly defaultAction: string;
    /**
     * @stability stable
     */
    readonly ipRules?: string[];
    /**
     * @stability stable
     */
    readonly virtualNetworkSubnetIds?: string[];
}
/**
 * @stability stable
 */
export interface KeyVaultTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class KeyVault extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: KeyVaultConfig);
    private _accessPolicy?;
    /**
     * @stability stable
     */
    get accessPolicy(): KeyVaultAccessPolicy[];
    /**
     * @stability stable
     */
    set accessPolicy(value: KeyVaultAccessPolicy[]);
    /**
     * @stability stable
     */
    resetAccessPolicy(): void;
    /**
     * @stability stable
     */
    get accessPolicyInput(): KeyVaultAccessPolicy[] | undefined;
    private _enableRbacAuthorization?;
    /**
     * @stability stable
     */
    get enableRbacAuthorization(): boolean;
    /**
     * @stability stable
     */
    set enableRbacAuthorization(value: boolean);
    /**
     * @stability stable
     */
    resetEnableRbacAuthorization(): void;
    /**
     * @stability stable
     */
    get enableRbacAuthorizationInput(): boolean | undefined;
    private _enabledForDeployment?;
    /**
     * @stability stable
     */
    get enabledForDeployment(): boolean;
    /**
     * @stability stable
     */
    set enabledForDeployment(value: boolean);
    /**
     * @stability stable
     */
    resetEnabledForDeployment(): void;
    /**
     * @stability stable
     */
    get enabledForDeploymentInput(): boolean | undefined;
    private _enabledForDiskEncryption?;
    /**
     * @stability stable
     */
    get enabledForDiskEncryption(): boolean;
    /**
     * @stability stable
     */
    set enabledForDiskEncryption(value: boolean);
    /**
     * @stability stable
     */
    resetEnabledForDiskEncryption(): void;
    /**
     * @stability stable
     */
    get enabledForDiskEncryptionInput(): boolean | undefined;
    private _enabledForTemplateDeployment?;
    /**
     * @stability stable
     */
    get enabledForTemplateDeployment(): boolean;
    /**
     * @stability stable
     */
    set enabledForTemplateDeployment(value: boolean);
    /**
     * @stability stable
     */
    resetEnabledForTemplateDeployment(): void;
    /**
     * @stability stable
     */
    get enabledForTemplateDeploymentInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _purgeProtectionEnabled?;
    /**
     * @stability stable
     */
    get purgeProtectionEnabled(): boolean;
    /**
     * @stability stable
     */
    set purgeProtectionEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetPurgeProtectionEnabled(): void;
    /**
     * @stability stable
     */
    get purgeProtectionEnabledInput(): boolean | undefined;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    private _skuName;
    /**
     * @stability stable
     */
    get skuName(): string;
    /**
     * @stability stable
     */
    set skuName(value: string);
    /**
     * @stability stable
     */
    get skuNameInput(): string;
    private _softDeleteEnabled?;
    /**
     * @stability stable
     */
    get softDeleteEnabled(): boolean;
    /**
     * @stability stable
     */
    set softDeleteEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetSoftDeleteEnabled(): void;
    /**
     * @stability stable
     */
    get softDeleteEnabledInput(): boolean | undefined;
    private _softDeleteRetentionDays?;
    /**
     * @stability stable
     */
    get softDeleteRetentionDays(): number;
    /**
     * @stability stable
     */
    set softDeleteRetentionDays(value: number);
    /**
     * @stability stable
     */
    resetSoftDeleteRetentionDays(): void;
    /**
     * @stability stable
     */
    get softDeleteRetentionDaysInput(): number | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tenantId;
    /**
     * @stability stable
     */
    get tenantId(): string;
    /**
     * @stability stable
     */
    set tenantId(value: string);
    /**
     * @stability stable
     */
    get tenantIdInput(): string;
    /**
     * @stability stable
     */
    get vaultUri(): string;
    private _contact?;
    /**
     * @stability stable
     */
    get contact(): KeyVaultContact[];
    /**
     * @stability stable
     */
    set contact(value: KeyVaultContact[]);
    /**
     * @stability stable
     */
    resetContact(): void;
    /**
     * @stability stable
     */
    get contactInput(): KeyVaultContact[] | undefined;
    private _networkAcls?;
    /**
     * @stability stable
     */
    get networkAcls(): KeyVaultNetworkAcls[];
    /**
     * @stability stable
     */
    set networkAcls(value: KeyVaultNetworkAcls[]);
    /**
     * @stability stable
     */
    resetNetworkAcls(): void;
    /**
     * @stability stable
     */
    get networkAclsInput(): KeyVaultNetworkAcls[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): KeyVaultTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: KeyVaultTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): KeyVaultTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
