import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface KustoClusterConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly doubleEncryptionEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly enableDiskEncryption?: boolean;
    /**
     * @stability stable
     */
    readonly enablePurge?: boolean;
    /**
     * @stability stable
     */
    readonly enableStreamingIngest?: boolean;
    /**
     * @stability stable
     */
    readonly engine?: string;
    /**
     * @stability stable
     */
    readonly languageExtensions?: string[];
    /**
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly trustedExternalTenants?: string[];
    /**
     * @stability stable
     */
    readonly zones?: string[];
    /**
     * identity block.
     *
     * @stability stable
     */
    readonly identity?: KustoClusterIdentity[];
    /**
     * optimized_auto_scale block.
     *
     * @stability stable
     */
    readonly optimizedAutoScale?: KustoClusterOptimizedAutoScale[];
    /**
     * sku block.
     *
     * @stability stable
     */
    readonly sku: KustoClusterSku[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: KustoClusterTimeouts;
    /**
     * virtual_network_configuration block.
     *
     * @stability stable
     */
    readonly virtualNetworkConfiguration?: KustoClusterVirtualNetworkConfiguration[];
}
/**
 * @stability stable
 */
export interface KustoClusterIdentity {
    /**
     * @stability stable
     */
    readonly identityIds?: string[];
    /**
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface KustoClusterOptimizedAutoScale {
    /**
     * @stability stable
     */
    readonly maximumInstances: number;
    /**
     * @stability stable
     */
    readonly minimumInstances: number;
}
/**
 * @stability stable
 */
export interface KustoClusterSku {
    /**
     * @stability stable
     */
    readonly capacity?: number;
    /**
     * @stability stable
     */
    readonly name: string;
}
/**
 * @stability stable
 */
export interface KustoClusterTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export interface KustoClusterVirtualNetworkConfiguration {
    /**
     * @stability stable
     */
    readonly dataManagementPublicIpId: string;
    /**
     * @stability stable
     */
    readonly enginePublicIpId: string;
    /**
     * @stability stable
     */
    readonly subnetId: string;
}
/**
 * @stability stable
 */
export declare class KustoCluster extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: KustoClusterConfig);
    /**
     * @stability stable
     */
    get dataIngestionUri(): string;
    private _doubleEncryptionEnabled?;
    /**
     * @stability stable
     */
    get doubleEncryptionEnabled(): boolean;
    /**
     * @stability stable
     */
    set doubleEncryptionEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetDoubleEncryptionEnabled(): void;
    /**
     * @stability stable
     */
    get doubleEncryptionEnabledInput(): boolean | undefined;
    private _enableDiskEncryption?;
    /**
     * @stability stable
     */
    get enableDiskEncryption(): boolean;
    /**
     * @stability stable
     */
    set enableDiskEncryption(value: boolean);
    /**
     * @stability stable
     */
    resetEnableDiskEncryption(): void;
    /**
     * @stability stable
     */
    get enableDiskEncryptionInput(): boolean | undefined;
    private _enablePurge?;
    /**
     * @stability stable
     */
    get enablePurge(): boolean;
    /**
     * @stability stable
     */
    set enablePurge(value: boolean);
    /**
     * @stability stable
     */
    resetEnablePurge(): void;
    /**
     * @stability stable
     */
    get enablePurgeInput(): boolean | undefined;
    private _enableStreamingIngest?;
    /**
     * @stability stable
     */
    get enableStreamingIngest(): boolean;
    /**
     * @stability stable
     */
    set enableStreamingIngest(value: boolean);
    /**
     * @stability stable
     */
    resetEnableStreamingIngest(): void;
    /**
     * @stability stable
     */
    get enableStreamingIngestInput(): boolean | undefined;
    private _engine?;
    /**
     * @stability stable
     */
    get engine(): string;
    /**
     * @stability stable
     */
    set engine(value: string);
    /**
     * @stability stable
     */
    resetEngine(): void;
    /**
     * @stability stable
     */
    get engineInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _languageExtensions?;
    /**
     * @stability stable
     */
    get languageExtensions(): string[];
    /**
     * @stability stable
     */
    set languageExtensions(value: string[]);
    /**
     * @stability stable
     */
    resetLanguageExtensions(): void;
    /**
     * @stability stable
     */
    get languageExtensionsInput(): string[] | undefined;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _trustedExternalTenants?;
    /**
     * @stability stable
     */
    get trustedExternalTenants(): string[];
    /**
     * @stability stable
     */
    set trustedExternalTenants(value: string[]);
    /**
     * @stability stable
     */
    resetTrustedExternalTenants(): void;
    /**
     * @stability stable
     */
    get trustedExternalTenantsInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get uri(): string;
    private _zones?;
    /**
     * @stability stable
     */
    get zones(): string[];
    /**
     * @stability stable
     */
    set zones(value: string[]);
    /**
     * @stability stable
     */
    resetZones(): void;
    /**
     * @stability stable
     */
    get zonesInput(): string[] | undefined;
    private _identity?;
    /**
     * @stability stable
     */
    get identity(): KustoClusterIdentity[];
    /**
     * @stability stable
     */
    set identity(value: KustoClusterIdentity[]);
    /**
     * @stability stable
     */
    resetIdentity(): void;
    /**
     * @stability stable
     */
    get identityInput(): KustoClusterIdentity[] | undefined;
    private _optimizedAutoScale?;
    /**
     * @stability stable
     */
    get optimizedAutoScale(): KustoClusterOptimizedAutoScale[];
    /**
     * @stability stable
     */
    set optimizedAutoScale(value: KustoClusterOptimizedAutoScale[]);
    /**
     * @stability stable
     */
    resetOptimizedAutoScale(): void;
    /**
     * @stability stable
     */
    get optimizedAutoScaleInput(): KustoClusterOptimizedAutoScale[] | undefined;
    private _sku;
    /**
     * @stability stable
     */
    get sku(): KustoClusterSku[];
    /**
     * @stability stable
     */
    set sku(value: KustoClusterSku[]);
    /**
     * @stability stable
     */
    get skuInput(): KustoClusterSku[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): KustoClusterTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: KustoClusterTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): KustoClusterTimeouts | undefined;
    private _virtualNetworkConfiguration?;
    /**
     * @stability stable
     */
    get virtualNetworkConfiguration(): KustoClusterVirtualNetworkConfiguration[];
    /**
     * @stability stable
     */
    set virtualNetworkConfiguration(value: KustoClusterVirtualNetworkConfiguration[]);
    /**
     * @stability stable
     */
    resetVirtualNetworkConfiguration(): void;
    /**
     * @stability stable
     */
    get virtualNetworkConfigurationInput(): KustoClusterVirtualNetworkConfiguration[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
