import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface MediaStreamingEndpointConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly autoStartEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly cdnEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly cdnProfile?: string;
    /**
     * @stability stable
     */
    readonly cdnProvider?: string;
    /**
     * @stability stable
     */
    readonly customHostNames?: string[];
    /**
     * @stability stable
     */
    readonly description?: string;
    /**
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly maxCacheAgeSeconds?: number;
    /**
     * @stability stable
     */
    readonly mediaServicesAccountName: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly scaleUnits: number;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * access_control block.
     *
     * @stability stable
     */
    readonly accessControl?: MediaStreamingEndpointAccessControl[];
    /**
     * cross_site_access_policy block.
     *
     * @stability stable
     */
    readonly crossSiteAccessPolicy?: MediaStreamingEndpointCrossSiteAccessPolicy[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: MediaStreamingEndpointTimeouts;
}
/**
 * @stability stable
 */
export interface MediaStreamingEndpointAccessControlAkamaiSignatureHeaderAuthenticationKey {
    /**
     * @stability stable
     */
    readonly base64Key?: string;
    /**
     * @stability stable
     */
    readonly expiration?: string;
    /**
     * @stability stable
     */
    readonly identifier?: string;
}
/**
 * @stability stable
 */
export interface MediaStreamingEndpointAccessControlIpAllow {
    /**
     * @stability stable
     */
    readonly address?: string;
    /**
     * @stability stable
     */
    readonly name?: string;
    /**
     * @stability stable
     */
    readonly subnetPrefixLength?: number;
}
/**
 * @stability stable
 */
export interface MediaStreamingEndpointAccessControl {
    /**
     * akamai_signature_header_authentication_key block.
     *
     * @stability stable
     */
    readonly akamaiSignatureHeaderAuthenticationKey?: MediaStreamingEndpointAccessControlAkamaiSignatureHeaderAuthenticationKey[];
    /**
     * ip_allow block.
     *
     * @stability stable
     */
    readonly ipAllow?: MediaStreamingEndpointAccessControlIpAllow[];
}
/**
 * @stability stable
 */
export interface MediaStreamingEndpointCrossSiteAccessPolicy {
    /**
     * @stability stable
     */
    readonly clientAccessPolicy?: string;
    /**
     * @stability stable
     */
    readonly crossDomainPolicy?: string;
}
/**
 * @stability stable
 */
export interface MediaStreamingEndpointTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class MediaStreamingEndpoint extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: MediaStreamingEndpointConfig);
    private _autoStartEnabled?;
    /**
     * @stability stable
     */
    get autoStartEnabled(): boolean;
    /**
     * @stability stable
     */
    set autoStartEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetAutoStartEnabled(): void;
    /**
     * @stability stable
     */
    get autoStartEnabledInput(): boolean | undefined;
    private _cdnEnabled?;
    /**
     * @stability stable
     */
    get cdnEnabled(): boolean;
    /**
     * @stability stable
     */
    set cdnEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetCdnEnabled(): void;
    /**
     * @stability stable
     */
    get cdnEnabledInput(): boolean | undefined;
    private _cdnProfile?;
    /**
     * @stability stable
     */
    get cdnProfile(): string;
    /**
     * @stability stable
     */
    set cdnProfile(value: string);
    /**
     * @stability stable
     */
    resetCdnProfile(): void;
    /**
     * @stability stable
     */
    get cdnProfileInput(): string | undefined;
    private _cdnProvider?;
    /**
     * @stability stable
     */
    get cdnProvider(): string;
    /**
     * @stability stable
     */
    set cdnProvider(value: string);
    /**
     * @stability stable
     */
    resetCdnProvider(): void;
    /**
     * @stability stable
     */
    get cdnProviderInput(): string | undefined;
    private _customHostNames?;
    /**
     * @stability stable
     */
    get customHostNames(): string[];
    /**
     * @stability stable
     */
    set customHostNames(value: string[]);
    /**
     * @stability stable
     */
    resetCustomHostNames(): void;
    /**
     * @stability stable
     */
    get customHostNamesInput(): string[] | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get hostName(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _maxCacheAgeSeconds?;
    /**
     * @stability stable
     */
    get maxCacheAgeSeconds(): number;
    /**
     * @stability stable
     */
    set maxCacheAgeSeconds(value: number);
    /**
     * @stability stable
     */
    resetMaxCacheAgeSeconds(): void;
    /**
     * @stability stable
     */
    get maxCacheAgeSecondsInput(): number | undefined;
    private _mediaServicesAccountName;
    /**
     * @stability stable
     */
    get mediaServicesAccountName(): string;
    /**
     * @stability stable
     */
    set mediaServicesAccountName(value: string);
    /**
     * @stability stable
     */
    get mediaServicesAccountNameInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    private _scaleUnits;
    /**
     * @stability stable
     */
    get scaleUnits(): number;
    /**
     * @stability stable
     */
    set scaleUnits(value: number);
    /**
     * @stability stable
     */
    get scaleUnitsInput(): number;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _accessControl?;
    /**
     * @stability stable
     */
    get accessControl(): MediaStreamingEndpointAccessControl[];
    /**
     * @stability stable
     */
    set accessControl(value: MediaStreamingEndpointAccessControl[]);
    /**
     * @stability stable
     */
    resetAccessControl(): void;
    /**
     * @stability stable
     */
    get accessControlInput(): MediaStreamingEndpointAccessControl[] | undefined;
    private _crossSiteAccessPolicy?;
    /**
     * @stability stable
     */
    get crossSiteAccessPolicy(): MediaStreamingEndpointCrossSiteAccessPolicy[];
    /**
     * @stability stable
     */
    set crossSiteAccessPolicy(value: MediaStreamingEndpointCrossSiteAccessPolicy[]);
    /**
     * @stability stable
     */
    resetCrossSiteAccessPolicy(): void;
    /**
     * @stability stable
     */
    get crossSiteAccessPolicyInput(): MediaStreamingEndpointCrossSiteAccessPolicy[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): MediaStreamingEndpointTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: MediaStreamingEndpointTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): MediaStreamingEndpointTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
