import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface MediaStreamingPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly defaultContentKeyPolicyName?: string;
    /**
     * @stability stable
     */
    readonly mediaServicesAccountName: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * common_encryption_cbcs block.
     *
     * @stability stable
     */
    readonly commonEncryptionCbcs?: MediaStreamingPolicyCommonEncryptionCbcs[];
    /**
     * common_encryption_cenc block.
     *
     * @stability stable
     */
    readonly commonEncryptionCenc?: MediaStreamingPolicyCommonEncryptionCenc[];
    /**
     * no_encryption_enabled_protocols block.
     *
     * @stability stable
     */
    readonly noEncryptionEnabledProtocols?: MediaStreamingPolicyNoEncryptionEnabledProtocols[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: MediaStreamingPolicyTimeouts;
}
/**
 * @stability stable
 */
export interface MediaStreamingPolicyCommonEncryptionCbcsDefaultContentKey {
    /**
     * @stability stable
     */
    readonly label?: string;
    /**
     * @stability stable
     */
    readonly policyName?: string;
}
/**
 * @stability stable
 */
export interface MediaStreamingPolicyCommonEncryptionCbcsDrmFairplay {
    /**
     * @stability stable
     */
    readonly allowPersistentLicense?: boolean;
    /**
     * @stability stable
     */
    readonly customLicenseAcquisitionUrlTemplate?: string;
}
/**
 * @stability stable
 */
export interface MediaStreamingPolicyCommonEncryptionCbcsEnabledProtocols {
    /**
     * @stability stable
     */
    readonly dash?: boolean;
    /**
     * @stability stable
     */
    readonly download?: boolean;
    /**
     * @stability stable
     */
    readonly hls?: boolean;
    /**
     * @stability stable
     */
    readonly smoothStreaming?: boolean;
}
/**
 * @stability stable
 */
export interface MediaStreamingPolicyCommonEncryptionCbcs {
    /**
     * default_content_key block.
     *
     * @stability stable
     */
    readonly defaultContentKey?: MediaStreamingPolicyCommonEncryptionCbcsDefaultContentKey[];
    /**
     * drm_fairplay block.
     *
     * @stability stable
     */
    readonly drmFairplay?: MediaStreamingPolicyCommonEncryptionCbcsDrmFairplay[];
    /**
     * enabled_protocols block.
     *
     * @stability stable
     */
    readonly enabledProtocols?: MediaStreamingPolicyCommonEncryptionCbcsEnabledProtocols[];
}
/**
 * @stability stable
 */
export interface MediaStreamingPolicyCommonEncryptionCencDefaultContentKey {
    /**
     * @stability stable
     */
    readonly label?: string;
    /**
     * @stability stable
     */
    readonly policyName?: string;
}
/**
 * @stability stable
 */
export interface MediaStreamingPolicyCommonEncryptionCencDrmPlayready {
    /**
     * @stability stable
     */
    readonly customAttributes?: string;
    /**
     * @stability stable
     */
    readonly customLicenseAcquisitionUrlTemplate?: string;
}
/**
 * @stability stable
 */
export interface MediaStreamingPolicyCommonEncryptionCencEnabledProtocols {
    /**
     * @stability stable
     */
    readonly dash?: boolean;
    /**
     * @stability stable
     */
    readonly download?: boolean;
    /**
     * @stability stable
     */
    readonly hls?: boolean;
    /**
     * @stability stable
     */
    readonly smoothStreaming?: boolean;
}
/**
 * @stability stable
 */
export interface MediaStreamingPolicyCommonEncryptionCenc {
    /**
     * @stability stable
     */
    readonly drmWidevineCustomLicenseAcquisitionUrlTemplate?: string;
    /**
     * default_content_key block.
     *
     * @stability stable
     */
    readonly defaultContentKey?: MediaStreamingPolicyCommonEncryptionCencDefaultContentKey[];
    /**
     * drm_playready block.
     *
     * @stability stable
     */
    readonly drmPlayready?: MediaStreamingPolicyCommonEncryptionCencDrmPlayready[];
    /**
     * enabled_protocols block.
     *
     * @stability stable
     */
    readonly enabledProtocols?: MediaStreamingPolicyCommonEncryptionCencEnabledProtocols[];
}
/**
 * @stability stable
 */
export interface MediaStreamingPolicyNoEncryptionEnabledProtocols {
    /**
     * @stability stable
     */
    readonly dash?: boolean;
    /**
     * @stability stable
     */
    readonly download?: boolean;
    /**
     * @stability stable
     */
    readonly hls?: boolean;
    /**
     * @stability stable
     */
    readonly smoothStreaming?: boolean;
}
/**
 * @stability stable
 */
export interface MediaStreamingPolicyTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
}
/**
 * @stability stable
 */
export declare class MediaStreamingPolicy extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: MediaStreamingPolicyConfig);
    private _defaultContentKeyPolicyName?;
    /**
     * @stability stable
     */
    get defaultContentKeyPolicyName(): string;
    /**
     * @stability stable
     */
    set defaultContentKeyPolicyName(value: string);
    /**
     * @stability stable
     */
    resetDefaultContentKeyPolicyName(): void;
    /**
     * @stability stable
     */
    get defaultContentKeyPolicyNameInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _mediaServicesAccountName;
    /**
     * @stability stable
     */
    get mediaServicesAccountName(): string;
    /**
     * @stability stable
     */
    set mediaServicesAccountName(value: string);
    /**
     * @stability stable
     */
    get mediaServicesAccountNameInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    private _commonEncryptionCbcs?;
    /**
     * @stability stable
     */
    get commonEncryptionCbcs(): MediaStreamingPolicyCommonEncryptionCbcs[];
    /**
     * @stability stable
     */
    set commonEncryptionCbcs(value: MediaStreamingPolicyCommonEncryptionCbcs[]);
    /**
     * @stability stable
     */
    resetCommonEncryptionCbcs(): void;
    /**
     * @stability stable
     */
    get commonEncryptionCbcsInput(): MediaStreamingPolicyCommonEncryptionCbcs[] | undefined;
    private _commonEncryptionCenc?;
    /**
     * @stability stable
     */
    get commonEncryptionCenc(): MediaStreamingPolicyCommonEncryptionCenc[];
    /**
     * @stability stable
     */
    set commonEncryptionCenc(value: MediaStreamingPolicyCommonEncryptionCenc[]);
    /**
     * @stability stable
     */
    resetCommonEncryptionCenc(): void;
    /**
     * @stability stable
     */
    get commonEncryptionCencInput(): MediaStreamingPolicyCommonEncryptionCenc[] | undefined;
    private _noEncryptionEnabledProtocols?;
    /**
     * @stability stable
     */
    get noEncryptionEnabledProtocols(): MediaStreamingPolicyNoEncryptionEnabledProtocols[];
    /**
     * @stability stable
     */
    set noEncryptionEnabledProtocols(value: MediaStreamingPolicyNoEncryptionEnabledProtocols[]);
    /**
     * @stability stable
     */
    resetNoEncryptionEnabledProtocols(): void;
    /**
     * @stability stable
     */
    get noEncryptionEnabledProtocolsInput(): MediaStreamingPolicyNoEncryptionEnabledProtocols[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): MediaStreamingPolicyTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: MediaStreamingPolicyTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): MediaStreamingPolicyTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
