import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface MssqlDatabaseConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly autoPauseDelayInMinutes?: number;
    /**
     * @stability stable
     */
    readonly collation?: string;
    /**
     * @stability stable
     */
    readonly createMode?: string;
    /**
     * @stability stable
     */
    readonly creationSourceDatabaseId?: string;
    /**
     * @stability stable
     */
    readonly elasticPoolId?: string;
    /**
     * @stability stable
     */
    readonly extendedAuditingPolicy?: MssqlDatabaseExtendedAuditingPolicy[];
    /**
     * @stability stable
     */
    readonly geoBackupEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly licenseType?: string;
    /**
     * @stability stable
     */
    readonly maxSizeGb?: number;
    /**
     * @stability stable
     */
    readonly minCapacity?: number;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly readReplicaCount?: number;
    /**
     * @stability stable
     */
    readonly readScale?: boolean;
    /**
     * @stability stable
     */
    readonly recoverDatabaseId?: string;
    /**
     * @stability stable
     */
    readonly restoreDroppedDatabaseId?: string;
    /**
     * @stability stable
     */
    readonly restorePointInTime?: string;
    /**
     * @stability stable
     */
    readonly sampleName?: string;
    /**
     * @stability stable
     */
    readonly serverId: string;
    /**
     * @stability stable
     */
    readonly skuName?: string;
    /**
     * @stability stable
     */
    readonly storageAccountType?: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly zoneRedundant?: boolean;
    /**
     * long_term_retention_policy block.
     *
     * @stability stable
     */
    readonly longTermRetentionPolicy?: MssqlDatabaseLongTermRetentionPolicy[];
    /**
     * short_term_retention_policy block.
     *
     * @stability stable
     */
    readonly shortTermRetentionPolicy?: MssqlDatabaseShortTermRetentionPolicy[];
    /**
     * threat_detection_policy block.
     *
     * @stability stable
     */
    readonly threatDetectionPolicy?: MssqlDatabaseThreatDetectionPolicy[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: MssqlDatabaseTimeouts;
}
/**
 * @stability stable
 */
export interface MssqlDatabaseExtendedAuditingPolicy {
    /**
     * @stability stable
     */
    readonly logMonitoringEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly retentionInDays?: number;
    /**
     * @stability stable
     */
    readonly storageAccountAccessKey?: string;
    /**
     * @stability stable
     */
    readonly storageAccountAccessKeyIsSecondary?: boolean;
    /**
     * @stability stable
     */
    readonly storageEndpoint?: string;
}
/**
 * @stability stable
 */
export interface MssqlDatabaseLongTermRetentionPolicy {
    /**
     * @stability stable
     */
    readonly monthlyRetention?: string;
    /**
     * @stability stable
     */
    readonly weekOfYear?: number;
    /**
     * @stability stable
     */
    readonly weeklyRetention?: string;
    /**
     * @stability stable
     */
    readonly yearlyRetention?: string;
}
/**
 * @stability stable
 */
export interface MssqlDatabaseShortTermRetentionPolicy {
    /**
     * @stability stable
     */
    readonly retentionDays: number;
}
/**
 * @stability stable
 */
export interface MssqlDatabaseThreatDetectionPolicy {
    /**
     * @stability stable
     */
    readonly disabledAlerts?: string[];
    /**
     * @stability stable
     */
    readonly emailAccountAdmins?: string;
    /**
     * @stability stable
     */
    readonly emailAddresses?: string[];
    /**
     * @stability stable
     */
    readonly retentionDays?: number;
    /**
     * @stability stable
     */
    readonly state?: string;
    /**
     * @stability stable
     */
    readonly storageAccountAccessKey?: string;
    /**
     * @stability stable
     */
    readonly storageEndpoint?: string;
    /**
     * @stability stable
     */
    readonly useServerDefault?: string;
}
/**
 * @stability stable
 */
export interface MssqlDatabaseTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class MssqlDatabase extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: MssqlDatabaseConfig);
    private _autoPauseDelayInMinutes?;
    /**
     * @stability stable
     */
    get autoPauseDelayInMinutes(): number;
    /**
     * @stability stable
     */
    set autoPauseDelayInMinutes(value: number);
    /**
     * @stability stable
     */
    resetAutoPauseDelayInMinutes(): void;
    /**
     * @stability stable
     */
    get autoPauseDelayInMinutesInput(): number | undefined;
    private _collation?;
    /**
     * @stability stable
     */
    get collation(): string;
    /**
     * @stability stable
     */
    set collation(value: string);
    /**
     * @stability stable
     */
    resetCollation(): void;
    /**
     * @stability stable
     */
    get collationInput(): string | undefined;
    private _createMode?;
    /**
     * @stability stable
     */
    get createMode(): string;
    /**
     * @stability stable
     */
    set createMode(value: string);
    /**
     * @stability stable
     */
    resetCreateMode(): void;
    /**
     * @stability stable
     */
    get createModeInput(): string | undefined;
    private _creationSourceDatabaseId?;
    /**
     * @stability stable
     */
    get creationSourceDatabaseId(): string;
    /**
     * @stability stable
     */
    set creationSourceDatabaseId(value: string);
    /**
     * @stability stable
     */
    resetCreationSourceDatabaseId(): void;
    /**
     * @stability stable
     */
    get creationSourceDatabaseIdInput(): string | undefined;
    private _elasticPoolId?;
    /**
     * @stability stable
     */
    get elasticPoolId(): string;
    /**
     * @stability stable
     */
    set elasticPoolId(value: string);
    /**
     * @stability stable
     */
    resetElasticPoolId(): void;
    /**
     * @stability stable
     */
    get elasticPoolIdInput(): string | undefined;
    private _extendedAuditingPolicy?;
    /**
     * @stability stable
     */
    get extendedAuditingPolicy(): MssqlDatabaseExtendedAuditingPolicy[];
    /**
     * @stability stable
     */
    set extendedAuditingPolicy(value: MssqlDatabaseExtendedAuditingPolicy[]);
    /**
     * @stability stable
     */
    resetExtendedAuditingPolicy(): void;
    /**
     * @stability stable
     */
    get extendedAuditingPolicyInput(): MssqlDatabaseExtendedAuditingPolicy[] | undefined;
    private _geoBackupEnabled?;
    /**
     * @stability stable
     */
    get geoBackupEnabled(): boolean;
    /**
     * @stability stable
     */
    set geoBackupEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetGeoBackupEnabled(): void;
    /**
     * @stability stable
     */
    get geoBackupEnabledInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _licenseType?;
    /**
     * @stability stable
     */
    get licenseType(): string;
    /**
     * @stability stable
     */
    set licenseType(value: string);
    /**
     * @stability stable
     */
    resetLicenseType(): void;
    /**
     * @stability stable
     */
    get licenseTypeInput(): string | undefined;
    private _maxSizeGb?;
    /**
     * @stability stable
     */
    get maxSizeGb(): number;
    /**
     * @stability stable
     */
    set maxSizeGb(value: number);
    /**
     * @stability stable
     */
    resetMaxSizeGb(): void;
    /**
     * @stability stable
     */
    get maxSizeGbInput(): number | undefined;
    private _minCapacity?;
    /**
     * @stability stable
     */
    get minCapacity(): number;
    /**
     * @stability stable
     */
    set minCapacity(value: number);
    /**
     * @stability stable
     */
    resetMinCapacity(): void;
    /**
     * @stability stable
     */
    get minCapacityInput(): number | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _readReplicaCount?;
    /**
     * @stability stable
     */
    get readReplicaCount(): number;
    /**
     * @stability stable
     */
    set readReplicaCount(value: number);
    /**
     * @stability stable
     */
    resetReadReplicaCount(): void;
    /**
     * @stability stable
     */
    get readReplicaCountInput(): number | undefined;
    private _readScale?;
    /**
     * @stability stable
     */
    get readScale(): boolean;
    /**
     * @stability stable
     */
    set readScale(value: boolean);
    /**
     * @stability stable
     */
    resetReadScale(): void;
    /**
     * @stability stable
     */
    get readScaleInput(): boolean | undefined;
    private _recoverDatabaseId?;
    /**
     * @stability stable
     */
    get recoverDatabaseId(): string;
    /**
     * @stability stable
     */
    set recoverDatabaseId(value: string);
    /**
     * @stability stable
     */
    resetRecoverDatabaseId(): void;
    /**
     * @stability stable
     */
    get recoverDatabaseIdInput(): string | undefined;
    private _restoreDroppedDatabaseId?;
    /**
     * @stability stable
     */
    get restoreDroppedDatabaseId(): string;
    /**
     * @stability stable
     */
    set restoreDroppedDatabaseId(value: string);
    /**
     * @stability stable
     */
    resetRestoreDroppedDatabaseId(): void;
    /**
     * @stability stable
     */
    get restoreDroppedDatabaseIdInput(): string | undefined;
    private _restorePointInTime?;
    /**
     * @stability stable
     */
    get restorePointInTime(): string;
    /**
     * @stability stable
     */
    set restorePointInTime(value: string);
    /**
     * @stability stable
     */
    resetRestorePointInTime(): void;
    /**
     * @stability stable
     */
    get restorePointInTimeInput(): string | undefined;
    private _sampleName?;
    /**
     * @stability stable
     */
    get sampleName(): string;
    /**
     * @stability stable
     */
    set sampleName(value: string);
    /**
     * @stability stable
     */
    resetSampleName(): void;
    /**
     * @stability stable
     */
    get sampleNameInput(): string | undefined;
    private _serverId;
    /**
     * @stability stable
     */
    get serverId(): string;
    /**
     * @stability stable
     */
    set serverId(value: string);
    /**
     * @stability stable
     */
    get serverIdInput(): string;
    private _skuName?;
    /**
     * @stability stable
     */
    get skuName(): string;
    /**
     * @stability stable
     */
    set skuName(value: string);
    /**
     * @stability stable
     */
    resetSkuName(): void;
    /**
     * @stability stable
     */
    get skuNameInput(): string | undefined;
    private _storageAccountType?;
    /**
     * @stability stable
     */
    get storageAccountType(): string;
    /**
     * @stability stable
     */
    set storageAccountType(value: string);
    /**
     * @stability stable
     */
    resetStorageAccountType(): void;
    /**
     * @stability stable
     */
    get storageAccountTypeInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _zoneRedundant?;
    /**
     * @stability stable
     */
    get zoneRedundant(): boolean;
    /**
     * @stability stable
     */
    set zoneRedundant(value: boolean);
    /**
     * @stability stable
     */
    resetZoneRedundant(): void;
    /**
     * @stability stable
     */
    get zoneRedundantInput(): boolean | undefined;
    private _longTermRetentionPolicy?;
    /**
     * @stability stable
     */
    get longTermRetentionPolicy(): MssqlDatabaseLongTermRetentionPolicy[];
    /**
     * @stability stable
     */
    set longTermRetentionPolicy(value: MssqlDatabaseLongTermRetentionPolicy[]);
    /**
     * @stability stable
     */
    resetLongTermRetentionPolicy(): void;
    /**
     * @stability stable
     */
    get longTermRetentionPolicyInput(): MssqlDatabaseLongTermRetentionPolicy[] | undefined;
    private _shortTermRetentionPolicy?;
    /**
     * @stability stable
     */
    get shortTermRetentionPolicy(): MssqlDatabaseShortTermRetentionPolicy[];
    /**
     * @stability stable
     */
    set shortTermRetentionPolicy(value: MssqlDatabaseShortTermRetentionPolicy[]);
    /**
     * @stability stable
     */
    resetShortTermRetentionPolicy(): void;
    /**
     * @stability stable
     */
    get shortTermRetentionPolicyInput(): MssqlDatabaseShortTermRetentionPolicy[] | undefined;
    private _threatDetectionPolicy?;
    /**
     * @stability stable
     */
    get threatDetectionPolicy(): MssqlDatabaseThreatDetectionPolicy[];
    /**
     * @stability stable
     */
    set threatDetectionPolicy(value: MssqlDatabaseThreatDetectionPolicy[]);
    /**
     * @stability stable
     */
    resetThreatDetectionPolicy(): void;
    /**
     * @stability stable
     */
    get threatDetectionPolicyInput(): MssqlDatabaseThreatDetectionPolicy[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): MssqlDatabaseTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: MssqlDatabaseTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): MssqlDatabaseTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
