import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface MssqlServerConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly administratorLogin: string;
    /**
     * @stability stable
     */
    readonly administratorLoginPassword: string;
    /**
     * @stability stable
     */
    readonly connectionPolicy?: string;
    /**
     * @stability stable
     */
    readonly extendedAuditingPolicy?: MssqlServerExtendedAuditingPolicy[];
    /**
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly minimumTlsVersion?: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly publicNetworkAccessEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly version: string;
    /**
     * azuread_administrator block.
     *
     * @stability stable
     */
    readonly azureadAdministrator?: MssqlServerAzureadAdministrator[];
    /**
     * identity block.
     *
     * @stability stable
     */
    readonly identity?: MssqlServerIdentity[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: MssqlServerTimeouts;
}
/**
 * @stability stable
 */
export interface MssqlServerExtendedAuditingPolicy {
    /**
     * @stability stable
     */
    readonly logMonitoringEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly retentionInDays?: number;
    /**
     * @stability stable
     */
    readonly storageAccountAccessKey?: string;
    /**
     * @stability stable
     */
    readonly storageAccountAccessKeyIsSecondary?: boolean;
    /**
     * @stability stable
     */
    readonly storageEndpoint?: string;
}
/**
 * @stability stable
 */
export interface MssqlServerAzureadAdministrator {
    /**
     * @stability stable
     */
    readonly loginUsername: string;
    /**
     * @stability stable
     */
    readonly objectId: string;
    /**
     * @stability stable
     */
    readonly tenantId?: string;
}
/**
 * @stability stable
 */
export interface MssqlServerIdentity {
    /**
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface MssqlServerTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class MssqlServer extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: MssqlServerConfig);
    private _administratorLogin;
    /**
     * @stability stable
     */
    get administratorLogin(): string;
    /**
     * @stability stable
     */
    set administratorLogin(value: string);
    /**
     * @stability stable
     */
    get administratorLoginInput(): string;
    private _administratorLoginPassword;
    /**
     * @stability stable
     */
    get administratorLoginPassword(): string;
    /**
     * @stability stable
     */
    set administratorLoginPassword(value: string);
    /**
     * @stability stable
     */
    get administratorLoginPasswordInput(): string;
    private _connectionPolicy?;
    /**
     * @stability stable
     */
    get connectionPolicy(): string;
    /**
     * @stability stable
     */
    set connectionPolicy(value: string);
    /**
     * @stability stable
     */
    resetConnectionPolicy(): void;
    /**
     * @stability stable
     */
    get connectionPolicyInput(): string | undefined;
    private _extendedAuditingPolicy?;
    /**
     * @stability stable
     */
    get extendedAuditingPolicy(): MssqlServerExtendedAuditingPolicy[];
    /**
     * @stability stable
     */
    set extendedAuditingPolicy(value: MssqlServerExtendedAuditingPolicy[]);
    /**
     * @stability stable
     */
    resetExtendedAuditingPolicy(): void;
    /**
     * @stability stable
     */
    get extendedAuditingPolicyInput(): MssqlServerExtendedAuditingPolicy[] | undefined;
    /**
     * @stability stable
     */
    get fullyQualifiedDomainName(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _minimumTlsVersion?;
    /**
     * @stability stable
     */
    get minimumTlsVersion(): string;
    /**
     * @stability stable
     */
    set minimumTlsVersion(value: string);
    /**
     * @stability stable
     */
    resetMinimumTlsVersion(): void;
    /**
     * @stability stable
     */
    get minimumTlsVersionInput(): string | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _publicNetworkAccessEnabled?;
    /**
     * @stability stable
     */
    get publicNetworkAccessEnabled(): boolean;
    /**
     * @stability stable
     */
    set publicNetworkAccessEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetPublicNetworkAccessEnabled(): void;
    /**
     * @stability stable
     */
    get publicNetworkAccessEnabledInput(): boolean | undefined;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    /**
     * @stability stable
     */
    get restorableDroppedDatabaseIds(): string[];
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _version;
    /**
     * @stability stable
     */
    get version(): string;
    /**
     * @stability stable
     */
    set version(value: string);
    /**
     * @stability stable
     */
    get versionInput(): string;
    private _azureadAdministrator?;
    /**
     * @stability stable
     */
    get azureadAdministrator(): MssqlServerAzureadAdministrator[];
    /**
     * @stability stable
     */
    set azureadAdministrator(value: MssqlServerAzureadAdministrator[]);
    /**
     * @stability stable
     */
    resetAzureadAdministrator(): void;
    /**
     * @stability stable
     */
    get azureadAdministratorInput(): MssqlServerAzureadAdministrator[] | undefined;
    private _identity?;
    /**
     * @stability stable
     */
    get identity(): MssqlServerIdentity[];
    /**
     * @stability stable
     */
    set identity(value: MssqlServerIdentity[]);
    /**
     * @stability stable
     */
    resetIdentity(): void;
    /**
     * @stability stable
     */
    get identityInput(): MssqlServerIdentity[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): MssqlServerTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: MssqlServerTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): MssqlServerTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
