import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface MssqlVirtualMachineConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly rServicesEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly sqlConnectivityPort?: number;
    /**
     * @stability stable
     */
    readonly sqlConnectivityType?: string;
    /**
     * @stability stable
     */
    readonly sqlConnectivityUpdatePassword?: string;
    /**
     * @stability stable
     */
    readonly sqlConnectivityUpdateUsername?: string;
    /**
     * @stability stable
     */
    readonly sqlLicenseType: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly virtualMachineId: string;
    /**
     * auto_backup block.
     *
     * @stability stable
     */
    readonly autoBackup?: MssqlVirtualMachineAutoBackup[];
    /**
     * auto_patching block.
     *
     * @stability stable
     */
    readonly autoPatching?: MssqlVirtualMachineAutoPatching[];
    /**
     * key_vault_credential block.
     *
     * @stability stable
     */
    readonly keyVaultCredential?: MssqlVirtualMachineKeyVaultCredential[];
    /**
     * storage_configuration block.
     *
     * @stability stable
     */
    readonly storageConfiguration?: MssqlVirtualMachineStorageConfiguration[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: MssqlVirtualMachineTimeouts;
}
/**
 * @stability stable
 */
export interface MssqlVirtualMachineAutoBackupManualSchedule {
    /**
     * @stability stable
     */
    readonly fullBackupFrequency: string;
    /**
     * @stability stable
     */
    readonly fullBackupStartHour: number;
    /**
     * @stability stable
     */
    readonly fullBackupWindowInHours: number;
    /**
     * @stability stable
     */
    readonly logBackupFrequencyInMinutes: number;
}
/**
 * @stability stable
 */
export interface MssqlVirtualMachineAutoBackup {
    /**
     * @stability stable
     */
    readonly encryptionEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly encryptionPassword?: string;
    /**
     * @stability stable
     */
    readonly retentionPeriodInDays: number;
    /**
     * @stability stable
     */
    readonly storageAccountAccessKey: string;
    /**
     * @stability stable
     */
    readonly storageBlobEndpoint: string;
    /**
     * @stability stable
     */
    readonly systemDatabasesBackupEnabled?: boolean;
    /**
     * manual_schedule block.
     *
     * @stability stable
     */
    readonly manualSchedule?: MssqlVirtualMachineAutoBackupManualSchedule[];
}
/**
 * @stability stable
 */
export interface MssqlVirtualMachineAutoPatching {
    /**
     * @stability stable
     */
    readonly dayOfWeek: string;
    /**
     * @stability stable
     */
    readonly maintenanceWindowDurationInMinutes: number;
    /**
     * @stability stable
     */
    readonly maintenanceWindowStartingHour: number;
}
/**
 * @stability stable
 */
export interface MssqlVirtualMachineKeyVaultCredential {
    /**
     * @stability stable
     */
    readonly keyVaultUrl: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly servicePrincipalName: string;
    /**
     * @stability stable
     */
    readonly servicePrincipalSecret: string;
}
/**
 * @stability stable
 */
export interface MssqlVirtualMachineStorageConfigurationDataSettings {
    /**
     * @stability stable
     */
    readonly defaultFilePath: string;
    /**
     * @stability stable
     */
    readonly luns: number[];
}
/**
 * @stability stable
 */
export interface MssqlVirtualMachineStorageConfigurationLogSettings {
    /**
     * @stability stable
     */
    readonly defaultFilePath: string;
    /**
     * @stability stable
     */
    readonly luns: number[];
}
/**
 * @stability stable
 */
export interface MssqlVirtualMachineStorageConfigurationTempDbSettings {
    /**
     * @stability stable
     */
    readonly defaultFilePath: string;
    /**
     * @stability stable
     */
    readonly luns: number[];
}
/**
 * @stability stable
 */
export interface MssqlVirtualMachineStorageConfiguration {
    /**
     * @stability stable
     */
    readonly diskType: string;
    /**
     * @stability stable
     */
    readonly storageWorkloadType: string;
    /**
     * data_settings block.
     *
     * @stability stable
     */
    readonly dataSettings?: MssqlVirtualMachineStorageConfigurationDataSettings[];
    /**
     * log_settings block.
     *
     * @stability stable
     */
    readonly logSettings?: MssqlVirtualMachineStorageConfigurationLogSettings[];
    /**
     * temp_db_settings block.
     *
     * @stability stable
     */
    readonly tempDbSettings?: MssqlVirtualMachineStorageConfigurationTempDbSettings[];
}
/**
 * @stability stable
 */
export interface MssqlVirtualMachineTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class MssqlVirtualMachine extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: MssqlVirtualMachineConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _rServicesEnabled?;
    /**
     * @stability stable
     */
    get rServicesEnabled(): boolean;
    /**
     * @stability stable
     */
    set rServicesEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetRServicesEnabled(): void;
    /**
     * @stability stable
     */
    get rServicesEnabledInput(): boolean | undefined;
    private _sqlConnectivityPort?;
    /**
     * @stability stable
     */
    get sqlConnectivityPort(): number;
    /**
     * @stability stable
     */
    set sqlConnectivityPort(value: number);
    /**
     * @stability stable
     */
    resetSqlConnectivityPort(): void;
    /**
     * @stability stable
     */
    get sqlConnectivityPortInput(): number | undefined;
    private _sqlConnectivityType?;
    /**
     * @stability stable
     */
    get sqlConnectivityType(): string;
    /**
     * @stability stable
     */
    set sqlConnectivityType(value: string);
    /**
     * @stability stable
     */
    resetSqlConnectivityType(): void;
    /**
     * @stability stable
     */
    get sqlConnectivityTypeInput(): string | undefined;
    private _sqlConnectivityUpdatePassword?;
    /**
     * @stability stable
     */
    get sqlConnectivityUpdatePassword(): string;
    /**
     * @stability stable
     */
    set sqlConnectivityUpdatePassword(value: string);
    /**
     * @stability stable
     */
    resetSqlConnectivityUpdatePassword(): void;
    /**
     * @stability stable
     */
    get sqlConnectivityUpdatePasswordInput(): string | undefined;
    private _sqlConnectivityUpdateUsername?;
    /**
     * @stability stable
     */
    get sqlConnectivityUpdateUsername(): string;
    /**
     * @stability stable
     */
    set sqlConnectivityUpdateUsername(value: string);
    /**
     * @stability stable
     */
    resetSqlConnectivityUpdateUsername(): void;
    /**
     * @stability stable
     */
    get sqlConnectivityUpdateUsernameInput(): string | undefined;
    private _sqlLicenseType;
    /**
     * @stability stable
     */
    get sqlLicenseType(): string;
    /**
     * @stability stable
     */
    set sqlLicenseType(value: string);
    /**
     * @stability stable
     */
    get sqlLicenseTypeInput(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _virtualMachineId;
    /**
     * @stability stable
     */
    get virtualMachineId(): string;
    /**
     * @stability stable
     */
    set virtualMachineId(value: string);
    /**
     * @stability stable
     */
    get virtualMachineIdInput(): string;
    private _autoBackup?;
    /**
     * @stability stable
     */
    get autoBackup(): MssqlVirtualMachineAutoBackup[];
    /**
     * @stability stable
     */
    set autoBackup(value: MssqlVirtualMachineAutoBackup[]);
    /**
     * @stability stable
     */
    resetAutoBackup(): void;
    /**
     * @stability stable
     */
    get autoBackupInput(): MssqlVirtualMachineAutoBackup[] | undefined;
    private _autoPatching?;
    /**
     * @stability stable
     */
    get autoPatching(): MssqlVirtualMachineAutoPatching[];
    /**
     * @stability stable
     */
    set autoPatching(value: MssqlVirtualMachineAutoPatching[]);
    /**
     * @stability stable
     */
    resetAutoPatching(): void;
    /**
     * @stability stable
     */
    get autoPatchingInput(): MssqlVirtualMachineAutoPatching[] | undefined;
    private _keyVaultCredential?;
    /**
     * @stability stable
     */
    get keyVaultCredential(): MssqlVirtualMachineKeyVaultCredential[];
    /**
     * @stability stable
     */
    set keyVaultCredential(value: MssqlVirtualMachineKeyVaultCredential[]);
    /**
     * @stability stable
     */
    resetKeyVaultCredential(): void;
    /**
     * @stability stable
     */
    get keyVaultCredentialInput(): MssqlVirtualMachineKeyVaultCredential[] | undefined;
    private _storageConfiguration?;
    /**
     * @stability stable
     */
    get storageConfiguration(): MssqlVirtualMachineStorageConfiguration[];
    /**
     * @stability stable
     */
    set storageConfiguration(value: MssqlVirtualMachineStorageConfiguration[]);
    /**
     * @stability stable
     */
    resetStorageConfiguration(): void;
    /**
     * @stability stable
     */
    get storageConfigurationInput(): MssqlVirtualMachineStorageConfiguration[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): MssqlVirtualMachineTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: MssqlVirtualMachineTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): MssqlVirtualMachineTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
