import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface NetworkConnectionMonitorConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly autoStart?: boolean;
    /**
     * @stability stable
     */
    readonly intervalInSeconds?: number;
    /**
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly networkWatcherId: string;
    /**
     * @stability stable
     */
    readonly notes?: string;
    /**
     * @stability stable
     */
    readonly outputWorkspaceResourceIds?: string[];
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * destination block.
     *
     * @stability stable
     */
    readonly destination?: NetworkConnectionMonitorDestination[];
    /**
     * endpoint block.
     *
     * @stability stable
     */
    readonly endpoint: NetworkConnectionMonitorEndpoint[];
    /**
     * source block.
     *
     * @stability stable
     */
    readonly source?: NetworkConnectionMonitorSource[];
    /**
     * test_configuration block.
     *
     * @stability stable
     */
    readonly testConfiguration: NetworkConnectionMonitorTestConfiguration[];
    /**
     * test_group block.
     *
     * @stability stable
     */
    readonly testGroup: NetworkConnectionMonitorTestGroup[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: NetworkConnectionMonitorTimeouts;
}
/**
 * @stability stable
 */
export interface NetworkConnectionMonitorDestination {
    /**
     * @stability stable
     */
    readonly address?: string;
    /**
     * @stability stable
     */
    readonly port?: number;
    /**
     * @stability stable
     */
    readonly virtualMachineId?: string;
}
/**
 * @stability stable
 */
export interface NetworkConnectionMonitorEndpointFilterItem {
    /**
     * @stability stable
     */
    readonly address?: string;
    /**
     * @stability stable
     */
    readonly type?: string;
}
/**
 * @stability stable
 */
export interface NetworkConnectionMonitorEndpointFilter {
    /**
     * @stability stable
     */
    readonly type?: string;
    /**
     * item block.
     *
     * @stability stable
     */
    readonly item?: NetworkConnectionMonitorEndpointFilterItem[];
}
/**
 * @stability stable
 */
export interface NetworkConnectionMonitorEndpoint {
    /**
     * @stability stable
     */
    readonly address?: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly virtualMachineId?: string;
    /**
     * filter block.
     *
     * @stability stable
     */
    readonly filter?: NetworkConnectionMonitorEndpointFilter[];
}
/**
 * @stability stable
 */
export interface NetworkConnectionMonitorSource {
    /**
     * @stability stable
     */
    readonly port?: number;
    /**
     * @stability stable
     */
    readonly virtualMachineId?: string;
}
/**
 * @stability stable
 */
export interface NetworkConnectionMonitorTestConfigurationHttpConfigurationRequestHeader {
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly value: string;
}
/**
 * @stability stable
 */
export interface NetworkConnectionMonitorTestConfigurationHttpConfiguration {
    /**
     * @stability stable
     */
    readonly method?: string;
    /**
     * @stability stable
     */
    readonly path?: string;
    /**
     * @stability stable
     */
    readonly port?: number;
    /**
     * @stability stable
     */
    readonly preferHttps?: boolean;
    /**
     * @stability stable
     */
    readonly validStatusCodeRanges?: string[];
    /**
     * request_header block.
     *
     * @stability stable
     */
    readonly requestHeader?: NetworkConnectionMonitorTestConfigurationHttpConfigurationRequestHeader[];
}
/**
 * @stability stable
 */
export interface NetworkConnectionMonitorTestConfigurationIcmpConfiguration {
    /**
     * @stability stable
     */
    readonly traceRouteEnabled?: boolean;
}
/**
 * @stability stable
 */
export interface NetworkConnectionMonitorTestConfigurationSuccessThreshold {
    /**
     * @stability stable
     */
    readonly checksFailedPercent?: number;
    /**
     * @stability stable
     */
    readonly roundTripTimeMs?: number;
}
/**
 * @stability stable
 */
export interface NetworkConnectionMonitorTestConfigurationTcpConfiguration {
    /**
     * @stability stable
     */
    readonly port: number;
    /**
     * @stability stable
     */
    readonly traceRouteEnabled?: boolean;
}
/**
 * @stability stable
 */
export interface NetworkConnectionMonitorTestConfiguration {
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly preferredIpVersion?: string;
    /**
     * @stability stable
     */
    readonly protocol: string;
    /**
     * @stability stable
     */
    readonly testFrequencyInSeconds?: number;
    /**
     * http_configuration block.
     *
     * @stability stable
     */
    readonly httpConfiguration?: NetworkConnectionMonitorTestConfigurationHttpConfiguration[];
    /**
     * icmp_configuration block.
     *
     * @stability stable
     */
    readonly icmpConfiguration?: NetworkConnectionMonitorTestConfigurationIcmpConfiguration[];
    /**
     * success_threshold block.
     *
     * @stability stable
     */
    readonly successThreshold?: NetworkConnectionMonitorTestConfigurationSuccessThreshold[];
    /**
     * tcp_configuration block.
     *
     * @stability stable
     */
    readonly tcpConfiguration?: NetworkConnectionMonitorTestConfigurationTcpConfiguration[];
}
/**
 * @stability stable
 */
export interface NetworkConnectionMonitorTestGroup {
    /**
     * @stability stable
     */
    readonly destinationEndpoints: string[];
    /**
     * @stability stable
     */
    readonly enabled?: boolean;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly sourceEndpoints: string[];
    /**
     * @stability stable
     */
    readonly testConfigurationNames: string[];
}
/**
 * @stability stable
 */
export interface NetworkConnectionMonitorTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class NetworkConnectionMonitor extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: NetworkConnectionMonitorConfig);
    private _autoStart?;
    /**
     * @stability stable
     */
    get autoStart(): boolean;
    /**
     * @stability stable
     */
    set autoStart(value: boolean);
    /**
     * @stability stable
     */
    resetAutoStart(): void;
    /**
     * @stability stable
     */
    get autoStartInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _intervalInSeconds?;
    /**
     * @stability stable
     */
    get intervalInSeconds(): number;
    /**
     * @stability stable
     */
    set intervalInSeconds(value: number);
    /**
     * @stability stable
     */
    resetIntervalInSeconds(): void;
    /**
     * @stability stable
     */
    get intervalInSecondsInput(): number | undefined;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _networkWatcherId;
    /**
     * @stability stable
     */
    get networkWatcherId(): string;
    /**
     * @stability stable
     */
    set networkWatcherId(value: string);
    /**
     * @stability stable
     */
    get networkWatcherIdInput(): string;
    private _notes?;
    /**
     * @stability stable
     */
    get notes(): string;
    /**
     * @stability stable
     */
    set notes(value: string);
    /**
     * @stability stable
     */
    resetNotes(): void;
    /**
     * @stability stable
     */
    get notesInput(): string | undefined;
    private _outputWorkspaceResourceIds?;
    /**
     * @stability stable
     */
    get outputWorkspaceResourceIds(): string[];
    /**
     * @stability stable
     */
    set outputWorkspaceResourceIds(value: string[]);
    /**
     * @stability stable
     */
    resetOutputWorkspaceResourceIds(): void;
    /**
     * @stability stable
     */
    get outputWorkspaceResourceIdsInput(): string[] | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _destination?;
    /**
     * @stability stable
     */
    get destination(): NetworkConnectionMonitorDestination[];
    /**
     * @stability stable
     */
    set destination(value: NetworkConnectionMonitorDestination[]);
    /**
     * @stability stable
     */
    resetDestination(): void;
    /**
     * @stability stable
     */
    get destinationInput(): NetworkConnectionMonitorDestination[] | undefined;
    private _endpoint;
    /**
     * @stability stable
     */
    get endpoint(): NetworkConnectionMonitorEndpoint[];
    /**
     * @stability stable
     */
    set endpoint(value: NetworkConnectionMonitorEndpoint[]);
    /**
     * @stability stable
     */
    get endpointInput(): NetworkConnectionMonitorEndpoint[];
    private _source?;
    /**
     * @stability stable
     */
    get source(): NetworkConnectionMonitorSource[];
    /**
     * @stability stable
     */
    set source(value: NetworkConnectionMonitorSource[]);
    /**
     * @stability stable
     */
    resetSource(): void;
    /**
     * @stability stable
     */
    get sourceInput(): NetworkConnectionMonitorSource[] | undefined;
    private _testConfiguration;
    /**
     * @stability stable
     */
    get testConfiguration(): NetworkConnectionMonitorTestConfiguration[];
    /**
     * @stability stable
     */
    set testConfiguration(value: NetworkConnectionMonitorTestConfiguration[]);
    /**
     * @stability stable
     */
    get testConfigurationInput(): NetworkConnectionMonitorTestConfiguration[];
    private _testGroup;
    /**
     * @stability stable
     */
    get testGroup(): NetworkConnectionMonitorTestGroup[];
    /**
     * @stability stable
     */
    set testGroup(value: NetworkConnectionMonitorTestGroup[]);
    /**
     * @stability stable
     */
    get testGroupInput(): NetworkConnectionMonitorTestGroup[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): NetworkConnectionMonitorTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: NetworkConnectionMonitorTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): NetworkConnectionMonitorTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
