import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface PostgresqlServerConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly administratorLogin?: string;
    /**
     * @stability stable
     */
    readonly administratorLoginPassword?: string;
    /**
     * @stability stable
     */
    readonly autoGrowEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly backupRetentionDays?: number;
    /**
     * @stability stable
     */
    readonly createMode?: string;
    /**
     * @stability stable
     */
    readonly creationSourceServerId?: string;
    /**
     * @stability stable
     */
    readonly geoRedundantBackupEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly infrastructureEncryptionEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly publicNetworkAccessEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly restorePointInTime?: string;
    /**
     * @stability stable
     */
    readonly skuName: string;
    /**
     * @stability stable
     */
    readonly sslEnforcement?: string;
    /**
     * @stability stable
     */
    readonly sslEnforcementEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly sslMinimalTlsVersionEnforced?: string;
    /**
     * @stability stable
     */
    readonly storageMb?: number;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly version: string;
    /**
     * identity block.
     *
     * @stability stable
     */
    readonly identity?: PostgresqlServerIdentity[];
    /**
     * storage_profile block.
     *
     * @stability stable
     */
    readonly storageProfile?: PostgresqlServerStorageProfile[];
    /**
     * threat_detection_policy block.
     *
     * @stability stable
     */
    readonly threatDetectionPolicy?: PostgresqlServerThreatDetectionPolicy[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: PostgresqlServerTimeouts;
}
/**
 * @stability stable
 */
export interface PostgresqlServerIdentity {
    /**
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface PostgresqlServerStorageProfile {
    /**
     * @stability stable
     */
    readonly autoGrow?: string;
    /**
     * @stability stable
     */
    readonly backupRetentionDays?: number;
    /**
     * @stability stable
     */
    readonly geoRedundantBackup?: string;
    /**
     * @stability stable
     */
    readonly storageMb?: number;
}
/**
 * @stability stable
 */
export interface PostgresqlServerThreatDetectionPolicy {
    /**
     * @stability stable
     */
    readonly disabledAlerts?: string[];
    /**
     * @stability stable
     */
    readonly emailAccountAdmins?: boolean;
    /**
     * @stability stable
     */
    readonly emailAddresses?: string[];
    /**
     * @stability stable
     */
    readonly enabled?: boolean;
    /**
     * @stability stable
     */
    readonly retentionDays?: number;
    /**
     * @stability stable
     */
    readonly storageAccountAccessKey?: string;
    /**
     * @stability stable
     */
    readonly storageEndpoint?: string;
}
/**
 * @stability stable
 */
export interface PostgresqlServerTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class PostgresqlServer extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: PostgresqlServerConfig);
    private _administratorLogin?;
    /**
     * @stability stable
     */
    get administratorLogin(): string;
    /**
     * @stability stable
     */
    set administratorLogin(value: string);
    /**
     * @stability stable
     */
    resetAdministratorLogin(): void;
    /**
     * @stability stable
     */
    get administratorLoginInput(): string | undefined;
    private _administratorLoginPassword?;
    /**
     * @stability stable
     */
    get administratorLoginPassword(): string;
    /**
     * @stability stable
     */
    set administratorLoginPassword(value: string);
    /**
     * @stability stable
     */
    resetAdministratorLoginPassword(): void;
    /**
     * @stability stable
     */
    get administratorLoginPasswordInput(): string | undefined;
    private _autoGrowEnabled?;
    /**
     * @stability stable
     */
    get autoGrowEnabled(): boolean;
    /**
     * @stability stable
     */
    set autoGrowEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetAutoGrowEnabled(): void;
    /**
     * @stability stable
     */
    get autoGrowEnabledInput(): boolean | undefined;
    private _backupRetentionDays?;
    /**
     * @stability stable
     */
    get backupRetentionDays(): number;
    /**
     * @stability stable
     */
    set backupRetentionDays(value: number);
    /**
     * @stability stable
     */
    resetBackupRetentionDays(): void;
    /**
     * @stability stable
     */
    get backupRetentionDaysInput(): number | undefined;
    private _createMode?;
    /**
     * @stability stable
     */
    get createMode(): string;
    /**
     * @stability stable
     */
    set createMode(value: string);
    /**
     * @stability stable
     */
    resetCreateMode(): void;
    /**
     * @stability stable
     */
    get createModeInput(): string | undefined;
    private _creationSourceServerId?;
    /**
     * @stability stable
     */
    get creationSourceServerId(): string;
    /**
     * @stability stable
     */
    set creationSourceServerId(value: string);
    /**
     * @stability stable
     */
    resetCreationSourceServerId(): void;
    /**
     * @stability stable
     */
    get creationSourceServerIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get fqdn(): string;
    private _geoRedundantBackupEnabled?;
    /**
     * @stability stable
     */
    get geoRedundantBackupEnabled(): boolean;
    /**
     * @stability stable
     */
    set geoRedundantBackupEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetGeoRedundantBackupEnabled(): void;
    /**
     * @stability stable
     */
    get geoRedundantBackupEnabledInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _infrastructureEncryptionEnabled?;
    /**
     * @stability stable
     */
    get infrastructureEncryptionEnabled(): boolean;
    /**
     * @stability stable
     */
    set infrastructureEncryptionEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetInfrastructureEncryptionEnabled(): void;
    /**
     * @stability stable
     */
    get infrastructureEncryptionEnabledInput(): boolean | undefined;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _publicNetworkAccessEnabled?;
    /**
     * @stability stable
     */
    get publicNetworkAccessEnabled(): boolean;
    /**
     * @stability stable
     */
    set publicNetworkAccessEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetPublicNetworkAccessEnabled(): void;
    /**
     * @stability stable
     */
    get publicNetworkAccessEnabledInput(): boolean | undefined;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    private _restorePointInTime?;
    /**
     * @stability stable
     */
    get restorePointInTime(): string;
    /**
     * @stability stable
     */
    set restorePointInTime(value: string);
    /**
     * @stability stable
     */
    resetRestorePointInTime(): void;
    /**
     * @stability stable
     */
    get restorePointInTimeInput(): string | undefined;
    private _skuName;
    /**
     * @stability stable
     */
    get skuName(): string;
    /**
     * @stability stable
     */
    set skuName(value: string);
    /**
     * @stability stable
     */
    get skuNameInput(): string;
    private _sslEnforcement?;
    /**
     * @stability stable
     */
    get sslEnforcement(): string;
    /**
     * @stability stable
     */
    set sslEnforcement(value: string);
    /**
     * @stability stable
     */
    resetSslEnforcement(): void;
    /**
     * @stability stable
     */
    get sslEnforcementInput(): string | undefined;
    private _sslEnforcementEnabled?;
    /**
     * @stability stable
     */
    get sslEnforcementEnabled(): boolean;
    /**
     * @stability stable
     */
    set sslEnforcementEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetSslEnforcementEnabled(): void;
    /**
     * @stability stable
     */
    get sslEnforcementEnabledInput(): boolean | undefined;
    private _sslMinimalTlsVersionEnforced?;
    /**
     * @stability stable
     */
    get sslMinimalTlsVersionEnforced(): string;
    /**
     * @stability stable
     */
    set sslMinimalTlsVersionEnforced(value: string);
    /**
     * @stability stable
     */
    resetSslMinimalTlsVersionEnforced(): void;
    /**
     * @stability stable
     */
    get sslMinimalTlsVersionEnforcedInput(): string | undefined;
    private _storageMb?;
    /**
     * @stability stable
     */
    get storageMb(): number;
    /**
     * @stability stable
     */
    set storageMb(value: number);
    /**
     * @stability stable
     */
    resetStorageMb(): void;
    /**
     * @stability stable
     */
    get storageMbInput(): number | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _version;
    /**
     * @stability stable
     */
    get version(): string;
    /**
     * @stability stable
     */
    set version(value: string);
    /**
     * @stability stable
     */
    get versionInput(): string;
    private _identity?;
    /**
     * @stability stable
     */
    get identity(): PostgresqlServerIdentity[];
    /**
     * @stability stable
     */
    set identity(value: PostgresqlServerIdentity[]);
    /**
     * @stability stable
     */
    resetIdentity(): void;
    /**
     * @stability stable
     */
    get identityInput(): PostgresqlServerIdentity[] | undefined;
    private _storageProfile?;
    /**
     * @stability stable
     */
    get storageProfile(): PostgresqlServerStorageProfile[];
    /**
     * @stability stable
     */
    set storageProfile(value: PostgresqlServerStorageProfile[]);
    /**
     * @stability stable
     */
    resetStorageProfile(): void;
    /**
     * @stability stable
     */
    get storageProfileInput(): PostgresqlServerStorageProfile[] | undefined;
    private _threatDetectionPolicy?;
    /**
     * @stability stable
     */
    get threatDetectionPolicy(): PostgresqlServerThreatDetectionPolicy[];
    /**
     * @stability stable
     */
    set threatDetectionPolicy(value: PostgresqlServerThreatDetectionPolicy[]);
    /**
     * @stability stable
     */
    resetThreatDetectionPolicy(): void;
    /**
     * @stability stable
     */
    get threatDetectionPolicyInput(): PostgresqlServerThreatDetectionPolicy[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): PostgresqlServerTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: PostgresqlServerTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): PostgresqlServerTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
