import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface SignalrServiceConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * cors block.
     *
     * @stability stable
     */
    readonly cors?: SignalrServiceCors[];
    /**
     * features block.
     *
     * @stability stable
     */
    readonly features?: SignalrServiceFeatures[];
    /**
     * sku block.
     *
     * @stability stable
     */
    readonly sku: SignalrServiceSku[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: SignalrServiceTimeouts;
    /**
     * upstream_endpoint block.
     *
     * @stability stable
     */
    readonly upstreamEndpoint?: SignalrServiceUpstreamEndpoint[];
}
/**
 * @stability stable
 */
export interface SignalrServiceCors {
    /**
     * @stability stable
     */
    readonly allowedOrigins: string[];
}
/**
 * @stability stable
 */
export interface SignalrServiceFeatures {
    /**
     * @stability stable
     */
    readonly flag: string;
    /**
     * @stability stable
     */
    readonly value: string;
}
/**
 * @stability stable
 */
export interface SignalrServiceSku {
    /**
     * @stability stable
     */
    readonly capacity: number;
    /**
     * @stability stable
     */
    readonly name: string;
}
/**
 * @stability stable
 */
export interface SignalrServiceTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export interface SignalrServiceUpstreamEndpoint {
    /**
     * @stability stable
     */
    readonly categoryPattern: string[];
    /**
     * @stability stable
     */
    readonly eventPattern: string[];
    /**
     * @stability stable
     */
    readonly hubPattern: string[];
    /**
     * @stability stable
     */
    readonly urlTemplate: string;
}
/**
 * @stability stable
 */
export declare class SignalrService extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SignalrServiceConfig);
    /**
     * @stability stable
     */
    get hostname(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get ipAddress(): string;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    /**
     * @stability stable
     */
    get primaryAccessKey(): string;
    /**
     * @stability stable
     */
    get primaryConnectionString(): string;
    /**
     * @stability stable
     */
    get publicPort(): number;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    /**
     * @stability stable
     */
    get secondaryAccessKey(): string;
    /**
     * @stability stable
     */
    get secondaryConnectionString(): string;
    /**
     * @stability stable
     */
    get serverPort(): number;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _cors?;
    /**
     * @stability stable
     */
    get cors(): SignalrServiceCors[];
    /**
     * @stability stable
     */
    set cors(value: SignalrServiceCors[]);
    /**
     * @stability stable
     */
    resetCors(): void;
    /**
     * @stability stable
     */
    get corsInput(): SignalrServiceCors[] | undefined;
    private _features?;
    /**
     * @stability stable
     */
    get features(): SignalrServiceFeatures[];
    /**
     * @stability stable
     */
    set features(value: SignalrServiceFeatures[]);
    /**
     * @stability stable
     */
    resetFeatures(): void;
    /**
     * @stability stable
     */
    get featuresInput(): SignalrServiceFeatures[] | undefined;
    private _sku;
    /**
     * @stability stable
     */
    get sku(): SignalrServiceSku[];
    /**
     * @stability stable
     */
    set sku(value: SignalrServiceSku[]);
    /**
     * @stability stable
     */
    get skuInput(): SignalrServiceSku[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): SignalrServiceTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: SignalrServiceTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): SignalrServiceTimeouts | undefined;
    private _upstreamEndpoint?;
    /**
     * @stability stable
     */
    get upstreamEndpoint(): SignalrServiceUpstreamEndpoint[];
    /**
     * @stability stable
     */
    set upstreamEndpoint(value: SignalrServiceUpstreamEndpoint[]);
    /**
     * @stability stable
     */
    resetUpstreamEndpoint(): void;
    /**
     * @stability stable
     */
    get upstreamEndpointInput(): SignalrServiceUpstreamEndpoint[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
