import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface SpringCloudServiceConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly skuName?: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * config_server_git_setting block.
     *
     * @stability stable
     */
    readonly configServerGitSetting?: SpringCloudServiceConfigServerGitSetting[];
    /**
     * network block.
     *
     * @stability stable
     */
    readonly network?: SpringCloudServiceNetwork[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: SpringCloudServiceTimeouts;
    /**
     * trace block.
     *
     * @stability stable
     */
    readonly trace?: SpringCloudServiceTrace[];
}
/**
 * @stability stable
 */
export interface SpringCloudServiceConfigServerGitSettingHttpBasicAuth {
    /**
     * @stability stable
     */
    readonly password: string;
    /**
     * @stability stable
     */
    readonly username: string;
}
/**
 * @stability stable
 */
export interface SpringCloudServiceConfigServerGitSettingRepositoryHttpBasicAuth {
    /**
     * @stability stable
     */
    readonly password: string;
    /**
     * @stability stable
     */
    readonly username: string;
}
/**
 * @stability stable
 */
export interface SpringCloudServiceConfigServerGitSettingRepositorySshAuth {
    /**
     * @stability stable
     */
    readonly hostKey?: string;
    /**
     * @stability stable
     */
    readonly hostKeyAlgorithm?: string;
    /**
     * @stability stable
     */
    readonly privateKey: string;
    /**
     * @stability stable
     */
    readonly strictHostKeyCheckingEnabled?: boolean;
}
/**
 * @stability stable
 */
export interface SpringCloudServiceConfigServerGitSettingRepository {
    /**
     * @stability stable
     */
    readonly label?: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly pattern?: string[];
    /**
     * @stability stable
     */
    readonly searchPaths?: string[];
    /**
     * @stability stable
     */
    readonly uri: string;
    /**
     * http_basic_auth block.
     *
     * @stability stable
     */
    readonly httpBasicAuth?: SpringCloudServiceConfigServerGitSettingRepositoryHttpBasicAuth[];
    /**
     * ssh_auth block.
     *
     * @stability stable
     */
    readonly sshAuth?: SpringCloudServiceConfigServerGitSettingRepositorySshAuth[];
}
/**
 * @stability stable
 */
export interface SpringCloudServiceConfigServerGitSettingSshAuth {
    /**
     * @stability stable
     */
    readonly hostKey?: string;
    /**
     * @stability stable
     */
    readonly hostKeyAlgorithm?: string;
    /**
     * @stability stable
     */
    readonly privateKey: string;
    /**
     * @stability stable
     */
    readonly strictHostKeyCheckingEnabled?: boolean;
}
/**
 * @stability stable
 */
export interface SpringCloudServiceConfigServerGitSetting {
    /**
     * @stability stable
     */
    readonly label?: string;
    /**
     * @stability stable
     */
    readonly searchPaths?: string[];
    /**
     * @stability stable
     */
    readonly uri: string;
    /**
     * http_basic_auth block.
     *
     * @stability stable
     */
    readonly httpBasicAuth?: SpringCloudServiceConfigServerGitSettingHttpBasicAuth[];
    /**
     * repository block.
     *
     * @stability stable
     */
    readonly repository?: SpringCloudServiceConfigServerGitSettingRepository[];
    /**
     * ssh_auth block.
     *
     * @stability stable
     */
    readonly sshAuth?: SpringCloudServiceConfigServerGitSettingSshAuth[];
}
/**
 * @stability stable
 */
export interface SpringCloudServiceNetwork {
    /**
     * @stability stable
     */
    readonly appNetworkResourceGroup?: string;
    /**
     * @stability stable
     */
    readonly appSubnetId: string;
    /**
     * @stability stable
     */
    readonly cidrRanges: string[];
    /**
     * @stability stable
     */
    readonly serviceRuntimeNetworkResourceGroup?: string;
    /**
     * @stability stable
     */
    readonly serviceRuntimeSubnetId: string;
}
/**
 * @stability stable
 */
export interface SpringCloudServiceTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export interface SpringCloudServiceTrace {
    /**
     * @stability stable
     */
    readonly instrumentationKey: string;
    /**
     * @stability stable
     */
    readonly sampleRate?: number;
}
/**
 * @stability stable
 */
export declare class SpringCloudService extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SpringCloudServiceConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    /**
     * @stability stable
     */
    get outboundPublicIpAddresses(): string[];
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    private _skuName?;
    /**
     * @stability stable
     */
    get skuName(): string;
    /**
     * @stability stable
     */
    set skuName(value: string);
    /**
     * @stability stable
     */
    resetSkuName(): void;
    /**
     * @stability stable
     */
    get skuNameInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _configServerGitSetting?;
    /**
     * @stability stable
     */
    get configServerGitSetting(): SpringCloudServiceConfigServerGitSetting[];
    /**
     * @stability stable
     */
    set configServerGitSetting(value: SpringCloudServiceConfigServerGitSetting[]);
    /**
     * @stability stable
     */
    resetConfigServerGitSetting(): void;
    /**
     * @stability stable
     */
    get configServerGitSettingInput(): SpringCloudServiceConfigServerGitSetting[] | undefined;
    private _network?;
    /**
     * @stability stable
     */
    get network(): SpringCloudServiceNetwork[];
    /**
     * @stability stable
     */
    set network(value: SpringCloudServiceNetwork[]);
    /**
     * @stability stable
     */
    resetNetwork(): void;
    /**
     * @stability stable
     */
    get networkInput(): SpringCloudServiceNetwork[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): SpringCloudServiceTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: SpringCloudServiceTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): SpringCloudServiceTimeouts | undefined;
    private _trace?;
    /**
     * @stability stable
     */
    get trace(): SpringCloudServiceTrace[];
    /**
     * @stability stable
     */
    set trace(value: SpringCloudServiceTrace[]);
    /**
     * @stability stable
     */
    resetTrace(): void;
    /**
     * @stability stable
     */
    get traceInput(): SpringCloudServiceTrace[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
