import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface SqlDatabaseConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly collation?: string;
    /**
     * @stability stable
     */
    readonly createMode?: string;
    /**
     * @stability stable
     */
    readonly edition?: string;
    /**
     * @stability stable
     */
    readonly elasticPoolName?: string;
    /**
     * @stability stable
     */
    readonly extendedAuditingPolicy?: SqlDatabaseExtendedAuditingPolicy[];
    /**
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly maxSizeBytes?: string;
    /**
     * @stability stable
     */
    readonly maxSizeGb?: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly readScale?: boolean;
    /**
     * @stability stable
     */
    readonly requestedServiceObjectiveId?: string;
    /**
     * @stability stable
     */
    readonly requestedServiceObjectiveName?: string;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly restorePointInTime?: string;
    /**
     * @stability stable
     */
    readonly serverName: string;
    /**
     * @stability stable
     */
    readonly sourceDatabaseDeletionDate?: string;
    /**
     * @stability stable
     */
    readonly sourceDatabaseId?: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly zoneRedundant?: boolean;
    /**
     * import block.
     *
     * @stability stable
     */
    readonly import?: SqlDatabaseImport[];
    /**
     * threat_detection_policy block.
     *
     * @stability stable
     */
    readonly threatDetectionPolicy?: SqlDatabaseThreatDetectionPolicy[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: SqlDatabaseTimeouts;
}
/**
 * @stability stable
 */
export interface SqlDatabaseExtendedAuditingPolicy {
    /**
     * @stability stable
     */
    readonly logMonitoringEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly retentionInDays?: number;
    /**
     * @stability stable
     */
    readonly storageAccountAccessKey?: string;
    /**
     * @stability stable
     */
    readonly storageAccountAccessKeyIsSecondary?: boolean;
    /**
     * @stability stable
     */
    readonly storageEndpoint?: string;
}
/**
 * @stability stable
 */
export interface SqlDatabaseImport {
    /**
     * @stability stable
     */
    readonly administratorLogin: string;
    /**
     * @stability stable
     */
    readonly administratorLoginPassword: string;
    /**
     * @stability stable
     */
    readonly authenticationType: string;
    /**
     * @stability stable
     */
    readonly operationMode?: string;
    /**
     * @stability stable
     */
    readonly storageKey: string;
    /**
     * @stability stable
     */
    readonly storageKeyType: string;
    /**
     * @stability stable
     */
    readonly storageUri: string;
}
/**
 * @stability stable
 */
export interface SqlDatabaseThreatDetectionPolicy {
    /**
     * @stability stable
     */
    readonly disabledAlerts?: string[];
    /**
     * @stability stable
     */
    readonly emailAccountAdmins?: string;
    /**
     * @stability stable
     */
    readonly emailAddresses?: string[];
    /**
     * @stability stable
     */
    readonly retentionDays?: number;
    /**
     * @stability stable
     */
    readonly state?: string;
    /**
     * @stability stable
     */
    readonly storageAccountAccessKey?: string;
    /**
     * @stability stable
     */
    readonly storageEndpoint?: string;
    /**
     * @stability stable
     */
    readonly useServerDefault?: string;
}
/**
 * @stability stable
 */
export interface SqlDatabaseTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class SqlDatabase extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SqlDatabaseConfig);
    private _collation?;
    /**
     * @stability stable
     */
    get collation(): string;
    /**
     * @stability stable
     */
    set collation(value: string);
    /**
     * @stability stable
     */
    resetCollation(): void;
    /**
     * @stability stable
     */
    get collationInput(): string | undefined;
    private _createMode?;
    /**
     * @stability stable
     */
    get createMode(): string;
    /**
     * @stability stable
     */
    set createMode(value: string);
    /**
     * @stability stable
     */
    resetCreateMode(): void;
    /**
     * @stability stable
     */
    get createModeInput(): string | undefined;
    /**
     * @stability stable
     */
    get creationDate(): string;
    /**
     * @stability stable
     */
    get defaultSecondaryLocation(): string;
    private _edition?;
    /**
     * @stability stable
     */
    get edition(): string;
    /**
     * @stability stable
     */
    set edition(value: string);
    /**
     * @stability stable
     */
    resetEdition(): void;
    /**
     * @stability stable
     */
    get editionInput(): string | undefined;
    private _elasticPoolName?;
    /**
     * @stability stable
     */
    get elasticPoolName(): string;
    /**
     * @stability stable
     */
    set elasticPoolName(value: string);
    /**
     * @stability stable
     */
    resetElasticPoolName(): void;
    /**
     * @stability stable
     */
    get elasticPoolNameInput(): string | undefined;
    /**
     * @stability stable
     */
    get encryption(): string;
    private _extendedAuditingPolicy?;
    /**
     * @stability stable
     */
    get extendedAuditingPolicy(): SqlDatabaseExtendedAuditingPolicy[];
    /**
     * @stability stable
     */
    set extendedAuditingPolicy(value: SqlDatabaseExtendedAuditingPolicy[]);
    /**
     * @stability stable
     */
    resetExtendedAuditingPolicy(): void;
    /**
     * @stability stable
     */
    get extendedAuditingPolicyInput(): SqlDatabaseExtendedAuditingPolicy[] | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _maxSizeBytes?;
    /**
     * @stability stable
     */
    get maxSizeBytes(): string;
    /**
     * @stability stable
     */
    set maxSizeBytes(value: string);
    /**
     * @stability stable
     */
    resetMaxSizeBytes(): void;
    /**
     * @stability stable
     */
    get maxSizeBytesInput(): string | undefined;
    private _maxSizeGb?;
    /**
     * @stability stable
     */
    get maxSizeGb(): string;
    /**
     * @stability stable
     */
    set maxSizeGb(value: string);
    /**
     * @stability stable
     */
    resetMaxSizeGb(): void;
    /**
     * @stability stable
     */
    get maxSizeGbInput(): string | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _readScale?;
    /**
     * @stability stable
     */
    get readScale(): boolean;
    /**
     * @stability stable
     */
    set readScale(value: boolean);
    /**
     * @stability stable
     */
    resetReadScale(): void;
    /**
     * @stability stable
     */
    get readScaleInput(): boolean | undefined;
    private _requestedServiceObjectiveId?;
    /**
     * @stability stable
     */
    get requestedServiceObjectiveId(): string;
    /**
     * @stability stable
     */
    set requestedServiceObjectiveId(value: string);
    /**
     * @stability stable
     */
    resetRequestedServiceObjectiveId(): void;
    /**
     * @stability stable
     */
    get requestedServiceObjectiveIdInput(): string | undefined;
    private _requestedServiceObjectiveName?;
    /**
     * @stability stable
     */
    get requestedServiceObjectiveName(): string;
    /**
     * @stability stable
     */
    set requestedServiceObjectiveName(value: string);
    /**
     * @stability stable
     */
    resetRequestedServiceObjectiveName(): void;
    /**
     * @stability stable
     */
    get requestedServiceObjectiveNameInput(): string | undefined;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    private _restorePointInTime?;
    /**
     * @stability stable
     */
    get restorePointInTime(): string;
    /**
     * @stability stable
     */
    set restorePointInTime(value: string);
    /**
     * @stability stable
     */
    resetRestorePointInTime(): void;
    /**
     * @stability stable
     */
    get restorePointInTimeInput(): string | undefined;
    private _serverName;
    /**
     * @stability stable
     */
    get serverName(): string;
    /**
     * @stability stable
     */
    set serverName(value: string);
    /**
     * @stability stable
     */
    get serverNameInput(): string;
    private _sourceDatabaseDeletionDate?;
    /**
     * @stability stable
     */
    get sourceDatabaseDeletionDate(): string;
    /**
     * @stability stable
     */
    set sourceDatabaseDeletionDate(value: string);
    /**
     * @stability stable
     */
    resetSourceDatabaseDeletionDate(): void;
    /**
     * @stability stable
     */
    get sourceDatabaseDeletionDateInput(): string | undefined;
    private _sourceDatabaseId?;
    /**
     * @stability stable
     */
    get sourceDatabaseId(): string;
    /**
     * @stability stable
     */
    set sourceDatabaseId(value: string);
    /**
     * @stability stable
     */
    resetSourceDatabaseId(): void;
    /**
     * @stability stable
     */
    get sourceDatabaseIdInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _zoneRedundant?;
    /**
     * @stability stable
     */
    get zoneRedundant(): boolean;
    /**
     * @stability stable
     */
    set zoneRedundant(value: boolean);
    /**
     * @stability stable
     */
    resetZoneRedundant(): void;
    /**
     * @stability stable
     */
    get zoneRedundantInput(): boolean | undefined;
    private _import?;
    /**
     * @stability stable
     */
    get import(): SqlDatabaseImport[];
    /**
     * @stability stable
     */
    set import(value: SqlDatabaseImport[]);
    /**
     * @stability stable
     */
    resetImport(): void;
    /**
     * @stability stable
     */
    get importInput(): SqlDatabaseImport[] | undefined;
    private _threatDetectionPolicy?;
    /**
     * @stability stable
     */
    get threatDetectionPolicy(): SqlDatabaseThreatDetectionPolicy[];
    /**
     * @stability stable
     */
    set threatDetectionPolicy(value: SqlDatabaseThreatDetectionPolicy[]);
    /**
     * @stability stable
     */
    resetThreatDetectionPolicy(): void;
    /**
     * @stability stable
     */
    get threatDetectionPolicyInput(): SqlDatabaseThreatDetectionPolicy[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): SqlDatabaseTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: SqlDatabaseTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): SqlDatabaseTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
