import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface SynapseSparkPoolConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly nodeCount?: number;
    /**
     * @stability stable
     */
    readonly nodeSize: string;
    /**
     * @stability stable
     */
    readonly nodeSizeFamily: string;
    /**
     * @stability stable
     */
    readonly sparkEventsFolder?: string;
    /**
     * @stability stable
     */
    readonly sparkLogFolder?: string;
    /**
     * @stability stable
     */
    readonly sparkVersion?: string;
    /**
     * @stability stable
     */
    readonly synapseWorkspaceId: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * auto_pause block.
     *
     * @stability stable
     */
    readonly autoPause?: SynapseSparkPoolAutoPause[];
    /**
     * auto_scale block.
     *
     * @stability stable
     */
    readonly autoScale?: SynapseSparkPoolAutoScale[];
    /**
     * library_requirement block.
     *
     * @stability stable
     */
    readonly libraryRequirement?: SynapseSparkPoolLibraryRequirement[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: SynapseSparkPoolTimeouts;
}
/**
 * @stability stable
 */
export interface SynapseSparkPoolAutoPause {
    /**
     * @stability stable
     */
    readonly delayInMinutes: number;
}
/**
 * @stability stable
 */
export interface SynapseSparkPoolAutoScale {
    /**
     * @stability stable
     */
    readonly maxNodeCount: number;
    /**
     * @stability stable
     */
    readonly minNodeCount: number;
}
/**
 * @stability stable
 */
export interface SynapseSparkPoolLibraryRequirement {
    /**
     * @stability stable
     */
    readonly content: string;
    /**
     * @stability stable
     */
    readonly filename: string;
}
/**
 * @stability stable
 */
export interface SynapseSparkPoolTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class SynapseSparkPool extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SynapseSparkPoolConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _nodeCount?;
    /**
     * @stability stable
     */
    get nodeCount(): number;
    /**
     * @stability stable
     */
    set nodeCount(value: number);
    /**
     * @stability stable
     */
    resetNodeCount(): void;
    /**
     * @stability stable
     */
    get nodeCountInput(): number | undefined;
    private _nodeSize;
    /**
     * @stability stable
     */
    get nodeSize(): string;
    /**
     * @stability stable
     */
    set nodeSize(value: string);
    /**
     * @stability stable
     */
    get nodeSizeInput(): string;
    private _nodeSizeFamily;
    /**
     * @stability stable
     */
    get nodeSizeFamily(): string;
    /**
     * @stability stable
     */
    set nodeSizeFamily(value: string);
    /**
     * @stability stable
     */
    get nodeSizeFamilyInput(): string;
    private _sparkEventsFolder?;
    /**
     * @stability stable
     */
    get sparkEventsFolder(): string;
    /**
     * @stability stable
     */
    set sparkEventsFolder(value: string);
    /**
     * @stability stable
     */
    resetSparkEventsFolder(): void;
    /**
     * @stability stable
     */
    get sparkEventsFolderInput(): string | undefined;
    private _sparkLogFolder?;
    /**
     * @stability stable
     */
    get sparkLogFolder(): string;
    /**
     * @stability stable
     */
    set sparkLogFolder(value: string);
    /**
     * @stability stable
     */
    resetSparkLogFolder(): void;
    /**
     * @stability stable
     */
    get sparkLogFolderInput(): string | undefined;
    private _sparkVersion?;
    /**
     * @stability stable
     */
    get sparkVersion(): string;
    /**
     * @stability stable
     */
    set sparkVersion(value: string);
    /**
     * @stability stable
     */
    resetSparkVersion(): void;
    /**
     * @stability stable
     */
    get sparkVersionInput(): string | undefined;
    private _synapseWorkspaceId;
    /**
     * @stability stable
     */
    get synapseWorkspaceId(): string;
    /**
     * @stability stable
     */
    set synapseWorkspaceId(value: string);
    /**
     * @stability stable
     */
    get synapseWorkspaceIdInput(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _autoPause?;
    /**
     * @stability stable
     */
    get autoPause(): SynapseSparkPoolAutoPause[];
    /**
     * @stability stable
     */
    set autoPause(value: SynapseSparkPoolAutoPause[]);
    /**
     * @stability stable
     */
    resetAutoPause(): void;
    /**
     * @stability stable
     */
    get autoPauseInput(): SynapseSparkPoolAutoPause[] | undefined;
    private _autoScale?;
    /**
     * @stability stable
     */
    get autoScale(): SynapseSparkPoolAutoScale[];
    /**
     * @stability stable
     */
    set autoScale(value: SynapseSparkPoolAutoScale[]);
    /**
     * @stability stable
     */
    resetAutoScale(): void;
    /**
     * @stability stable
     */
    get autoScaleInput(): SynapseSparkPoolAutoScale[] | undefined;
    private _libraryRequirement?;
    /**
     * @stability stable
     */
    get libraryRequirement(): SynapseSparkPoolLibraryRequirement[];
    /**
     * @stability stable
     */
    set libraryRequirement(value: SynapseSparkPoolLibraryRequirement[]);
    /**
     * @stability stable
     */
    resetLibraryRequirement(): void;
    /**
     * @stability stable
     */
    get libraryRequirementInput(): SynapseSparkPoolLibraryRequirement[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): SynapseSparkPoolTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: SynapseSparkPoolTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): SynapseSparkPoolTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
