import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface TrafficManagerProfileConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly maxReturn?: number;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly profileStatus?: string;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly trafficRoutingMethod: string;
    /**
     * @stability stable
     */
    readonly trafficViewEnabled?: boolean;
    /**
     * dns_config block.
     *
     * @stability stable
     */
    readonly dnsConfig: TrafficManagerProfileDnsConfig[];
    /**
     * monitor_config block.
     *
     * @stability stable
     */
    readonly monitorConfig: TrafficManagerProfileMonitorConfig[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: TrafficManagerProfileTimeouts;
}
/**
 * @stability stable
 */
export interface TrafficManagerProfileDnsConfig {
    /**
     * @stability stable
     */
    readonly relativeName: string;
    /**
     * @stability stable
     */
    readonly ttl: number;
}
/**
 * @stability stable
 */
export interface TrafficManagerProfileMonitorConfigCustomHeader {
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly value: string;
}
/**
 * @stability stable
 */
export interface TrafficManagerProfileMonitorConfig {
    /**
     * @stability stable
     */
    readonly expectedStatusCodeRanges?: string[];
    /**
     * @stability stable
     */
    readonly intervalInSeconds?: number;
    /**
     * @stability stable
     */
    readonly path?: string;
    /**
     * @stability stable
     */
    readonly port: number;
    /**
     * @stability stable
     */
    readonly protocol: string;
    /**
     * @stability stable
     */
    readonly timeoutInSeconds?: number;
    /**
     * @stability stable
     */
    readonly toleratedNumberOfFailures?: number;
    /**
     * custom_header block.
     *
     * @stability stable
     */
    readonly customHeader?: TrafficManagerProfileMonitorConfigCustomHeader[];
}
/**
 * @stability stable
 */
export interface TrafficManagerProfileTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class TrafficManagerProfile extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: TrafficManagerProfileConfig);
    /**
     * @stability stable
     */
    get fqdn(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _maxReturn?;
    /**
     * @stability stable
     */
    get maxReturn(): number;
    /**
     * @stability stable
     */
    set maxReturn(value: number);
    /**
     * @stability stable
     */
    resetMaxReturn(): void;
    /**
     * @stability stable
     */
    get maxReturnInput(): number | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _profileStatus?;
    /**
     * @stability stable
     */
    get profileStatus(): string;
    /**
     * @stability stable
     */
    set profileStatus(value: string);
    /**
     * @stability stable
     */
    resetProfileStatus(): void;
    /**
     * @stability stable
     */
    get profileStatusInput(): string | undefined;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _trafficRoutingMethod;
    /**
     * @stability stable
     */
    get trafficRoutingMethod(): string;
    /**
     * @stability stable
     */
    set trafficRoutingMethod(value: string);
    /**
     * @stability stable
     */
    get trafficRoutingMethodInput(): string;
    private _trafficViewEnabled?;
    /**
     * @stability stable
     */
    get trafficViewEnabled(): boolean;
    /**
     * @stability stable
     */
    set trafficViewEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetTrafficViewEnabled(): void;
    /**
     * @stability stable
     */
    get trafficViewEnabledInput(): boolean | undefined;
    private _dnsConfig;
    /**
     * @stability stable
     */
    get dnsConfig(): TrafficManagerProfileDnsConfig[];
    /**
     * @stability stable
     */
    set dnsConfig(value: TrafficManagerProfileDnsConfig[]);
    /**
     * @stability stable
     */
    get dnsConfigInput(): TrafficManagerProfileDnsConfig[];
    private _monitorConfig;
    /**
     * @stability stable
     */
    get monitorConfig(): TrafficManagerProfileMonitorConfig[];
    /**
     * @stability stable
     */
    set monitorConfig(value: TrafficManagerProfileMonitorConfig[]);
    /**
     * @stability stable
     */
    get monitorConfigInput(): TrafficManagerProfileMonitorConfig[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): TrafficManagerProfileTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: TrafficManagerProfileTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): TrafficManagerProfileTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
