import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface VirtualNetworkConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly addressSpace: string[];
    /**
     * @stability stable
     */
    readonly bgpCommunity?: string;
    /**
     * @stability stable
     */
    readonly dnsServers?: string[];
    /**
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly subnet?: VirtualNetworkSubnet[];
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly vmProtectionEnabled?: boolean;
    /**
     * ddos_protection_plan block.
     *
     * @stability stable
     */
    readonly ddosProtectionPlan?: VirtualNetworkDdosProtectionPlan[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: VirtualNetworkTimeouts;
}
/**
 * @stability stable
 */
export interface VirtualNetworkSubnet {
    /**
     * @stability stable
     */
    readonly addressPrefix?: string;
    /**
     * @stability stable
     */
    readonly id?: string;
    /**
     * @stability stable
     */
    readonly name?: string;
    /**
     * @stability stable
     */
    readonly securityGroup?: string;
}
/**
 * @stability stable
 */
export interface VirtualNetworkDdosProtectionPlan {
    /**
     * @stability stable
     */
    readonly enable: boolean;
    /**
     * @stability stable
     */
    readonly id: string;
}
/**
 * @stability stable
 */
export interface VirtualNetworkTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class VirtualNetwork extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: VirtualNetworkConfig);
    private _addressSpace;
    /**
     * @stability stable
     */
    get addressSpace(): string[];
    /**
     * @stability stable
     */
    set addressSpace(value: string[]);
    /**
     * @stability stable
     */
    get addressSpaceInput(): string[];
    private _bgpCommunity?;
    /**
     * @stability stable
     */
    get bgpCommunity(): string;
    /**
     * @stability stable
     */
    set bgpCommunity(value: string);
    /**
     * @stability stable
     */
    resetBgpCommunity(): void;
    /**
     * @stability stable
     */
    get bgpCommunityInput(): string | undefined;
    private _dnsServers?;
    /**
     * @stability stable
     */
    get dnsServers(): string[];
    /**
     * @stability stable
     */
    set dnsServers(value: string[]);
    /**
     * @stability stable
     */
    resetDnsServers(): void;
    /**
     * @stability stable
     */
    get dnsServersInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get guid(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    private _subnet?;
    /**
     * @stability stable
     */
    get subnet(): VirtualNetworkSubnet[];
    /**
     * @stability stable
     */
    set subnet(value: VirtualNetworkSubnet[]);
    /**
     * @stability stable
     */
    resetSubnet(): void;
    /**
     * @stability stable
     */
    get subnetInput(): VirtualNetworkSubnet[] | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _vmProtectionEnabled?;
    /**
     * @stability stable
     */
    get vmProtectionEnabled(): boolean;
    /**
     * @stability stable
     */
    set vmProtectionEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetVmProtectionEnabled(): void;
    /**
     * @stability stable
     */
    get vmProtectionEnabledInput(): boolean | undefined;
    private _ddosProtectionPlan?;
    /**
     * @stability stable
     */
    get ddosProtectionPlan(): VirtualNetworkDdosProtectionPlan[];
    /**
     * @stability stable
     */
    set ddosProtectionPlan(value: VirtualNetworkDdosProtectionPlan[]);
    /**
     * @stability stable
     */
    resetDdosProtectionPlan(): void;
    /**
     * @stability stable
     */
    get ddosProtectionPlanInput(): VirtualNetworkDdosProtectionPlan[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): VirtualNetworkTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: VirtualNetworkTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): VirtualNetworkTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
