import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface VpnServerConfigurationConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly vpnAuthenticationTypes: string[];
    /**
     * @stability stable
     */
    readonly vpnProtocols?: string[];
    /**
     * azure_active_directory_authentication block.
     *
     * @stability stable
     */
    readonly azureActiveDirectoryAuthentication?: VpnServerConfigurationAzureActiveDirectoryAuthentication[];
    /**
     * client_revoked_certificate block.
     *
     * @stability stable
     */
    readonly clientRevokedCertificate?: VpnServerConfigurationClientRevokedCertificate[];
    /**
     * client_root_certificate block.
     *
     * @stability stable
     */
    readonly clientRootCertificate?: VpnServerConfigurationClientRootCertificate[];
    /**
     * ipsec_policy block.
     *
     * @stability stable
     */
    readonly ipsecPolicy?: VpnServerConfigurationIpsecPolicy[];
    /**
     * radius block.
     *
     * @stability stable
     */
    readonly radius?: VpnServerConfigurationRadius[];
    /**
     * radius_server block.
     *
     * @stability stable
     */
    readonly radiusServer?: VpnServerConfigurationRadiusServerA[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: VpnServerConfigurationTimeouts;
}
/**
 * @stability stable
 */
export interface VpnServerConfigurationAzureActiveDirectoryAuthentication {
    /**
     * @stability stable
     */
    readonly audience: string;
    /**
     * @stability stable
     */
    readonly issuer: string;
    /**
     * @stability stable
     */
    readonly tenant: string;
}
/**
 * @stability stable
 */
export interface VpnServerConfigurationClientRevokedCertificate {
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly thumbprint: string;
}
/**
 * @stability stable
 */
export interface VpnServerConfigurationClientRootCertificate {
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly publicCertData: string;
}
/**
 * @stability stable
 */
export interface VpnServerConfigurationIpsecPolicy {
    /**
     * @stability stable
     */
    readonly dhGroup: string;
    /**
     * @stability stable
     */
    readonly ikeEncryption: string;
    /**
     * @stability stable
     */
    readonly ikeIntegrity: string;
    /**
     * @stability stable
     */
    readonly ipsecEncryption: string;
    /**
     * @stability stable
     */
    readonly ipsecIntegrity: string;
    /**
     * @stability stable
     */
    readonly pfsGroup: string;
    /**
     * @stability stable
     */
    readonly saDataSizeKilobytes: number;
    /**
     * @stability stable
     */
    readonly saLifetimeSeconds: number;
}
/**
 * @stability stable
 */
export interface VpnServerConfigurationRadiusClientRootCertificate {
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly thumbprint: string;
}
/**
 * @stability stable
 */
export interface VpnServerConfigurationRadiusServer {
    /**
     * @stability stable
     */
    readonly address: string;
    /**
     * @stability stable
     */
    readonly score: number;
    /**
     * @stability stable
     */
    readonly secret: string;
}
/**
 * @stability stable
 */
export interface VpnServerConfigurationRadiusServerRootCertificate {
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly publicCertData: string;
}
/**
 * @stability stable
 */
export interface VpnServerConfigurationRadius {
    /**
     * client_root_certificate block.
     *
     * @stability stable
     */
    readonly clientRootCertificate?: VpnServerConfigurationRadiusClientRootCertificate[];
    /**
     * server block.
     *
     * @stability stable
     */
    readonly server?: VpnServerConfigurationRadiusServer[];
    /**
     * server_root_certificate block.
     *
     * @stability stable
     */
    readonly serverRootCertificate: VpnServerConfigurationRadiusServerRootCertificate[];
}
/**
 * @stability stable
 */
export interface VpnServerConfigurationRadiusServerClientRootCertificate {
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly thumbprint: string;
}
/**
 * @stability stable
 */
export interface VpnServerConfigurationRadiusServerServerRootCertificate {
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly publicCertData: string;
}
/**
 * @stability stable
 */
export interface VpnServerConfigurationRadiusServerA {
    /**
     * @stability stable
     */
    readonly address: string;
    /**
     * @stability stable
     */
    readonly secret: string;
    /**
     * client_root_certificate block.
     *
     * @stability stable
     */
    readonly clientRootCertificate?: VpnServerConfigurationRadiusServerClientRootCertificate[];
    /**
     * server_root_certificate block.
     *
     * @stability stable
     */
    readonly serverRootCertificate: VpnServerConfigurationRadiusServerServerRootCertificate[];
}
/**
 * @stability stable
 */
export interface VpnServerConfigurationTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class VpnServerConfiguration extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: VpnServerConfigurationConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _vpnAuthenticationTypes;
    /**
     * @stability stable
     */
    get vpnAuthenticationTypes(): string[];
    /**
     * @stability stable
     */
    set vpnAuthenticationTypes(value: string[]);
    /**
     * @stability stable
     */
    get vpnAuthenticationTypesInput(): string[];
    private _vpnProtocols?;
    /**
     * @stability stable
     */
    get vpnProtocols(): string[];
    /**
     * @stability stable
     */
    set vpnProtocols(value: string[]);
    /**
     * @stability stable
     */
    resetVpnProtocols(): void;
    /**
     * @stability stable
     */
    get vpnProtocolsInput(): string[] | undefined;
    private _azureActiveDirectoryAuthentication?;
    /**
     * @stability stable
     */
    get azureActiveDirectoryAuthentication(): VpnServerConfigurationAzureActiveDirectoryAuthentication[];
    /**
     * @stability stable
     */
    set azureActiveDirectoryAuthentication(value: VpnServerConfigurationAzureActiveDirectoryAuthentication[]);
    /**
     * @stability stable
     */
    resetAzureActiveDirectoryAuthentication(): void;
    /**
     * @stability stable
     */
    get azureActiveDirectoryAuthenticationInput(): VpnServerConfigurationAzureActiveDirectoryAuthentication[] | undefined;
    private _clientRevokedCertificate?;
    /**
     * @stability stable
     */
    get clientRevokedCertificate(): VpnServerConfigurationClientRevokedCertificate[];
    /**
     * @stability stable
     */
    set clientRevokedCertificate(value: VpnServerConfigurationClientRevokedCertificate[]);
    /**
     * @stability stable
     */
    resetClientRevokedCertificate(): void;
    /**
     * @stability stable
     */
    get clientRevokedCertificateInput(): VpnServerConfigurationClientRevokedCertificate[] | undefined;
    private _clientRootCertificate?;
    /**
     * @stability stable
     */
    get clientRootCertificate(): VpnServerConfigurationClientRootCertificate[];
    /**
     * @stability stable
     */
    set clientRootCertificate(value: VpnServerConfigurationClientRootCertificate[]);
    /**
     * @stability stable
     */
    resetClientRootCertificate(): void;
    /**
     * @stability stable
     */
    get clientRootCertificateInput(): VpnServerConfigurationClientRootCertificate[] | undefined;
    private _ipsecPolicy?;
    /**
     * @stability stable
     */
    get ipsecPolicy(): VpnServerConfigurationIpsecPolicy[];
    /**
     * @stability stable
     */
    set ipsecPolicy(value: VpnServerConfigurationIpsecPolicy[]);
    /**
     * @stability stable
     */
    resetIpsecPolicy(): void;
    /**
     * @stability stable
     */
    get ipsecPolicyInput(): VpnServerConfigurationIpsecPolicy[] | undefined;
    private _radius?;
    /**
     * @stability stable
     */
    get radius(): VpnServerConfigurationRadius[];
    /**
     * @stability stable
     */
    set radius(value: VpnServerConfigurationRadius[]);
    /**
     * @stability stable
     */
    resetRadius(): void;
    /**
     * @stability stable
     */
    get radiusInput(): VpnServerConfigurationRadius[] | undefined;
    private _radiusServer?;
    /**
     * @stability stable
     */
    get radiusServer(): VpnServerConfigurationRadiusServerA[];
    /**
     * @stability stable
     */
    set radiusServer(value: VpnServerConfigurationRadiusServerA[]);
    /**
     * @stability stable
     */
    resetRadiusServer(): void;
    /**
     * @stability stable
     */
    get radiusServerInput(): VpnServerConfigurationRadiusServerA[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): VpnServerConfigurationTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: VpnServerConfigurationTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): VpnServerConfigurationTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
