import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface WebApplicationFirewallPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * custom_rules block.
     *
     * @stability stable
     */
    readonly customRules?: WebApplicationFirewallPolicyCustomRules[];
    /**
     * managed_rules block.
     *
     * @stability stable
     */
    readonly managedRules: WebApplicationFirewallPolicyManagedRules[];
    /**
     * policy_settings block.
     *
     * @stability stable
     */
    readonly policySettings?: WebApplicationFirewallPolicyPolicySettings[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: WebApplicationFirewallPolicyTimeouts;
}
/**
 * @stability stable
 */
export interface WebApplicationFirewallPolicyCustomRulesMatchConditionsMatchVariables {
    /**
     * @stability stable
     */
    readonly selector?: string;
    /**
     * @stability stable
     */
    readonly variableName: string;
}
/**
 * @stability stable
 */
export interface WebApplicationFirewallPolicyCustomRulesMatchConditions {
    /**
     * @stability stable
     */
    readonly matchValues: string[];
    /**
     * @stability stable
     */
    readonly negationCondition?: boolean;
    /**
     * @stability stable
     */
    readonly operator: string;
    /**
     * @stability stable
     */
    readonly transforms?: string[];
    /**
     * match_variables block.
     *
     * @stability stable
     */
    readonly matchVariables: WebApplicationFirewallPolicyCustomRulesMatchConditionsMatchVariables[];
}
/**
 * @stability stable
 */
export interface WebApplicationFirewallPolicyCustomRules {
    /**
     * @stability stable
     */
    readonly action: string;
    /**
     * @stability stable
     */
    readonly name?: string;
    /**
     * @stability stable
     */
    readonly priority: number;
    /**
     * @stability stable
     */
    readonly ruleType: string;
    /**
     * match_conditions block.
     *
     * @stability stable
     */
    readonly matchConditions: WebApplicationFirewallPolicyCustomRulesMatchConditions[];
}
/**
 * @stability stable
 */
export interface WebApplicationFirewallPolicyManagedRulesExclusion {
    /**
     * @stability stable
     */
    readonly matchVariable: string;
    /**
     * @stability stable
     */
    readonly selector: string;
    /**
     * @stability stable
     */
    readonly selectorMatchOperator: string;
}
/**
 * @stability stable
 */
export interface WebApplicationFirewallPolicyManagedRulesManagedRuleSetRuleGroupOverride {
    /**
     * @stability stable
     */
    readonly disabledRules: string[];
    /**
     * @stability stable
     */
    readonly ruleGroupName: string;
}
/**
 * @stability stable
 */
export interface WebApplicationFirewallPolicyManagedRulesManagedRuleSet {
    /**
     * @stability stable
     */
    readonly type?: string;
    /**
     * @stability stable
     */
    readonly version: string;
    /**
     * rule_group_override block.
     *
     * @stability stable
     */
    readonly ruleGroupOverride?: WebApplicationFirewallPolicyManagedRulesManagedRuleSetRuleGroupOverride[];
}
/**
 * @stability stable
 */
export interface WebApplicationFirewallPolicyManagedRules {
    /**
     * exclusion block.
     *
     * @stability stable
     */
    readonly exclusion?: WebApplicationFirewallPolicyManagedRulesExclusion[];
    /**
     * managed_rule_set block.
     *
     * @stability stable
     */
    readonly managedRuleSet: WebApplicationFirewallPolicyManagedRulesManagedRuleSet[];
}
/**
 * @stability stable
 */
export interface WebApplicationFirewallPolicyPolicySettings {
    /**
     * @stability stable
     */
    readonly enabled?: boolean;
    /**
     * @stability stable
     */
    readonly fileUploadLimitInMb?: number;
    /**
     * @stability stable
     */
    readonly maxRequestBodySizeInKb?: number;
    /**
     * @stability stable
     */
    readonly mode?: string;
    /**
     * @stability stable
     */
    readonly requestBodyCheck?: boolean;
}
/**
 * @stability stable
 */
export interface WebApplicationFirewallPolicyTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class WebApplicationFirewallPolicy extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: WebApplicationFirewallPolicyConfig);
    /**
     * @stability stable
     */
    get httpListenerIds(): string[];
    /**
     * @stability stable
     */
    get id(): string;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    /**
     * @stability stable
     */
    get pathBasedRuleIds(): string[];
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _customRules?;
    /**
     * @stability stable
     */
    get customRules(): WebApplicationFirewallPolicyCustomRules[];
    /**
     * @stability stable
     */
    set customRules(value: WebApplicationFirewallPolicyCustomRules[]);
    /**
     * @stability stable
     */
    resetCustomRules(): void;
    /**
     * @stability stable
     */
    get customRulesInput(): WebApplicationFirewallPolicyCustomRules[] | undefined;
    private _managedRules;
    /**
     * @stability stable
     */
    get managedRules(): WebApplicationFirewallPolicyManagedRules[];
    /**
     * @stability stable
     */
    set managedRules(value: WebApplicationFirewallPolicyManagedRules[]);
    /**
     * @stability stable
     */
    get managedRulesInput(): WebApplicationFirewallPolicyManagedRules[];
    private _policySettings?;
    /**
     * @stability stable
     */
    get policySettings(): WebApplicationFirewallPolicyPolicySettings[];
    /**
     * @stability stable
     */
    set policySettings(value: WebApplicationFirewallPolicyPolicySettings[]);
    /**
     * @stability stable
     */
    resetPolicySettings(): void;
    /**
     * @stability stable
     */
    get policySettingsInput(): WebApplicationFirewallPolicyPolicySettings[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): WebApplicationFirewallPolicyTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: WebApplicationFirewallPolicyTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): WebApplicationFirewallPolicyTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
